#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1286
#define LARGE_STATE_COUNT 8
#define SYMBOL_COUNT 176
#define ALIAS_COUNT 5
#define TOKEN_COUNT 111
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 24
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 80

enum ts_symbol_identifiers {
  sym_word = 1,
  aux_sym__thing_token1 = 2,
  anon_sym_COLON = 3,
  anon_sym_AMP_COLON = 4,
  anon_sym_COLON_COLON = 5,
  aux_sym__ordinary_rule_token1 = 6,
  anon_sym_PIPE = 7,
  anon_sym_SEMI = 8,
  anon_sym_AT = 9,
  anon_sym_DASH = 10,
  anon_sym_PLUS = 11,
  anon_sym_VPATH = 12,
  anon_sym_EQ = 13,
  anon_sym_COLON_EQ = 14,
  anon_sym_COLON_COLON_EQ = 15,
  anon_sym_QMARK_EQ = 16,
  anon_sym_PLUS_EQ = 17,
  anon_sym_DOTRECIPEPREFIX = 18,
  anon_sym_BANG_EQ = 19,
  anon_sym_define = 20,
  anon_sym_endef = 21,
  anon_sym_include = 22,
  anon_sym_sinclude = 23,
  anon_sym_DASHinclude = 24,
  anon_sym_vpath = 25,
  anon_sym_export = 26,
  anon_sym_unexport = 27,
  anon_sym_override = 28,
  anon_sym_undefine = 29,
  anon_sym_private = 30,
  anon_sym_endif = 31,
  anon_sym_else = 32,
  anon_sym_ifeq = 33,
  anon_sym_ifneq = 34,
  anon_sym_ifdef = 35,
  anon_sym_ifndef = 36,
  anon_sym_LPAREN = 37,
  anon_sym_COMMA = 38,
  anon_sym_RPAREN = 39,
  anon_sym_DOLLAR = 40,
  anon_sym_DOLLAR_DOLLAR = 41,
  anon_sym_LPAREN2 = 42,
  anon_sym_LBRACE = 43,
  anon_sym_RBRACE = 44,
  aux_sym_variable_reference_token1 = 45,
  anon_sym_AT2 = 46,
  anon_sym_PERCENT = 47,
  anon_sym_LT = 48,
  anon_sym_QMARK = 49,
  anon_sym_CARET = 50,
  anon_sym_PLUS2 = 51,
  anon_sym_SLASH = 52,
  anon_sym_STAR = 53,
  anon_sym_PERCENT2 = 54,
  anon_sym_LT2 = 55,
  anon_sym_QMARK2 = 56,
  anon_sym_CARET2 = 57,
  anon_sym_SLASH2 = 58,
  anon_sym_STAR2 = 59,
  anon_sym_D = 60,
  anon_sym_F = 61,
  anon_sym_subst = 62,
  anon_sym_patsubst = 63,
  anon_sym_strip = 64,
  anon_sym_findstring = 65,
  anon_sym_filter = 66,
  anon_sym_filter_DASHout = 67,
  anon_sym_sort = 68,
  anon_sym_word = 69,
  anon_sym_words = 70,
  anon_sym_wordlist = 71,
  anon_sym_firstword = 72,
  anon_sym_lastword = 73,
  anon_sym_dir = 74,
  anon_sym_notdir = 75,
  anon_sym_suffix = 76,
  anon_sym_basename = 77,
  anon_sym_addsuffix = 78,
  anon_sym_addprefix = 79,
  anon_sym_join = 80,
  anon_sym_wildcard = 81,
  anon_sym_realpath = 82,
  anon_sym_abspath = 83,
  anon_sym_error = 84,
  anon_sym_warning = 85,
  anon_sym_info = 86,
  anon_sym_origin = 87,
  anon_sym_flavor = 88,
  anon_sym_foreach = 89,
  anon_sym_if = 90,
  anon_sym_or = 91,
  anon_sym_and = 92,
  anon_sym_call = 93,
  anon_sym_eval = 94,
  anon_sym_file = 95,
  anon_sym_value = 96,
  anon_sym_shell = 97,
  aux_sym_list_token1 = 98,
  anon_sym_COLON2 = 99,
  anon_sym_SEMI2 = 100,
  anon_sym_DQUOTE = 101,
  anon_sym_SQUOTE = 102,
  aux_sym__string_token1 = 103,
  anon_sym_RPAREN2 = 104,
  sym__recipeprefix = 105,
  sym__rawline = 106,
  aux_sym__shell_text_without_split_token1 = 107,
  anon_sym_SLASH_SLASH = 108,
  aux_sym_text_token1 = 109,
  sym_comment = 110,
  sym_makefile = 111,
  sym__thing = 112,
  sym_rule = 113,
  sym__ordinary_rule = 114,
  sym__static_pattern_rule = 115,
  sym__normal_prerequisites = 116,
  sym_recipe = 117,
  sym__attached_recipe_line = 118,
  sym__prefixed_recipe_line = 119,
  sym_recipe_line = 120,
  sym__variable_definition = 121,
  sym_VPATH_assignment = 122,
  sym_RECIPEPREFIX_assignment = 123,
  sym_variable_assignment = 124,
  sym_shell_assignment = 125,
  sym_define_directive = 126,
  sym__directive = 127,
  sym_include_directive = 128,
  sym_vpath_directive = 129,
  sym_export_directive = 130,
  sym_unexport_directive = 131,
  sym_override_directive = 132,
  sym_undefine_directive = 133,
  sym_private_directive = 134,
  sym_conditional = 135,
  sym_elsif_directive = 136,
  sym_else_directive = 137,
  sym__conditional_directives = 138,
  aux_sym__conditional_consequence = 139,
  sym_ifeq_directive = 140,
  sym_ifneq_directive = 141,
  sym_ifdef_directive = 142,
  sym_ifndef_directive = 143,
  sym__conditional_args_cmp = 144,
  sym__variable = 145,
  sym_variable_reference = 146,
  sym_substitution_reference = 147,
  sym_automatic_variable = 148,
  sym__function = 149,
  sym_function_call = 150,
  sym_arguments = 151,
  sym_shell_function = 152,
  sym_list = 153,
  sym_paths = 154,
  sym_concatenation = 155,
  sym_string = 156,
  aux_sym__string = 157,
  sym_archive = 158,
  sym__shell_text_without_split = 159,
  sym_shell_text_with_split = 160,
  sym__shell_command = 161,
  sym_text = 162,
  aux_sym_makefile_repeat1 = 163,
  aux_sym_recipe_repeat1 = 164,
  aux_sym_recipe_line_repeat1 = 165,
  aux_sym_define_directive_repeat1 = 166,
  aux_sym_conditional_repeat1 = 167,
  aux_sym_arguments_repeat1 = 168,
  aux_sym_list_repeat1 = 169,
  aux_sym_paths_repeat1 = 170,
  aux_sym_concatenation_repeat1 = 171,
  aux_sym__shell_text_without_split_repeat1 = 172,
  aux_sym__shell_text_without_split_repeat2 = 173,
  aux_sym_text_repeat1 = 174,
  aux_sym_text_repeat2 = 175,
  alias_sym_pattern_list = 176,
  alias_sym_prerequisites = 177,
  alias_sym_raw_text = 178,
  alias_sym_shell_command = 179,
  alias_sym_targets = 180,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_word] = "word",
  [aux_sym__thing_token1] = "_thing_token1",
  [anon_sym_COLON] = ":",
  [anon_sym_AMP_COLON] = "&:",
  [anon_sym_COLON_COLON] = "::",
  [aux_sym__ordinary_rule_token1] = "_ordinary_rule_token1",
  [anon_sym_PIPE] = "|",
  [anon_sym_SEMI] = ";",
  [anon_sym_AT] = "@",
  [anon_sym_DASH] = "-",
  [anon_sym_PLUS] = "+",
  [anon_sym_VPATH] = "VPATH",
  [anon_sym_EQ] = "=",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_COLON_COLON_EQ] = "::=",
  [anon_sym_QMARK_EQ] = "\?=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DOTRECIPEPREFIX] = ".RECIPEPREFIX",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_define] = "define",
  [anon_sym_endef] = "endef",
  [anon_sym_include] = "include",
  [anon_sym_sinclude] = "sinclude",
  [anon_sym_DASHinclude] = "-include",
  [anon_sym_vpath] = "vpath",
  [anon_sym_export] = "export",
  [anon_sym_unexport] = "unexport",
  [anon_sym_override] = "override",
  [anon_sym_undefine] = "undefine",
  [anon_sym_private] = "private",
  [anon_sym_endif] = "endif",
  [anon_sym_else] = "else",
  [anon_sym_ifeq] = "ifeq",
  [anon_sym_ifneq] = "ifneq",
  [anon_sym_ifdef] = "ifdef",
  [anon_sym_ifndef] = "ifndef",
  [anon_sym_LPAREN] = "(",
  [anon_sym_COMMA] = ",",
  [anon_sym_RPAREN] = ")",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_DOLLAR_DOLLAR] = "$$",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_variable_reference_token1] = "word",
  [anon_sym_AT2] = "@",
  [anon_sym_PERCENT] = "%",
  [anon_sym_LT] = "<",
  [anon_sym_QMARK] = "\?",
  [anon_sym_CARET] = "^",
  [anon_sym_PLUS2] = "+",
  [anon_sym_SLASH] = "/",
  [anon_sym_STAR] = "*",
  [anon_sym_PERCENT2] = "%",
  [anon_sym_LT2] = "<",
  [anon_sym_QMARK2] = "\?",
  [anon_sym_CARET2] = "^",
  [anon_sym_SLASH2] = "/",
  [anon_sym_STAR2] = "*",
  [anon_sym_D] = "D",
  [anon_sym_F] = "F",
  [anon_sym_subst] = "subst",
  [anon_sym_patsubst] = "patsubst",
  [anon_sym_strip] = "strip",
  [anon_sym_findstring] = "findstring",
  [anon_sym_filter] = "filter",
  [anon_sym_filter_DASHout] = "filter-out",
  [anon_sym_sort] = "sort",
  [anon_sym_word] = "word",
  [anon_sym_words] = "words",
  [anon_sym_wordlist] = "wordlist",
  [anon_sym_firstword] = "firstword",
  [anon_sym_lastword] = "lastword",
  [anon_sym_dir] = "dir",
  [anon_sym_notdir] = "notdir",
  [anon_sym_suffix] = "suffix",
  [anon_sym_basename] = "basename",
  [anon_sym_addsuffix] = "addsuffix",
  [anon_sym_addprefix] = "addprefix",
  [anon_sym_join] = "join",
  [anon_sym_wildcard] = "wildcard",
  [anon_sym_realpath] = "realpath",
  [anon_sym_abspath] = "abspath",
  [anon_sym_error] = "error",
  [anon_sym_warning] = "warning",
  [anon_sym_info] = "info",
  [anon_sym_origin] = "origin",
  [anon_sym_flavor] = "flavor",
  [anon_sym_foreach] = "foreach",
  [anon_sym_if] = "if",
  [anon_sym_or] = "or",
  [anon_sym_and] = "and",
  [anon_sym_call] = "call",
  [anon_sym_eval] = "eval",
  [anon_sym_file] = "file",
  [anon_sym_value] = "value",
  [anon_sym_shell] = "shell",
  [aux_sym_list_token1] = "\\",
  [anon_sym_COLON2] = ":",
  [anon_sym_SEMI2] = ";",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_SQUOTE] = "'",
  [aux_sym__string_token1] = "_string_token1",
  [anon_sym_RPAREN2] = ")",
  [sym__recipeprefix] = "_recipeprefix",
  [sym__rawline] = "_rawline",
  [aux_sym__shell_text_without_split_token1] = "_shell_text_without_split_token1",
  [anon_sym_SLASH_SLASH] = "escape",
  [aux_sym_text_token1] = "text_token1",
  [sym_comment] = "comment",
  [sym_makefile] = "makefile",
  [sym__thing] = "_thing",
  [sym_rule] = "rule",
  [sym__ordinary_rule] = "_ordinary_rule",
  [sym__static_pattern_rule] = "_static_pattern_rule",
  [sym__normal_prerequisites] = "_normal_prerequisites",
  [sym_recipe] = "recipe",
  [sym__attached_recipe_line] = "_attached_recipe_line",
  [sym__prefixed_recipe_line] = "_prefixed_recipe_line",
  [sym_recipe_line] = "recipe_line",
  [sym__variable_definition] = "_variable_definition",
  [sym_VPATH_assignment] = "VPATH_assignment",
  [sym_RECIPEPREFIX_assignment] = "RECIPEPREFIX_assignment",
  [sym_variable_assignment] = "variable_assignment",
  [sym_shell_assignment] = "shell_assignment",
  [sym_define_directive] = "define_directive",
  [sym__directive] = "_directive",
  [sym_include_directive] = "include_directive",
  [sym_vpath_directive] = "vpath_directive",
  [sym_export_directive] = "export_directive",
  [sym_unexport_directive] = "unexport_directive",
  [sym_override_directive] = "override_directive",
  [sym_undefine_directive] = "undefine_directive",
  [sym_private_directive] = "private_directive",
  [sym_conditional] = "conditional",
  [sym_elsif_directive] = "elsif_directive",
  [sym_else_directive] = "else_directive",
  [sym__conditional_directives] = "_conditional_directives",
  [aux_sym__conditional_consequence] = "_conditional_consequence",
  [sym_ifeq_directive] = "ifeq_directive",
  [sym_ifneq_directive] = "ifneq_directive",
  [sym_ifdef_directive] = "ifdef_directive",
  [sym_ifndef_directive] = "ifndef_directive",
  [sym__conditional_args_cmp] = "_conditional_args_cmp",
  [sym__variable] = "_variable",
  [sym_variable_reference] = "variable_reference",
  [sym_substitution_reference] = "substitution_reference",
  [sym_automatic_variable] = "automatic_variable",
  [sym__function] = "_function",
  [sym_function_call] = "function_call",
  [sym_arguments] = "arguments",
  [sym_shell_function] = "shell_function",
  [sym_list] = "list",
  [sym_paths] = "paths",
  [sym_concatenation] = "concatenation",
  [sym_string] = "string",
  [aux_sym__string] = "_string",
  [sym_archive] = "archive",
  [sym__shell_text_without_split] = "_shell_text_without_split",
  [sym_shell_text_with_split] = "shell_text",
  [sym__shell_command] = "_shell_command",
  [sym_text] = "text",
  [aux_sym_makefile_repeat1] = "makefile_repeat1",
  [aux_sym_recipe_repeat1] = "recipe_repeat1",
  [aux_sym_recipe_line_repeat1] = "recipe_line_repeat1",
  [aux_sym_define_directive_repeat1] = "define_directive_repeat1",
  [aux_sym_conditional_repeat1] = "conditional_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_list_repeat1] = "list_repeat1",
  [aux_sym_paths_repeat1] = "paths_repeat1",
  [aux_sym_concatenation_repeat1] = "concatenation_repeat1",
  [aux_sym__shell_text_without_split_repeat1] = "_shell_text_without_split_repeat1",
  [aux_sym__shell_text_without_split_repeat2] = "_shell_text_without_split_repeat2",
  [aux_sym_text_repeat1] = "text_repeat1",
  [aux_sym_text_repeat2] = "text_repeat2",
  [alias_sym_pattern_list] = "pattern_list",
  [alias_sym_prerequisites] = "prerequisites",
  [alias_sym_raw_text] = "raw_text",
  [alias_sym_shell_command] = "shell_command",
  [alias_sym_targets] = "targets",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_word] = sym_word,
  [aux_sym__thing_token1] = aux_sym__thing_token1,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_AMP_COLON] = anon_sym_AMP_COLON,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [aux_sym__ordinary_rule_token1] = aux_sym__ordinary_rule_token1,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_VPATH] = anon_sym_VPATH,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_COLON_COLON_EQ] = anon_sym_COLON_COLON_EQ,
  [anon_sym_QMARK_EQ] = anon_sym_QMARK_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DOTRECIPEPREFIX] = anon_sym_DOTRECIPEPREFIX,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_define] = anon_sym_define,
  [anon_sym_endef] = anon_sym_endef,
  [anon_sym_include] = anon_sym_include,
  [anon_sym_sinclude] = anon_sym_sinclude,
  [anon_sym_DASHinclude] = anon_sym_DASHinclude,
  [anon_sym_vpath] = anon_sym_vpath,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_unexport] = anon_sym_unexport,
  [anon_sym_override] = anon_sym_override,
  [anon_sym_undefine] = anon_sym_undefine,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_endif] = anon_sym_endif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_ifeq] = anon_sym_ifeq,
  [anon_sym_ifneq] = anon_sym_ifneq,
  [anon_sym_ifdef] = anon_sym_ifdef,
  [anon_sym_ifndef] = anon_sym_ifndef,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_DOLLAR_DOLLAR] = anon_sym_DOLLAR_DOLLAR,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_variable_reference_token1] = sym_word,
  [anon_sym_AT2] = anon_sym_AT,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_PLUS2] = anon_sym_PLUS,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_PERCENT2] = anon_sym_PERCENT,
  [anon_sym_LT2] = anon_sym_LT,
  [anon_sym_QMARK2] = anon_sym_QMARK,
  [anon_sym_CARET2] = anon_sym_CARET,
  [anon_sym_SLASH2] = anon_sym_SLASH,
  [anon_sym_STAR2] = anon_sym_STAR,
  [anon_sym_D] = anon_sym_D,
  [anon_sym_F] = anon_sym_F,
  [anon_sym_subst] = anon_sym_subst,
  [anon_sym_patsubst] = anon_sym_patsubst,
  [anon_sym_strip] = anon_sym_strip,
  [anon_sym_findstring] = anon_sym_findstring,
  [anon_sym_filter] = anon_sym_filter,
  [anon_sym_filter_DASHout] = anon_sym_filter_DASHout,
  [anon_sym_sort] = anon_sym_sort,
  [anon_sym_word] = anon_sym_word,
  [anon_sym_words] = anon_sym_words,
  [anon_sym_wordlist] = anon_sym_wordlist,
  [anon_sym_firstword] = anon_sym_firstword,
  [anon_sym_lastword] = anon_sym_lastword,
  [anon_sym_dir] = anon_sym_dir,
  [anon_sym_notdir] = anon_sym_notdir,
  [anon_sym_suffix] = anon_sym_suffix,
  [anon_sym_basename] = anon_sym_basename,
  [anon_sym_addsuffix] = anon_sym_addsuffix,
  [anon_sym_addprefix] = anon_sym_addprefix,
  [anon_sym_join] = anon_sym_join,
  [anon_sym_wildcard] = anon_sym_wildcard,
  [anon_sym_realpath] = anon_sym_realpath,
  [anon_sym_abspath] = anon_sym_abspath,
  [anon_sym_error] = anon_sym_error,
  [anon_sym_warning] = anon_sym_warning,
  [anon_sym_info] = anon_sym_info,
  [anon_sym_origin] = anon_sym_origin,
  [anon_sym_flavor] = anon_sym_flavor,
  [anon_sym_foreach] = anon_sym_foreach,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_call] = anon_sym_call,
  [anon_sym_eval] = anon_sym_eval,
  [anon_sym_file] = anon_sym_file,
  [anon_sym_value] = anon_sym_value,
  [anon_sym_shell] = anon_sym_shell,
  [aux_sym_list_token1] = aux_sym_list_token1,
  [anon_sym_COLON2] = anon_sym_COLON,
  [anon_sym_SEMI2] = anon_sym_SEMI,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym__string_token1] = aux_sym__string_token1,
  [anon_sym_RPAREN2] = anon_sym_RPAREN,
  [sym__recipeprefix] = sym__recipeprefix,
  [sym__rawline] = sym__rawline,
  [aux_sym__shell_text_without_split_token1] = aux_sym__shell_text_without_split_token1,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [aux_sym_text_token1] = aux_sym_text_token1,
  [sym_comment] = sym_comment,
  [sym_makefile] = sym_makefile,
  [sym__thing] = sym__thing,
  [sym_rule] = sym_rule,
  [sym__ordinary_rule] = sym__ordinary_rule,
  [sym__static_pattern_rule] = sym__static_pattern_rule,
  [sym__normal_prerequisites] = sym__normal_prerequisites,
  [sym_recipe] = sym_recipe,
  [sym__attached_recipe_line] = sym__attached_recipe_line,
  [sym__prefixed_recipe_line] = sym__prefixed_recipe_line,
  [sym_recipe_line] = sym_recipe_line,
  [sym__variable_definition] = sym__variable_definition,
  [sym_VPATH_assignment] = sym_VPATH_assignment,
  [sym_RECIPEPREFIX_assignment] = sym_RECIPEPREFIX_assignment,
  [sym_variable_assignment] = sym_variable_assignment,
  [sym_shell_assignment] = sym_shell_assignment,
  [sym_define_directive] = sym_define_directive,
  [sym__directive] = sym__directive,
  [sym_include_directive] = sym_include_directive,
  [sym_vpath_directive] = sym_vpath_directive,
  [sym_export_directive] = sym_export_directive,
  [sym_unexport_directive] = sym_unexport_directive,
  [sym_override_directive] = sym_override_directive,
  [sym_undefine_directive] = sym_undefine_directive,
  [sym_private_directive] = sym_private_directive,
  [sym_conditional] = sym_conditional,
  [sym_elsif_directive] = sym_elsif_directive,
  [sym_else_directive] = sym_else_directive,
  [sym__conditional_directives] = sym__conditional_directives,
  [aux_sym__conditional_consequence] = aux_sym__conditional_consequence,
  [sym_ifeq_directive] = sym_ifeq_directive,
  [sym_ifneq_directive] = sym_ifneq_directive,
  [sym_ifdef_directive] = sym_ifdef_directive,
  [sym_ifndef_directive] = sym_ifndef_directive,
  [sym__conditional_args_cmp] = sym__conditional_args_cmp,
  [sym__variable] = sym__variable,
  [sym_variable_reference] = sym_variable_reference,
  [sym_substitution_reference] = sym_substitution_reference,
  [sym_automatic_variable] = sym_automatic_variable,
  [sym__function] = sym__function,
  [sym_function_call] = sym_function_call,
  [sym_arguments] = sym_arguments,
  [sym_shell_function] = sym_shell_function,
  [sym_list] = sym_list,
  [sym_paths] = sym_paths,
  [sym_concatenation] = sym_concatenation,
  [sym_string] = sym_string,
  [aux_sym__string] = aux_sym__string,
  [sym_archive] = sym_archive,
  [sym__shell_text_without_split] = sym__shell_text_without_split,
  [sym_shell_text_with_split] = sym_shell_text_with_split,
  [sym__shell_command] = sym__shell_command,
  [sym_text] = sym_text,
  [aux_sym_makefile_repeat1] = aux_sym_makefile_repeat1,
  [aux_sym_recipe_repeat1] = aux_sym_recipe_repeat1,
  [aux_sym_recipe_line_repeat1] = aux_sym_recipe_line_repeat1,
  [aux_sym_define_directive_repeat1] = aux_sym_define_directive_repeat1,
  [aux_sym_conditional_repeat1] = aux_sym_conditional_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_list_repeat1] = aux_sym_list_repeat1,
  [aux_sym_paths_repeat1] = aux_sym_paths_repeat1,
  [aux_sym_concatenation_repeat1] = aux_sym_concatenation_repeat1,
  [aux_sym__shell_text_without_split_repeat1] = aux_sym__shell_text_without_split_repeat1,
  [aux_sym__shell_text_without_split_repeat2] = aux_sym__shell_text_without_split_repeat2,
  [aux_sym_text_repeat1] = aux_sym_text_repeat1,
  [aux_sym_text_repeat2] = aux_sym_text_repeat2,
  [alias_sym_pattern_list] = alias_sym_pattern_list,
  [alias_sym_prerequisites] = alias_sym_prerequisites,
  [alias_sym_raw_text] = alias_sym_raw_text,
  [alias_sym_shell_command] = alias_sym_shell_command,
  [alias_sym_targets] = alias_sym_targets,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_word] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__thing_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__ordinary_rule_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_VPATH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOTRECIPEPREFIX] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_define] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_include] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sinclude] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHinclude] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vpath] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unexport] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_undefine] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ifeq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ifneq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ifdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ifndef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_variable_reference_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_AT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_D] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_F] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_subst] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_patsubst] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_strip] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_findstring] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_filter] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_filter_DASHout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sort] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_word] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_words] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wordlist] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_firstword] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lastword] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dir] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_notdir] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_suffix] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_basename] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_addsuffix] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_addprefix] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_join] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_wildcard] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_realpath] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abspath] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_error] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_warning] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_info] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_origin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_flavor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreach] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_call] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eval] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_file] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_value] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_shell] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_list_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__string_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RPAREN2] = {
    .visible = true,
    .named = false,
  },
  [sym__recipeprefix] = {
    .visible = false,
    .named = true,
  },
  [sym__rawline] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__shell_text_without_split_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_text_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_makefile] = {
    .visible = true,
    .named = true,
  },
  [sym__thing] = {
    .visible = false,
    .named = true,
  },
  [sym_rule] = {
    .visible = true,
    .named = true,
  },
  [sym__ordinary_rule] = {
    .visible = false,
    .named = true,
  },
  [sym__static_pattern_rule] = {
    .visible = false,
    .named = true,
  },
  [sym__normal_prerequisites] = {
    .visible = false,
    .named = true,
  },
  [sym_recipe] = {
    .visible = true,
    .named = true,
  },
  [sym__attached_recipe_line] = {
    .visible = false,
    .named = true,
  },
  [sym__prefixed_recipe_line] = {
    .visible = false,
    .named = true,
  },
  [sym_recipe_line] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_definition] = {
    .visible = false,
    .named = true,
  },
  [sym_VPATH_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_RECIPEPREFIX_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_shell_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_define_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__directive] = {
    .visible = false,
    .named = true,
  },
  [sym_include_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_vpath_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_export_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_unexport_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_override_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_undefine_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_private_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional] = {
    .visible = true,
    .named = true,
  },
  [sym_elsif_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_else_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__conditional_directives] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__conditional_consequence] = {
    .visible = false,
    .named = false,
  },
  [sym_ifeq_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_ifneq_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_ifdef_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_ifndef_directive] = {
    .visible = true,
    .named = true,
  },
  [sym__conditional_args_cmp] = {
    .visible = false,
    .named = true,
  },
  [sym__variable] = {
    .visible = false,
    .named = true,
  },
  [sym_variable_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_substitution_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_automatic_variable] = {
    .visible = true,
    .named = true,
  },
  [sym__function] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_shell_function] = {
    .visible = true,
    .named = true,
  },
  [sym_list] = {
    .visible = true,
    .named = true,
  },
  [sym_paths] = {
    .visible = true,
    .named = true,
  },
  [sym_concatenation] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__string] = {
    .visible = false,
    .named = false,
  },
  [sym_archive] = {
    .visible = true,
    .named = true,
  },
  [sym__shell_text_without_split] = {
    .visible = false,
    .named = true,
  },
  [sym_shell_text_with_split] = {
    .visible = true,
    .named = true,
  },
  [sym__shell_command] = {
    .visible = false,
    .named = true,
  },
  [sym_text] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_makefile_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_recipe_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_recipe_line_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_directive_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_conditional_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_paths_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_concatenation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__shell_text_without_split_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__shell_text_without_split_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_text_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_text_repeat2] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_pattern_list] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_prerequisites] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_raw_text] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_shell_command] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_targets] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_archive = 1,
  field_arg0 = 2,
  field_arg1 = 3,
  field_argument = 4,
  field_condition = 5,
  field_consequence = 6,
  field_directories = 7,
  field_filenames = 8,
  field_function = 9,
  field_members = 10,
  field_name = 11,
  field_normal = 12,
  field_operator = 13,
  field_order_only = 14,
  field_pattern = 15,
  field_prerequisite = 16,
  field_replacement = 17,
  field_string = 18,
  field_target = 19,
  field_target_or_pattern = 20,
  field_text = 21,
  field_value = 22,
  field_variable = 23,
  field_variables = 24,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_archive] = "archive",
  [field_arg0] = "arg0",
  [field_arg1] = "arg1",
  [field_argument] = "argument",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_directories] = "directories",
  [field_filenames] = "filenames",
  [field_function] = "function",
  [field_members] = "members",
  [field_name] = "name",
  [field_normal] = "normal",
  [field_operator] = "operator",
  [field_order_only] = "order_only",
  [field_pattern] = "pattern",
  [field_prerequisite] = "prerequisite",
  [field_replacement] = "replacement",
  [field_string] = "string",
  [field_target] = "target",
  [field_target_or_pattern] = "target_or_pattern",
  [field_text] = "text",
  [field_value] = "value",
  [field_variable] = "variable",
  [field_variables] = "variables",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 2},
  [2] = {.index = 2, .length = 2},
  [3] = {.index = 4, .length = 2},
  [5] = {.index = 6, .length = 1},
  [6] = {.index = 7, .length = 1},
  [7] = {.index = 8, .length = 1},
  [8] = {.index = 9, .length = 1},
  [9] = {.index = 10, .length = 2},
  [10] = {.index = 12, .length = 2},
  [11] = {.index = 14, .length = 3},
  [12] = {.index = 17, .length = 2},
  [14] = {.index = 19, .length = 1},
  [15] = {.index = 20, .length = 1},
  [18] = {.index = 21, .length = 1},
  [19] = {.index = 22, .length = 3},
  [20] = {.index = 25, .length = 2},
  [21] = {.index = 27, .length = 1},
  [22] = {.index = 28, .length = 2},
  [23] = {.index = 30, .length = 2},
  [24] = {.index = 32, .length = 1},
  [25] = {.index = 33, .length = 2},
  [28] = {.index = 35, .length = 2},
  [29] = {.index = 37, .length = 1},
  [30] = {.index = 38, .length = 3},
  [32] = {.index = 41, .length = 1},
  [33] = {.index = 42, .length = 1},
  [34] = {.index = 43, .length = 1},
  [35] = {.index = 44, .length = 1},
  [36] = {.index = 45, .length = 2},
  [37] = {.index = 47, .length = 3},
  [40] = {.index = 50, .length = 1},
  [41] = {.index = 51, .length = 1},
  [42] = {.index = 52, .length = 3},
  [43] = {.index = 55, .length = 1},
  [44] = {.index = 56, .length = 2},
  [45] = {.index = 58, .length = 2},
  [46] = {.index = 60, .length = 2},
  [47] = {.index = 62, .length = 1},
  [48] = {.index = 63, .length = 2},
  [49] = {.index = 65, .length = 3},
  [52] = {.index = 68, .length = 1},
  [53] = {.index = 69, .length = 3},
  [54] = {.index = 72, .length = 1},
  [55] = {.index = 73, .length = 3},
  [56] = {.index = 76, .length = 4},
  [57] = {.index = 80, .length = 2},
  [58] = {.index = 82, .length = 2},
  [59] = {.index = 84, .length = 2},
  [60] = {.index = 86, .length = 2},
  [61] = {.index = 88, .length = 3},
  [63] = {.index = 91, .length = 3},
  [64] = {.index = 94, .length = 4},
  [65] = {.index = 98, .length = 2},
  [66] = {.index = 100, .length = 2},
  [67] = {.index = 102, .length = 4},
  [68] = {.index = 106, .length = 4},
  [69] = {.index = 110, .length = 2},
  [70] = {.index = 112, .length = 2},
  [71] = {.index = 114, .length = 3},
  [72] = {.index = 117, .length = 3},
  [73] = {.index = 120, .length = 3},
  [74] = {.index = 123, .length = 4},
  [75] = {.index = 127, .length = 4},
  [76] = {.index = 131, .length = 2},
  [77] = {.index = 133, .length = 4},
  [78] = {.index = 137, .length = 3},
  [79] = {.index = 140, .length = 4},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_normal, 0, .inherited = true},
    {field_order_only, 0, .inherited = true},
  [2] =
    {field_prerequisite, 0, .inherited = true},
    {field_target, 0, .inherited = true},
  [4] =
    {field_string, 0},
    {field_string, 1},
  [6] =
    {field_filenames, 1},
  [7] =
    {field_pattern, 1},
  [8] =
    {field_variables, 1},
  [9] =
    {field_variable, 1},
  [10] =
    {field_arg0, 0},
    {field_arg1, 1},
  [12] =
    {field_arg0, 1, .inherited = true},
    {field_arg1, 1, .inherited = true},
  [14] =
    {field_string, 0},
    {field_string, 1},
    {field_string, 2},
  [17] =
    {field_name, 0},
    {field_operator, 1},
  [19] =
    {field_condition, 0},
  [20] =
    {field_condition, 1},
  [21] =
    {field_normal, 0},
  [22] =
    {field_name, 0},
    {field_operator, 1},
    {field_value, 2},
  [25] =
    {field_directories, 2},
    {field_pattern, 1},
  [27] =
    {field_argument, 0},
  [28] =
    {field_name, 0},
    {field_operator, 2},
  [30] =
    {field_archive, 0},
    {field_members, 2},
  [32] =
    {field_consequence, 2},
  [33] =
    {field_condition, 1},
    {field_consequence, 2},
  [35] =
    {field_condition, 0},
    {field_consequence, 1},
  [37] =
    {field_normal, 2, .inherited = true},
  [38] =
    {field_name, 0},
    {field_operator, 2},
    {field_value, 3},
  [41] =
    {field_name, 1},
  [42] =
    {field_arg1, 2},
  [43] =
    {field_arg0, 1},
  [44] =
    {field_function, 2},
  [45] =
    {field_argument, 0},
    {field_argument, 1, .inherited = true},
  [47] =
    {field_name, 0},
    {field_operator, 1},
    {field_value, 3},
  [50] =
    {field_normal, 3, .inherited = true},
  [51] =
    {field_order_only, 3},
  [52] =
    {field_name, 2},
    {field_operator, 3},
    {field_target_or_pattern, 0},
  [55] =
    {field_target, 2},
  [56] =
    {field_name, 1},
    {field_value, 3},
  [58] =
    {field_name, 1},
    {field_operator, 2},
  [60] =
    {field_arg0, 1},
    {field_arg1, 3},
  [62] =
    {field_argument, 1},
  [63] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [65] =
    {field_name, 0},
    {field_operator, 2},
    {field_value, 4},
  [68] =
    {field_order_only, 4},
  [69] =
    {field_name, 3},
    {field_operator, 4},
    {field_target_or_pattern, 0},
  [72] =
    {field_target, 3},
  [73] =
    {field_name, 2},
    {field_operator, 4},
    {field_target_or_pattern, 0},
  [76] =
    {field_name, 2},
    {field_operator, 3},
    {field_target_or_pattern, 0},
    {field_value, 4},
  [80] =
    {field_normal, 2, .inherited = true},
    {field_order_only, 4},
  [82] =
    {field_prerequisite, 4},
    {field_target, 2},
  [84] =
    {field_name, 1},
    {field_value, 4},
  [86] =
    {field_name, 1},
    {field_operator, 3},
  [88] =
    {field_name, 1},
    {field_operator, 2},
    {field_value, 4},
  [91] =
    {field_name, 3},
    {field_operator, 5},
    {field_target_or_pattern, 0},
  [94] =
    {field_name, 3},
    {field_operator, 4},
    {field_target_or_pattern, 0},
    {field_value, 5},
  [98] =
    {field_normal, 3, .inherited = true},
    {field_order_only, 5},
  [100] =
    {field_prerequisite, 5},
    {field_target, 3},
  [102] =
    {field_name, 2},
    {field_operator, 4},
    {field_target_or_pattern, 0},
    {field_value, 5},
  [106] =
    {field_name, 2},
    {field_operator, 3},
    {field_target_or_pattern, 0},
    {field_value, 5},
  [110] =
    {field_prerequisite, 5},
    {field_target, 2},
  [112] =
    {field_name, 1},
    {field_value, 5},
  [114] =
    {field_name, 1},
    {field_operator, 3},
    {field_value, 5},
  [117] =
    {field_name, 1},
    {field_operator, 2},
    {field_value, 5},
  [120] =
    {field_pattern, 4},
    {field_replacement, 6},
    {field_text, 2},
  [123] =
    {field_name, 3},
    {field_operator, 5},
    {field_target_or_pattern, 0},
    {field_value, 6},
  [127] =
    {field_name, 3},
    {field_operator, 4},
    {field_target_or_pattern, 0},
    {field_value, 6},
  [131] =
    {field_prerequisite, 6},
    {field_target, 3},
  [133] =
    {field_name, 2},
    {field_operator, 4},
    {field_target_or_pattern, 0},
    {field_value, 6},
  [137] =
    {field_name, 1},
    {field_operator, 3},
    {field_value, 6},
  [140] =
    {field_name, 3},
    {field_operator, 5},
    {field_target_or_pattern, 0},
    {field_value, 7},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [4] = {
    [0] = anon_sym_SLASH_SLASH,
  },
  [13] = {
    [0] = alias_sym_shell_command,
  },
  [16] = {
    [0] = sym_shell_text_with_split,
  },
  [17] = {
    [0] = alias_sym_targets,
  },
  [18] = {
    [0] = alias_sym_prerequisites,
  },
  [26] = {
    [1] = sym_shell_text_with_split,
  },
  [27] = {
    [0] = sym_shell_text_with_split,
    [1] = sym_shell_text_with_split,
  },
  [29] = {
    [0] = alias_sym_targets,
  },
  [31] = {
    [1] = anon_sym_SLASH_SLASH,
  },
  [38] = {
    [1] = sym_shell_text_with_split,
    [2] = sym_shell_text_with_split,
  },
  [39] = {
    [0] = sym_shell_text_with_split,
    [2] = sym_shell_text_with_split,
  },
  [40] = {
    [0] = alias_sym_targets,
  },
  [41] = {
    [0] = alias_sym_targets,
    [3] = alias_sym_prerequisites,
  },
  [43] = {
    [0] = alias_sym_targets,
    [2] = alias_sym_pattern_list,
  },
  [44] = {
    [3] = alias_sym_raw_text,
  },
  [50] = {
    [1] = sym_shell_text_with_split,
    [3] = sym_shell_text_with_split,
  },
  [51] = {
    [0] = sym_shell_text_with_split,
    [3] = sym_shell_text_with_split,
  },
  [52] = {
    [0] = alias_sym_targets,
    [4] = alias_sym_prerequisites,
  },
  [54] = {
    [0] = alias_sym_targets,
    [3] = alias_sym_pattern_list,
  },
  [57] = {
    [0] = alias_sym_targets,
    [4] = alias_sym_prerequisites,
  },
  [58] = {
    [0] = alias_sym_targets,
    [2] = alias_sym_pattern_list,
    [4] = alias_sym_pattern_list,
  },
  [59] = {
    [4] = alias_sym_raw_text,
  },
  [61] = {
    [4] = alias_sym_raw_text,
  },
  [62] = {
    [1] = sym_shell_text_with_split,
    [4] = sym_shell_text_with_split,
  },
  [65] = {
    [0] = alias_sym_targets,
    [5] = alias_sym_prerequisites,
  },
  [66] = {
    [0] = alias_sym_targets,
    [3] = alias_sym_pattern_list,
    [5] = alias_sym_pattern_list,
  },
  [69] = {
    [0] = alias_sym_targets,
    [2] = alias_sym_pattern_list,
    [5] = alias_sym_pattern_list,
  },
  [70] = {
    [5] = alias_sym_raw_text,
  },
  [71] = {
    [5] = alias_sym_raw_text,
  },
  [72] = {
    [5] = alias_sym_raw_text,
  },
  [76] = {
    [0] = alias_sym_targets,
    [3] = alias_sym_pattern_list,
    [6] = alias_sym_pattern_list,
  },
  [78] = {
    [6] = alias_sym_raw_text,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_list, 4,
    sym_list,
    alias_sym_pattern_list,
    alias_sym_prerequisites,
    alias_sym_targets,
  sym__shell_text_without_split, 2,
    sym__shell_text_without_split,
    sym_shell_text_with_split,
  sym_text, 2,
    sym_text,
    alias_sym_shell_command,
  aux_sym_define_directive_repeat1, 2,
    aux_sym_define_directive_repeat1,
    alias_sym_raw_text,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 4,
  [5] = 2,
  [6] = 4,
  [7] = 4,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 13,
  [15] = 13,
  [16] = 13,
  [17] = 13,
  [18] = 13,
  [19] = 13,
  [20] = 13,
  [21] = 13,
  [22] = 13,
  [23] = 13,
  [24] = 13,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 46,
  [52] = 34,
  [53] = 32,
  [54] = 49,
  [55] = 44,
  [56] = 31,
  [57] = 47,
  [58] = 36,
  [59] = 39,
  [60] = 38,
  [61] = 30,
  [62] = 50,
  [63] = 43,
  [64] = 35,
  [65] = 40,
  [66] = 29,
  [67] = 37,
  [68] = 41,
  [69] = 33,
  [70] = 48,
  [71] = 45,
  [72] = 28,
  [73] = 42,
  [74] = 27,
  [75] = 75,
  [76] = 75,
  [77] = 77,
  [78] = 78,
  [79] = 77,
  [80] = 78,
  [81] = 81,
  [82] = 81,
  [83] = 81,
  [84] = 81,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 86,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 102,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 101,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 135,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 85,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 86,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 162,
  [190] = 190,
  [191] = 191,
  [192] = 179,
  [193] = 164,
  [194] = 191,
  [195] = 138,
  [196] = 191,
  [197] = 188,
  [198] = 198,
  [199] = 89,
  [200] = 191,
  [201] = 201,
  [202] = 202,
  [203] = 191,
  [204] = 191,
  [205] = 191,
  [206] = 139,
  [207] = 201,
  [208] = 133,
  [209] = 191,
  [210] = 202,
  [211] = 117,
  [212] = 191,
  [213] = 191,
  [214] = 214,
  [215] = 191,
  [216] = 216,
  [217] = 198,
  [218] = 214,
  [219] = 216,
  [220] = 127,
  [221] = 221,
  [222] = 103,
  [223] = 187,
  [224] = 90,
  [225] = 92,
  [226] = 93,
  [227] = 180,
  [228] = 131,
  [229] = 155,
  [230] = 163,
  [231] = 167,
  [232] = 166,
  [233] = 88,
  [234] = 181,
  [235] = 177,
  [236] = 175,
  [237] = 161,
  [238] = 164,
  [239] = 162,
  [240] = 107,
  [241] = 168,
  [242] = 158,
  [243] = 87,
  [244] = 165,
  [245] = 178,
  [246] = 156,
  [247] = 160,
  [248] = 169,
  [249] = 157,
  [250] = 152,
  [251] = 154,
  [252] = 150,
  [253] = 170,
  [254] = 140,
  [255] = 255,
  [256] = 137,
  [257] = 153,
  [258] = 151,
  [259] = 184,
  [260] = 260,
  [261] = 261,
  [262] = 133,
  [263] = 149,
  [264] = 148,
  [265] = 186,
  [266] = 136,
  [267] = 139,
  [268] = 147,
  [269] = 132,
  [270] = 171,
  [271] = 91,
  [272] = 123,
  [273] = 94,
  [274] = 95,
  [275] = 97,
  [276] = 276,
  [277] = 172,
  [278] = 146,
  [279] = 104,
  [280] = 173,
  [281] = 98,
  [282] = 130,
  [283] = 283,
  [284] = 99,
  [285] = 126,
  [286] = 100,
  [287] = 174,
  [288] = 125,
  [289] = 261,
  [290] = 105,
  [291] = 260,
  [292] = 108,
  [293] = 109,
  [294] = 110,
  [295] = 120,
  [296] = 179,
  [297] = 221,
  [298] = 111,
  [299] = 116,
  [300] = 182,
  [301] = 276,
  [302] = 117,
  [303] = 255,
  [304] = 118,
  [305] = 119,
  [306] = 145,
  [307] = 188,
  [308] = 144,
  [309] = 283,
  [310] = 143,
  [311] = 142,
  [312] = 141,
  [313] = 124,
  [314] = 129,
  [315] = 122,
  [316] = 128,
  [317] = 121,
  [318] = 185,
  [319] = 319,
  [320] = 255,
  [321] = 321,
  [322] = 322,
  [323] = 319,
  [324] = 221,
  [325] = 260,
  [326] = 255,
  [327] = 322,
  [328] = 190,
  [329] = 329,
  [330] = 321,
  [331] = 331,
  [332] = 332,
  [333] = 332,
  [334] = 331,
  [335] = 335,
  [336] = 188,
  [337] = 337,
  [338] = 338,
  [339] = 338,
  [340] = 340,
  [341] = 338,
  [342] = 340,
  [343] = 338,
  [344] = 340,
  [345] = 345,
  [346] = 338,
  [347] = 340,
  [348] = 340,
  [349] = 345,
  [350] = 350,
  [351] = 338,
  [352] = 340,
  [353] = 338,
  [354] = 338,
  [355] = 340,
  [356] = 350,
  [357] = 357,
  [358] = 340,
  [359] = 260,
  [360] = 338,
  [361] = 340,
  [362] = 338,
  [363] = 340,
  [364] = 338,
  [365] = 221,
  [366] = 340,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 367,
  [374] = 370,
  [375] = 375,
  [376] = 371,
  [377] = 377,
  [378] = 369,
  [379] = 375,
  [380] = 372,
  [381] = 367,
  [382] = 371,
  [383] = 370,
  [384] = 375,
  [385] = 369,
  [386] = 372,
  [387] = 369,
  [388] = 375,
  [389] = 372,
  [390] = 367,
  [391] = 371,
  [392] = 367,
  [393] = 371,
  [394] = 370,
  [395] = 370,
  [396] = 375,
  [397] = 397,
  [398] = 369,
  [399] = 369,
  [400] = 371,
  [401] = 372,
  [402] = 369,
  [403] = 403,
  [404] = 367,
  [405] = 372,
  [406] = 370,
  [407] = 375,
  [408] = 408,
  [409] = 370,
  [410] = 367,
  [411] = 369,
  [412] = 372,
  [413] = 372,
  [414] = 367,
  [415] = 372,
  [416] = 416,
  [417] = 408,
  [418] = 371,
  [419] = 371,
  [420] = 420,
  [421] = 375,
  [422] = 370,
  [423] = 367,
  [424] = 369,
  [425] = 370,
  [426] = 371,
  [427] = 372,
  [428] = 428,
  [429] = 369,
  [430] = 370,
  [431] = 375,
  [432] = 370,
  [433] = 433,
  [434] = 367,
  [435] = 375,
  [436] = 369,
  [437] = 397,
  [438] = 372,
  [439] = 371,
  [440] = 375,
  [441] = 375,
  [442] = 367,
  [443] = 371,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 447,
  [449] = 449,
  [450] = 450,
  [451] = 447,
  [452] = 450,
  [453] = 453,
  [454] = 454,
  [455] = 444,
  [456] = 449,
  [457] = 450,
  [458] = 458,
  [459] = 459,
  [460] = 447,
  [461] = 461,
  [462] = 447,
  [463] = 444,
  [464] = 444,
  [465] = 465,
  [466] = 449,
  [467] = 444,
  [468] = 468,
  [469] = 454,
  [470] = 449,
  [471] = 444,
  [472] = 450,
  [473] = 447,
  [474] = 447,
  [475] = 444,
  [476] = 449,
  [477] = 477,
  [478] = 450,
  [479] = 450,
  [480] = 447,
  [481] = 444,
  [482] = 482,
  [483] = 450,
  [484] = 444,
  [485] = 447,
  [486] = 486,
  [487] = 449,
  [488] = 488,
  [489] = 488,
  [490] = 450,
  [491] = 491,
  [492] = 446,
  [493] = 449,
  [494] = 494,
  [495] = 447,
  [496] = 449,
  [497] = 450,
  [498] = 449,
  [499] = 450,
  [500] = 449,
  [501] = 501,
  [502] = 447,
  [503] = 503,
  [504] = 450,
  [505] = 505,
  [506] = 444,
  [507] = 444,
  [508] = 449,
  [509] = 509,
  [510] = 491,
  [511] = 511,
  [512] = 503,
  [513] = 505,
  [514] = 514,
  [515] = 494,
  [516] = 459,
  [517] = 509,
  [518] = 505,
  [519] = 453,
  [520] = 520,
  [521] = 503,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 511,
  [526] = 526,
  [527] = 494,
  [528] = 528,
  [529] = 529,
  [530] = 528,
  [531] = 511,
  [532] = 532,
  [533] = 514,
  [534] = 520,
  [535] = 532,
  [536] = 524,
  [537] = 537,
  [538] = 511,
  [539] = 539,
  [540] = 539,
  [541] = 541,
  [542] = 537,
  [543] = 529,
  [544] = 544,
  [545] = 545,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 545,
  [550] = 550,
  [551] = 551,
  [552] = 547,
  [553] = 545,
  [554] = 554,
  [555] = 550,
  [556] = 546,
  [557] = 557,
  [558] = 558,
  [559] = 546,
  [560] = 550,
  [561] = 547,
  [562] = 545,
  [563] = 563,
  [564] = 547,
  [565] = 565,
  [566] = 545,
  [567] = 546,
  [568] = 550,
  [569] = 546,
  [570] = 547,
  [571] = 550,
  [572] = 545,
  [573] = 547,
  [574] = 545,
  [575] = 550,
  [576] = 546,
  [577] = 547,
  [578] = 547,
  [579] = 545,
  [580] = 546,
  [581] = 547,
  [582] = 550,
  [583] = 546,
  [584] = 545,
  [585] = 547,
  [586] = 551,
  [587] = 545,
  [588] = 546,
  [589] = 550,
  [590] = 550,
  [591] = 546,
  [592] = 592,
  [593] = 550,
  [594] = 550,
  [595] = 547,
  [596] = 546,
  [597] = 545,
  [598] = 598,
  [599] = 599,
  [600] = 600,
  [601] = 601,
  [602] = 602,
  [603] = 598,
  [604] = 602,
  [605] = 598,
  [606] = 602,
  [607] = 598,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 611,
  [614] = 614,
  [615] = 615,
  [616] = 612,
  [617] = 617,
  [618] = 618,
  [619] = 602,
  [620] = 602,
  [621] = 621,
  [622] = 598,
  [623] = 608,
  [624] = 618,
  [625] = 598,
  [626] = 598,
  [627] = 614,
  [628] = 598,
  [629] = 602,
  [630] = 602,
  [631] = 631,
  [632] = 600,
  [633] = 631,
  [634] = 598,
  [635] = 598,
  [636] = 602,
  [637] = 637,
  [638] = 609,
  [639] = 598,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 602,
  [644] = 602,
  [645] = 602,
  [646] = 640,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 647,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 617,
  [656] = 654,
  [657] = 599,
  [658] = 610,
  [659] = 601,
  [660] = 647,
  [661] = 647,
  [662] = 654,
  [663] = 637,
  [664] = 641,
  [665] = 665,
  [666] = 647,
  [667] = 654,
  [668] = 621,
  [669] = 647,
  [670] = 621,
  [671] = 599,
  [672] = 654,
  [673] = 654,
  [674] = 654,
  [675] = 654,
  [676] = 647,
  [677] = 677,
  [678] = 678,
  [679] = 647,
  [680] = 617,
  [681] = 654,
  [682] = 682,
  [683] = 683,
  [684] = 647,
  [685] = 685,
  [686] = 642,
  [687] = 687,
  [688] = 647,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 677,
  [695] = 654,
  [696] = 690,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 641,
  [702] = 702,
  [703] = 703,
  [704] = 685,
  [705] = 682,
  [706] = 706,
  [707] = 647,
  [708] = 654,
  [709] = 678,
  [710] = 700,
  [711] = 637,
  [712] = 665,
  [713] = 648,
  [714] = 615,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 716,
  [721] = 721,
  [722] = 649,
  [723] = 715,
  [724] = 724,
  [725] = 725,
  [726] = 717,
  [727] = 718,
  [728] = 653,
  [729] = 729,
  [730] = 652,
  [731] = 716,
  [732] = 721,
  [733] = 733,
  [734] = 717,
  [735] = 702,
  [736] = 736,
  [737] = 718,
  [738] = 738,
  [739] = 739,
  [740] = 649,
  [741] = 698,
  [742] = 742,
  [743] = 721,
  [744] = 652,
  [745] = 745,
  [746] = 721,
  [747] = 716,
  [748] = 736,
  [749] = 702,
  [750] = 718,
  [751] = 717,
  [752] = 687,
  [753] = 753,
  [754] = 745,
  [755] = 755,
  [756] = 719,
  [757] = 753,
  [758] = 755,
  [759] = 759,
  [760] = 755,
  [761] = 755,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 755,
  [766] = 755,
  [767] = 724,
  [768] = 719,
  [769] = 769,
  [770] = 733,
  [771] = 771,
  [772] = 733,
  [773] = 755,
  [774] = 753,
  [775] = 703,
  [776] = 706,
  [777] = 729,
  [778] = 742,
  [779] = 771,
  [780] = 780,
  [781] = 755,
  [782] = 689,
  [783] = 683,
  [784] = 755,
  [785] = 785,
  [786] = 755,
  [787] = 725,
  [788] = 788,
  [789] = 738,
  [790] = 788,
  [791] = 780,
  [792] = 755,
  [793] = 769,
  [794] = 764,
  [795] = 755,
  [796] = 724,
  [797] = 785,
  [798] = 763,
  [799] = 759,
  [800] = 762,
  [801] = 769,
  [802] = 706,
  [803] = 803,
  [804] = 762,
  [805] = 763,
  [806] = 764,
  [807] = 771,
  [808] = 780,
  [809] = 809,
  [810] = 788,
  [811] = 785,
  [812] = 812,
  [813] = 809,
  [814] = 683,
  [815] = 689,
  [816] = 803,
  [817] = 809,
  [818] = 759,
  [819] = 703,
  [820] = 820,
  [821] = 788,
  [822] = 759,
  [823] = 762,
  [824] = 763,
  [825] = 764,
  [826] = 769,
  [827] = 771,
  [828] = 780,
  [829] = 785,
  [830] = 683,
  [831] = 689,
  [832] = 706,
  [833] = 703,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 837,
  [839] = 836,
  [840] = 834,
  [841] = 835,
  [842] = 759,
  [843] = 703,
  [844] = 683,
  [845] = 845,
  [846] = 846,
  [847] = 771,
  [848] = 848,
  [849] = 849,
  [850] = 763,
  [851] = 762,
  [852] = 852,
  [853] = 853,
  [854] = 845,
  [855] = 855,
  [856] = 856,
  [857] = 780,
  [858] = 858,
  [859] = 859,
  [860] = 689,
  [861] = 861,
  [862] = 785,
  [863] = 706,
  [864] = 703,
  [865] = 861,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 689,
  [870] = 762,
  [871] = 763,
  [872] = 771,
  [873] = 706,
  [874] = 866,
  [875] = 780,
  [876] = 785,
  [877] = 683,
  [878] = 846,
  [879] = 759,
  [880] = 880,
  [881] = 683,
  [882] = 882,
  [883] = 883,
  [884] = 880,
  [885] = 763,
  [886] = 883,
  [887] = 887,
  [888] = 771,
  [889] = 889,
  [890] = 890,
  [891] = 689,
  [892] = 892,
  [893] = 683,
  [894] = 894,
  [895] = 895,
  [896] = 780,
  [897] = 897,
  [898] = 785,
  [899] = 887,
  [900] = 900,
  [901] = 706,
  [902] = 703,
  [903] = 785,
  [904] = 683,
  [905] = 852,
  [906] = 689,
  [907] = 853,
  [908] = 706,
  [909] = 703,
  [910] = 759,
  [911] = 889,
  [912] = 855,
  [913] = 762,
  [914] = 759,
  [915] = 915,
  [916] = 916,
  [917] = 917,
  [918] = 763,
  [919] = 771,
  [920] = 762,
  [921] = 780,
  [922] = 922,
  [923] = 868,
  [924] = 867,
  [925] = 780,
  [926] = 848,
  [927] = 887,
  [928] = 849,
  [929] = 922,
  [930] = 771,
  [931] = 917,
  [932] = 889,
  [933] = 892,
  [934] = 689,
  [935] = 895,
  [936] = 706,
  [937] = 894,
  [938] = 859,
  [939] = 785,
  [940] = 856,
  [941] = 858,
  [942] = 890,
  [943] = 703,
  [944] = 849,
  [945] = 759,
  [946] = 762,
  [947] = 763,
  [948] = 858,
  [949] = 949,
  [950] = 856,
  [951] = 859,
  [952] = 848,
  [953] = 763,
  [954] = 954,
  [955] = 759,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 706,
  [962] = 960,
  [963] = 958,
  [964] = 959,
  [965] = 703,
  [966] = 703,
  [967] = 759,
  [968] = 968,
  [969] = 969,
  [970] = 957,
  [971] = 971,
  [972] = 971,
  [973] = 973,
  [974] = 706,
  [975] = 975,
  [976] = 954,
  [977] = 762,
  [978] = 978,
  [979] = 969,
  [980] = 689,
  [981] = 683,
  [982] = 762,
  [983] = 771,
  [984] = 785,
  [985] = 780,
  [986] = 986,
  [987] = 689,
  [988] = 968,
  [989] = 989,
  [990] = 990,
  [991] = 771,
  [992] = 683,
  [993] = 897,
  [994] = 900,
  [995] = 973,
  [996] = 785,
  [997] = 989,
  [998] = 763,
  [999] = 975,
  [1000] = 780,
  [1001] = 978,
  [1002] = 915,
  [1003] = 916,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1011,
  [1014] = 1010,
  [1015] = 1011,
  [1016] = 1011,
  [1017] = 1017,
  [1018] = 1010,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1010,
  [1023] = 1010,
  [1024] = 1011,
  [1025] = 1011,
  [1026] = 1010,
  [1027] = 1011,
  [1028] = 1011,
  [1029] = 1029,
  [1030] = 1011,
  [1031] = 1010,
  [1032] = 1010,
  [1033] = 1010,
  [1034] = 1034,
  [1035] = 1011,
  [1036] = 1011,
  [1037] = 1010,
  [1038] = 1005,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1017,
  [1042] = 1012,
  [1043] = 1043,
  [1044] = 1009,
  [1045] = 1045,
  [1046] = 1004,
  [1047] = 1047,
  [1048] = 1019,
  [1049] = 1008,
  [1050] = 1007,
  [1051] = 1051,
  [1052] = 1040,
  [1053] = 1039,
  [1054] = 1054,
  [1055] = 1054,
  [1056] = 1047,
  [1057] = 1045,
  [1058] = 1010,
  [1059] = 1029,
  [1060] = 1034,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1065,
  [1066] = 1066,
  [1067] = 1067,
  [1068] = 1068,
  [1069] = 1067,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1068,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1076,
  [1078] = 1078,
  [1079] = 1078,
  [1080] = 1066,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1085,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1107,
  [1108] = 1085,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 1111,
  [1112] = 1096,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1097,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1118,
  [1119] = 1099,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1100,
  [1124] = 1104,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1127,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1097,
  [1136] = 1089,
  [1137] = 1099,
  [1138] = 1091,
  [1139] = 1104,
  [1140] = 1100,
  [1141] = 1102,
  [1142] = 1099,
  [1143] = 1097,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1104,
  [1147] = 1096,
  [1148] = 1100,
  [1149] = 1085,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 1153,
  [1154] = 1104,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1110,
  [1159] = 1100,
  [1160] = 1099,
  [1161] = 1081,
  [1162] = 1097,
  [1163] = 1163,
  [1164] = 1096,
  [1165] = 1085,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1168,
  [1169] = 1104,
  [1170] = 1100,
  [1171] = 1129,
  [1172] = 1172,
  [1173] = 1099,
  [1174] = 1097,
  [1175] = 1096,
  [1176] = 1176,
  [1177] = 1168,
  [1178] = 1102,
  [1179] = 1166,
  [1180] = 1085,
  [1181] = 1163,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1156,
  [1186] = 1100,
  [1187] = 1155,
  [1188] = 1134,
  [1189] = 1153,
  [1190] = 1152,
  [1191] = 1099,
  [1192] = 1192,
  [1193] = 1097,
  [1194] = 1104,
  [1195] = 1096,
  [1196] = 1085,
  [1197] = 1145,
  [1198] = 1198,
  [1199] = 1144,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1104,
  [1203] = 1100,
  [1204] = 1204,
  [1205] = 1099,
  [1206] = 1097,
  [1207] = 1096,
  [1208] = 1133,
  [1209] = 1085,
  [1210] = 1130,
  [1211] = 1104,
  [1212] = 1100,
  [1213] = 1099,
  [1214] = 1097,
  [1215] = 1096,
  [1216] = 1085,
  [1217] = 1128,
  [1218] = 1204,
  [1219] = 1117,
  [1220] = 1201,
  [1221] = 1200,
  [1222] = 1157,
  [1223] = 1116,
  [1224] = 1104,
  [1225] = 1100,
  [1226] = 1099,
  [1227] = 1087,
  [1228] = 1097,
  [1229] = 1090,
  [1230] = 1096,
  [1231] = 1085,
  [1232] = 1098,
  [1233] = 1184,
  [1234] = 1107,
  [1235] = 1103,
  [1236] = 1091,
  [1237] = 1101,
  [1238] = 1089,
  [1239] = 1088,
  [1240] = 1094,
  [1241] = 1083,
  [1242] = 1086,
  [1243] = 1126,
  [1244] = 1098,
  [1245] = 1125,
  [1246] = 1114,
  [1247] = 1118,
  [1248] = 1130,
  [1249] = 1104,
  [1250] = 1100,
  [1251] = 1168,
  [1252] = 1132,
  [1253] = 1166,
  [1254] = 1099,
  [1255] = 1097,
  [1256] = 1167,
  [1257] = 1176,
  [1258] = 1096,
  [1259] = 1127,
  [1260] = 1085,
  [1261] = 1182,
  [1262] = 1088,
  [1263] = 1263,
  [1264] = 1094,
  [1265] = 1265,
  [1266] = 1098,
  [1267] = 1122,
  [1268] = 1121,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1183,
  [1272] = 1265,
  [1273] = 1082,
  [1274] = 1096,
  [1275] = 1192,
  [1276] = 1182,
  [1277] = 1113,
  [1278] = 1120,
  [1279] = 1092,
  [1280] = 1280,
  [1281] = 1105,
  [1282] = 1111,
  [1283] = 1106,
  [1284] = 1263,
  [1285] = 1109,
};

static TSCharacterRange sym_word_character_set_1[] = {
  {'!', '$'}, {'&', '*'}, {',', ','}, {'0', '9'}, {';', '<'}, {'>', '?'}, {'E', 'E'}, {'[', '^'},
  {'`', 'b'}, {'f', 'f'}, {'n', 'n'}, {'r', 'r'}, {'t', 't'}, {'v', 'v'}, {'{', '~'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(107);
      ADVANCE_MAP(
        '!', 95,
        '"', 168,
        '#', 233,
        '$', 136,
        '%', 150,
        '&', 93,
        '\'', 169,
        '(', 138,
        ')', 200,
        '*', 156,
        '+', 154,
        ',', 133,
        '-', 121,
        '.', 185,
        '/', 155,
        ':', 166,
        ';', 167,
        '<', 151,
        '=', 123,
        '?', 152,
        '@', 149,
        '\\', 3,
        '^', 153,
        'e', 196,
        '{', 140,
        '|', 118,
        '}', 143,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(105);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\t', 201,
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '-', 194,
        '.', 185,
        '\\', 5,
      );
      if (('\n' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('/' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 2:
      if (lookahead == '\t') ADVANCE(202);
      if (lookahead == '#') ADVANCE(212);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(210);
      if (lookahead == '\\') ADVANCE(28);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(2);
      if (lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(207);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(45);
      if (lookahead == '\r') SKIP(45);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(54);
      if (lookahead == '\r') SKIP(54);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 5:
      if (lookahead == '\n') SKIP(1);
      if (lookahead == '\r') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(49);
      if (lookahead == '\r') SKIP(49);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 7:
      if (lookahead == '\n') SKIP(47);
      if (lookahead == '\r') SKIP(47);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 8:
      if (lookahead == '\n') ADVANCE(163);
      if (lookahead == '\r') ADVANCE(164);
      END_STATE();
    case 9:
      if (lookahead == '\n') ADVANCE(163);
      if (lookahead == '\r') ADVANCE(164);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 10:
      if (lookahead == '\n') ADVANCE(163);
      if (lookahead == '\r') ADVANCE(164);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(213);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '\n', 109,
        '\r', 109,
        '#', 145,
        '$', 136,
        '%', 150,
        '(', 139,
        '*', 156,
        '+', 154,
        '/', 155,
        '<', 151,
        '?', 152,
        '@', 149,
        '\\', 144,
        '^', 153,
        '{', 141,
        '\t', 144,
        0x0b, 144,
        '\f', 144,
        ' ', 144,
      );
      if (lookahead != 0) ADVANCE(146);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '\n', 109,
        '\r', 109,
        '#', 147,
        '$', 136,
        '%', 150,
        '(', 138,
        ')', 144,
        '*', 156,
        '+', 154,
        '/', 155,
        '<', 151,
        '?', 152,
        '@', 149,
        '\\', 144,
        '^', 153,
        '{', 142,
        '\t', 144,
        0x0b, 144,
        '\f', 144,
        ' ', 144,
      );
      if (lookahead != 0) ADVANCE(148);
      END_STATE();
    case 13:
      if (lookahead == '\n') SKIP(63);
      if (lookahead == '\r') SKIP(63);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 14:
      if (lookahead == '\n') SKIP(85);
      if (lookahead == '\r') ADVANCE(144);
      if (lookahead == '#') ADVANCE(147);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '%') ADVANCE(150);
      if (lookahead == '(') ADVANCE(138);
      if (lookahead == ')') ADVANCE(135);
      if (lookahead == '*') ADVANCE(156);
      if (lookahead == '+') ADVANCE(154);
      if (lookahead == ',') ADVANCE(134);
      if (lookahead == '/') ADVANCE(155);
      if (lookahead == '<') ADVANCE(151);
      if (lookahead == '?') ADVANCE(152);
      if (lookahead == '@') ADVANCE(149);
      if (lookahead == '\\') ADVANCE(144);
      if (lookahead == '^') ADVANCE(153);
      if (lookahead == '{') ADVANCE(142);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(144);
      if (lookahead != 0) ADVANCE(148);
      END_STATE();
    case 15:
      if (lookahead == '\n') ADVANCE(219);
      if (lookahead == '\r') ADVANCE(220);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (lookahead != 0) ADVANCE(227);
      END_STATE();
    case 16:
      if (lookahead == '\n') SKIP(82);
      if (lookahead == '\r') ADVANCE(144);
      if (lookahead == '#') ADVANCE(145);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '%') ADVANCE(150);
      if (lookahead == '(') ADVANCE(139);
      if (lookahead == '*') ADVANCE(156);
      if (lookahead == '+') ADVANCE(154);
      if (lookahead == '/') ADVANCE(155);
      if (lookahead == '<') ADVANCE(151);
      if (lookahead == '?') ADVANCE(152);
      if (lookahead == '@') ADVANCE(149);
      if (lookahead == '\\') ADVANCE(144);
      if (lookahead == '^') ADVANCE(153);
      if (lookahead == '{') ADVANCE(141);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(144);
      if (lookahead != 0) ADVANCE(146);
      END_STATE();
    case 17:
      if (lookahead == '\n') SKIP(82);
      if (lookahead == '\r') SKIP(82);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(213);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 18:
      if (lookahead == '\n') SKIP(86);
      if (lookahead == '\r') ADVANCE(144);
      if (lookahead == '#') ADVANCE(147);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '%') ADVANCE(150);
      if (lookahead == '(') ADVANCE(138);
      if (lookahead == ')') ADVANCE(135);
      if (lookahead == '*') ADVANCE(156);
      if (lookahead == '+') ADVANCE(154);
      if (lookahead == '/') ADVANCE(155);
      if (lookahead == '<') ADVANCE(151);
      if (lookahead == '?') ADVANCE(152);
      if (lookahead == '@') ADVANCE(149);
      if (lookahead == '\\') ADVANCE(144);
      if (lookahead == '^') ADVANCE(153);
      if (lookahead == '{') ADVANCE(142);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(144);
      if (lookahead != 0) ADVANCE(148);
      END_STATE();
    case 19:
      if (lookahead == '\n') ADVANCE(221);
      if (lookahead == '\r') ADVANCE(222);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (lookahead != 0) ADVANCE(227);
      END_STATE();
    case 20:
      if (lookahead == '\n') SKIP(56);
      if (lookahead == '\r') SKIP(56);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 21:
      if (lookahead == '\n') SKIP(55);
      if (lookahead == '\r') SKIP(55);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 22:
      if (lookahead == '\n') SKIP(66);
      if (lookahead == '\r') SKIP(66);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 23:
      if (lookahead == '\n') SKIP(64);
      if (lookahead == '\r') SKIP(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 24:
      if (lookahead == '\n') SKIP(61);
      if (lookahead == '\r') SKIP(61);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 25:
      if (lookahead == '\n') SKIP(67);
      if (lookahead == '\r') SKIP(67);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 26:
      if (lookahead == '\n') SKIP(53);
      if (lookahead == '\r') SKIP(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 27:
      if (lookahead == '\n') SKIP(81);
      if (lookahead == '\r') SKIP(81);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(213);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 28:
      if (lookahead == '\n') SKIP(2);
      if (lookahead == '\r') SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(213);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 29:
      if (lookahead == '\n') SKIP(69);
      if (lookahead == '\r') SKIP(69);
      END_STATE();
    case 30:
      if (lookahead == '\n') SKIP(73);
      if (lookahead == '\r') SKIP(73);
      END_STATE();
    case 31:
      if (lookahead == '\n') SKIP(68);
      if (lookahead == '\r') SKIP(68);
      if (lookahead != 0) ADVANCE(173);
      END_STATE();
    case 32:
      if (lookahead == '\n') SKIP(91);
      if (lookahead == '\r') SKIP(91);
      if (lookahead != 0) ADVANCE(173);
      END_STATE();
    case 33:
      if (lookahead == '\n') SKIP(77);
      if (lookahead == '\r') SKIP(77);
      END_STATE();
    case 34:
      if (lookahead == '\n') SKIP(77);
      if (lookahead == '#') ADVANCE(144);
      if (lookahead == '%') ADVANCE(150);
      if (lookahead == '(') ADVANCE(138);
      if (lookahead == '*') ADVANCE(156);
      if (lookahead == '+') ADVANCE(154);
      if (lookahead == '/') ADVANCE(155);
      if (lookahead == '<') ADVANCE(151);
      if (lookahead == '?') ADVANCE(152);
      if (lookahead == '@') ADVANCE(149);
      if (lookahead == '\\') ADVANCE(144);
      if (lookahead == '^') ADVANCE(153);
      if (lookahead == '{') ADVANCE(140);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(144);
      if (lookahead != 0) ADVANCE(144);
      END_STATE();
    case 35:
      if (lookahead == '\n') SKIP(76);
      if (lookahead == '\r') SKIP(76);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '\n', 203,
        '\r', 203,
        '#', 229,
        '\\', 37,
        'e', 41,
        '\t', 36,
        0x0b, 36,
        '\f', 36,
        ' ', 36,
      );
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 37:
      if (lookahead == '\n') ADVANCE(203);
      if (lookahead == '\r') ADVANCE(203);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 38:
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(205);
      if (lookahead == 'd') ADVANCE(39);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 39:
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(205);
      if (lookahead == 'e') ADVANCE(40);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 40:
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(205);
      if (lookahead == 'f') ADVANCE(130);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 41:
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(205);
      if (lookahead == 'n') ADVANCE(38);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 42:
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(205);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 43:
      if (lookahead == '\n') SKIP(79);
      if (lookahead == '\r') SKIP(79);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 44:
      if (lookahead == '\r') ADVANCE(228);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(226);
      if (lookahead != 0) ADVANCE(227);
      END_STATE();
    case 45:
      ADVANCE_MAP(
        '!', 95,
        '"', 168,
        '#', 233,
        '$', 136,
        '%', 157,
        '&', 93,
        '\'', 169,
        '(', 132,
        ')', 135,
        '*', 162,
        '+', 122,
        ',', 133,
        '-', 121,
        '.', 185,
        '/', 161,
        ':', 111,
        ';', 119,
        '<', 158,
        '=', 123,
        '?', 159,
        '@', 120,
        '\\', 3,
        '^', 160,
        'e', 196,
        '|', 118,
        '}', 143,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(45);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 46:
      ADVANCE_MAP(
        '!', 95,
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        '(', 138,
        ')', 200,
        '+', 174,
        ':', 111,
        '=', 123,
        '?', 175,
        '\\', 9,
        '\t', 117,
        ' ', 117,
      );
      if (('\n' <= lookahead && lookahead <= '\r')) SKIP(47);
      if (('%' <= lookahead && lookahead <= '*') ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 47:
      ADVANCE_MAP(
        '!', 95,
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        '+', 174,
        ':', 111,
        '=', 123,
        '?', 175,
        '\\', 7,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(47);
      if (lookahead == '%' ||
          lookahead == '*' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 48:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '%', 157,
        '\'', 169,
        ')', 200,
        '*', 162,
        '+', 122,
        '/', 161,
        '<', 158,
        '?', 159,
        '@', 120,
        '\\', 6,
        '^', 160,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(49);
      if (('-' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 49:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '%', 157,
        '\'', 169,
        '*', 162,
        '+', 122,
        '/', 161,
        '<', 158,
        '?', 159,
        '@', 120,
        '\\', 6,
        '^', 160,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(49);
      if (('-' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 50:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        '(', 138,
        ')', 200,
        ':', 112,
        '\\', 9,
        '\t', 117,
        ' ', 117,
      );
      if (('\n' <= lookahead && lookahead <= '\r')) SKIP(56);
      if (('%' <= lookahead && lookahead <= '+') ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 51:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        '(', 138,
        ':', 112,
        ';', 119,
        '\\', 9,
        '|', 118,
        '\t', 117,
        ' ', 117,
        '\n', 109,
        '\r', 109,
      );
      if (lookahead == 0x0b ||
          lookahead == '\f') SKIP(55);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 52:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        '(', 132,
        ')', 200,
        ':', 112,
        '\\', 26,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(53);
      if (('%' <= lookahead && lookahead <= '+') ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 53:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        '(', 132,
        ':', 112,
        '\\', 26,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(53);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 54:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        ')', 135,
        ',', 133,
        '-', 194,
        '.', 185,
        ':', 112,
        '\\', 4,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(54);
      if (lookahead == '%' ||
          ('*' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 55:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        ':', 112,
        ';', 119,
        '\\', 21,
        '|', 118,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(55);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 56:
      if (lookahead == '"') ADVANCE(168);
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '&') ADVANCE(93);
      if (lookahead == '\'') ADVANCE(169);
      if (lookahead == ':') ADVANCE(112);
      if (lookahead == '\\') ADVANCE(20);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(56);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 57:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '(', 138,
        ')', 135,
        ',', 133,
        ':', 110,
        '=', 123,
        '\\', 24,
        '}', 143,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(61);
      if (lookahead == '%' ||
          ('*' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 58:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '(', 138,
        '+', 174,
        ':', 113,
        ';', 119,
        '=', 123,
        '?', 175,
        '\\', 9,
        '|', 118,
        '\t', 117,
        ' ', 117,
        '\n', 109,
        '\r', 109,
      );
      if (lookahead == 0x0b ||
          lookahead == '\f') SKIP(63);
      if (lookahead == '%' ||
          lookahead == '*' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 59:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '(', 138,
        ':', 110,
        ';', 119,
        '\\', 23,
        '|', 118,
        '\n', 109,
        '\r', 109,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(64);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 60:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '(', 138,
        ':', 165,
        ';', 167,
        '\\', 25,
        '\n', 109,
        '\r', 109,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(67);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 61:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        ')', 135,
        ',', 133,
        ':', 110,
        '=', 123,
        '\\', 24,
        '}', 143,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(61);
      if (lookahead == '%' ||
          ('*' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 62:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '+', 174,
        ':', 113,
        ';', 119,
        '=', 123,
        '?', 175,
        '\\', 13,
        '|', 118,
        '\n', 109,
        '\r', 109,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(63);
      if (lookahead == '%' ||
          lookahead == '*' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 63:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '+', 174,
        ':', 113,
        ';', 119,
        '=', 123,
        '?', 175,
        '\\', 13,
        '|', 118,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(63);
      if (lookahead == '%' ||
          lookahead == '*' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 64:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        ':', 110,
        ';', 119,
        '\\', 23,
        '|', 118,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(64);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 65:
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        ';', 119,
        '\\', 22,
        '|', 118,
        '\t', 117,
        ' ', 117,
        '\n', 109,
        '\r', 109,
      );
      if (lookahead == 0x0b ||
          lookahead == '\f') SKIP(66);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 66:
      if (lookahead == '"') ADVANCE(168);
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '\'') ADVANCE(169);
      if (lookahead == ';') ADVANCE(119);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead == '|') ADVANCE(118);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(66);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 67:
      if (lookahead == '"') ADVANCE(168);
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '\'') ADVANCE(169);
      if (lookahead == '\\') ADVANCE(25);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(67);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 68:
      if (lookahead == '"') ADVANCE(168);
      if (lookahead == '#') ADVANCE(172);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '\\') ADVANCE(31);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(68);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(170);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(173);
      END_STATE();
    case 69:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == ')') ADVANCE(135);
      if (lookahead == ',') ADVANCE(133);
      if (lookahead == '/') ADVANCE(92);
      if (lookahead == '\\') SKIP(29);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(69);
      END_STATE();
    case 70:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(92);
      if (lookahead == '\\') ADVANCE(8);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(73);
      END_STATE();
    case 71:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(92);
      if (lookahead == '\\') ADVANCE(8);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(73);
      END_STATE();
    case 72:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(92);
      if (lookahead == '\\') SKIP(30);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(73);
      END_STATE();
    case 73:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(92);
      if (lookahead == '\\') SKIP(30);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(73);
      END_STATE();
    case 74:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '+') ADVANCE(97);
      if (lookahead == ':') ADVANCE(94);
      if (lookahead == '=') ADVANCE(123);
      if (lookahead == '?') ADVANCE(98);
      if (lookahead == '\\') SKIP(35);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(117);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(109);
      if (lookahead == 0x0b ||
          lookahead == '\f') SKIP(76);
      END_STATE();
    case 75:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '+') ADVANCE(97);
      if (lookahead == ':') ADVANCE(94);
      if (lookahead == '=') ADVANCE(123);
      if (lookahead == '?') ADVANCE(98);
      if (lookahead == '\\') SKIP(35);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(117);
      if (('\n' <= lookahead && lookahead <= '\r')) SKIP(76);
      END_STATE();
    case 76:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '+') ADVANCE(97);
      if (lookahead == ':') ADVANCE(94);
      if (lookahead == '=') ADVANCE(123);
      if (lookahead == '?') ADVANCE(98);
      if (lookahead == '\\') SKIP(35);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(76);
      END_STATE();
    case 77:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '\\') SKIP(33);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(77);
      END_STATE();
    case 78:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '\\') ADVANCE(43);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(117);
      if (('\n' <= lookahead && lookahead <= '\r')) SKIP(79);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 79:
      if (lookahead == '#') ADVANCE(233);
      if (lookahead == '\\') ADVANCE(43);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(79);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 80:
      ADVANCE_MAP(
        '#', 212,
        '$', 136,
        '+', 122,
        '-', 121,
        '/', 210,
        '@', 120,
        '\\', 27,
        '\n', 108,
        '\r', 108,
        '\t', 208,
        0x0b, 208,
        '\f', 208,
        ' ', 208,
      );
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 81:
      if (lookahead == '#') ADVANCE(212);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '+') ADVANCE(122);
      if (lookahead == '-') ADVANCE(121);
      if (lookahead == '/') ADVANCE(210);
      if (lookahead == '@') ADVANCE(120);
      if (lookahead == '\\') ADVANCE(27);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(81);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(208);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 82:
      if (lookahead == '#') ADVANCE(212);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(210);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(82);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(209);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 83:
      ADVANCE_MAP(
        '#', 212,
        '$', 136,
        '/', 210,
        '\\', 10,
        '\n', 109,
        '\r', 109,
        '\t', 209,
        0x0b, 209,
        '\f', 209,
        ' ', 209,
      );
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 84:
      if (lookahead == '#') ADVANCE(212);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(210);
      if (lookahead == '\\') ADVANCE(10);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(82);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(209);
      if (lookahead != 0) ADVANCE(214);
      END_STATE();
    case 85:
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == ')') ADVANCE(135);
      if (lookahead == ',') ADVANCE(134);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(15);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(85);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(219);
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 86:
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == ')') ADVANCE(135);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(19);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(86);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(221);
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 87:
      ADVANCE_MAP(
        '#', 225,
        '$', 136,
        '/', 223,
        '\\', 19,
        '\t', 117,
        ' ', 117,
        '\n', 109,
        '\r', 109,
        0x0b, 221,
        '\f', 221,
      );
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 88:
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(19);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(117);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(90);
      if (lookahead == 0x0b ||
          lookahead == '\f') ADVANCE(221);
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 89:
      ADVANCE_MAP(
        '#', 225,
        '$', 136,
        '/', 223,
        '\\', 19,
        '\n', 109,
        '\r', 109,
        '\t', 221,
        0x0b, 221,
        '\f', 221,
        ' ', 221,
      );
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 90:
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(19);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(90);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(221);
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 91:
      if (lookahead == '#') ADVANCE(172);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '\'') ADVANCE(169);
      if (lookahead == '\\') ADVANCE(32);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(91);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(171);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead)) ADVANCE(173);
      END_STATE();
    case 92:
      if (lookahead == '/') ADVANCE(215);
      END_STATE();
    case 93:
      if (lookahead == ':') ADVANCE(114);
      END_STATE();
    case 94:
      if (lookahead == ':') ADVANCE(96);
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 95:
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 96:
      if (lookahead == '=') ADVANCE(125);
      END_STATE();
    case 97:
      if (lookahead == '=') ADVANCE(127);
      END_STATE();
    case 98:
      if (lookahead == '=') ADVANCE(126);
      END_STATE();
    case 99:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(199);
      END_STATE();
    case 100:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(101);
      if (set_contains(sym_word_character_set_1, 15, lookahead)) ADVANCE(199);
      END_STATE();
    case 101:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(99);
      END_STATE();
    case 102:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(213);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(214);
      END_STATE();
    case 103:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(173);
      END_STATE();
    case 104:
      if (eof) ADVANCE(107);
      ADVANCE_MAP(
        '\t', 201,
        '"', 168,
        '#', 233,
        '$', 136,
        '\'', 169,
        '-', 194,
        '.', 185,
        '\\', 5,
      );
      if (('\n' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(104);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('/' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 105:
      if (eof) ADVANCE(107);
      ADVANCE_MAP(
        '!', 95,
        '"', 168,
        '#', 233,
        '$', 136,
        '%', 157,
        '&', 93,
        '\'', 169,
        '(', 132,
        ')', 135,
        '*', 162,
        '+', 122,
        ',', 133,
        '-', 121,
        '.', 185,
        '/', 161,
        ':', 111,
        ';', 119,
        '<', 158,
        '=', 123,
        '?', 159,
        '@', 120,
        '\\', 3,
        '^', 160,
        'e', 196,
        '|', 118,
        '}', 143,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(105);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 106:
      if (eof) ADVANCE(107);
      ADVANCE_MAP(
        '"', 168,
        '#', 233,
        '$', 136,
        '&', 93,
        '\'', 169,
        ')', 135,
        ',', 133,
        '-', 194,
        '.', 185,
        ':', 112,
        '\\', 4,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(106);
      if (lookahead == '%' ||
          ('*' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(aux_sym__thing_token1);
      if (lookahead == '+') ADVANCE(122);
      if (lookahead == '-') ADVANCE(121);
      if (lookahead == '@') ADVANCE(120);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(108);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(aux_sym__thing_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(109);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(116);
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(115);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(96);
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_AMP_COLON);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      if (lookahead == '=') ADVANCE(125);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(aux_sym__ordinary_rule_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(117);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_COLON_COLON_EQ);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_QMARK_EQ);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_DOTRECIPEPREFIX);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_endef);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_DASHinclude);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_COMMA);
      if (lookahead == '\\') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '$') ADVANCE(137);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_DOLLAR_DOLLAR);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      if (lookahead == '\\') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '\\') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '\\') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(aux_sym_variable_reference_token1);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(aux_sym_variable_reference_token1);
      if (lookahead == '\\') ADVANCE(231);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(212);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(aux_sym_variable_reference_token1);
      if (lookahead == '\\') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(aux_sym_variable_reference_token1);
      if (lookahead == '\\') ADVANCE(230);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(225);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(aux_sym_variable_reference_token1);
      if (lookahead == '\\') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_AT2);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_PLUS2);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_PERCENT2);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_LT2);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_QMARK2);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_CARET2);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_SLASH2);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_STAR2);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(aux_sym_list_token1);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(aux_sym_list_token1);
      if (lookahead == '\n') ADVANCE(163);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_COLON2);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == ':') ADVANCE(116);
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_SEMI2);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(aux_sym__string_token1);
      if (lookahead == '"') ADVANCE(168);
      if (lookahead == '#') ADVANCE(172);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '\\') ADVANCE(31);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(68);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(170);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(173);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(aux_sym__string_token1);
      if (lookahead == '#') ADVANCE(172);
      if (lookahead == '$') ADVANCE(136);
      if (lookahead == '\'') ADVANCE(169);
      if (lookahead == '\\') ADVANCE(32);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(91);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(171);
      if (lookahead != 0 &&
          (lookahead < '"' || '$' < lookahead)) ADVANCE(173);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(aux_sym__string_token1);
      if (lookahead == '\\') ADVANCE(232);
      if (lookahead == '\r' ||
          lookahead == '"' ||
          lookahead == '$' ||
          lookahead == '\'') ADVANCE(233);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(172);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(aux_sym__string_token1);
      if (lookahead == '\\') ADVANCE(103);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '"' &&
          lookahead != '$' &&
          lookahead != '\'') ADVANCE(173);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '=') ADVANCE(127);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '=') ADVANCE(126);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'C') ADVANCE(181);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E') ADVANCE(176);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E') ADVANCE(180);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'E') ADVANCE(184);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'F') ADVANCE(182);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'I') ADVANCE(183);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'I') ADVANCE(187);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'P') ADVANCE(179);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'P') ADVANCE(186);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'R') ADVANCE(177);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'R') ADVANCE(178);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == 'X') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'c') ADVANCE(195);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'd') ADVANCE(191);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'd') ADVANCE(192);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'e') ADVANCE(193);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'e') ADVANCE(131);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'f') ADVANCE(130);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'i') ADVANCE(197);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'l') ADVANCE(198);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'n') ADVANCE(189);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'n') ADVANCE(188);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == 'u') ADVANCE(190);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(sym_word);
      if (lookahead == '\\') ADVANCE(100);
      if (lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '9') ||
          ('?' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(199);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_RPAREN2);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(sym__recipeprefix);
      if (lookahead == '\t') ADVANCE(201);
      if (lookahead == '\\') ADVANCE(5);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym__recipeprefix);
      if (lookahead == '\t') ADVANCE(202);
      if (lookahead == '\\') ADVANCE(28);
      if (lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(207);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym__rawline);
      ADVANCE_MAP(
        '\n', 203,
        '\r', 203,
        '#', 229,
        '\\', 37,
        'e', 41,
        '\t', 36,
        0x0b, 36,
        '\f', 36,
        ' ', 36,
      );
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(sym__rawline);
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(204);
      if (lookahead != 0) ADVANCE(229);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym__rawline);
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(205);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(sym__rawline);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(206);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      if (lookahead == '\t') ADVANCE(202);
      if (lookahead == '#') ADVANCE(212);
      if (lookahead == '/') ADVANCE(210);
      if (lookahead == '\\') ADVANCE(28);
      if (lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(207);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '#' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      ADVANCE_MAP(
        '#', 212,
        '+', 122,
        '-', 121,
        '/', 210,
        '@', 120,
        '\\', 27,
        '\t', 208,
        0x0b, 208,
        '\f', 208,
        ' ', 208,
      );
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '#' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      if (lookahead == '#') ADVANCE(212);
      if (lookahead == '/') ADVANCE(210);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(209);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '#' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      if (lookahead == '/') ADVANCE(216);
      if (lookahead == '\\') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      if (lookahead == '\\') ADVANCE(231);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(212);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      if (lookahead == '\\') ADVANCE(231);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(212);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      if (lookahead == '\\') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(214);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(aux_sym__shell_text_without_split_token1);
      if (lookahead == '\\') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead == '\\') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$') ADVANCE(214);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead == '\\') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '\n') ADVANCE(227);
      if (lookahead == '\\') ADVANCE(230);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(225);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == ',') ADVANCE(134);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(15);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(219);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '#' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == ',') ADVANCE(134);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(15);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(219);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '#' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(19);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(221);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '#' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '#') ADVANCE(225);
      if (lookahead == '/') ADVANCE(223);
      if (lookahead == '\\') ADVANCE(19);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(221);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '#' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '/') ADVANCE(217);
      if (lookahead == '\\') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '\\') ADVANCE(230);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(225);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(225);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '\\') ADVANCE(230);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(225);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '\\') ADVANCE(44);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(227);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '\\') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(aux_sym_text_token1);
      if (lookahead == '\\') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '$' &&
          lookahead != '(' &&
          lookahead != ')') ADVANCE(227);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(206);
      if (lookahead == '\r') ADVANCE(204);
      if (lookahead != 0) ADVANCE(229);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(227);
      if (lookahead == '\r') ADVANCE(218);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(224);
      if (lookahead != 0) ADVANCE(225);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(233);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(211);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(212);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(233);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(172);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(233);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'D') ADVANCE(1);
      if (lookahead == 'F') ADVANCE(2);
      if (lookahead == 'V') ADVANCE(3);
      if (lookahead == '\\') SKIP(4);
      if (lookahead == 'a') ADVANCE(5);
      if (lookahead == 'b') ADVANCE(6);
      if (lookahead == 'c') ADVANCE(7);
      if (lookahead == 'd') ADVANCE(8);
      if (lookahead == 'e') ADVANCE(9);
      if (lookahead == 'f') ADVANCE(10);
      if (lookahead == 'i') ADVANCE(11);
      if (lookahead == 'j') ADVANCE(12);
      if (lookahead == 'l') ADVANCE(13);
      if (lookahead == 'n') ADVANCE(14);
      if (lookahead == 'o') ADVANCE(15);
      if (lookahead == 'p') ADVANCE(16);
      if (lookahead == 'r') ADVANCE(17);
      if (lookahead == 's') ADVANCE(18);
      if (lookahead == 'u') ADVANCE(19);
      if (lookahead == 'v') ADVANCE(20);
      if (lookahead == 'w') ADVANCE(21);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      END_STATE();
    case 1:
      ACCEPT_TOKEN(anon_sym_D);
      END_STATE();
    case 2:
      ACCEPT_TOKEN(anon_sym_F);
      END_STATE();
    case 3:
      if (lookahead == 'P') ADVANCE(23);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(22);
      if (lookahead == '\r') SKIP(24);
      END_STATE();
    case 5:
      if (lookahead == 'b') ADVANCE(25);
      if (lookahead == 'd') ADVANCE(26);
      if (lookahead == 'n') ADVANCE(27);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(28);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(29);
      END_STATE();
    case 8:
      if (lookahead == 'e') ADVANCE(30);
      if (lookahead == 'i') ADVANCE(31);
      END_STATE();
    case 9:
      if (lookahead == 'l') ADVANCE(32);
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 'r') ADVANCE(34);
      if (lookahead == 'v') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(36);
      END_STATE();
    case 10:
      if (lookahead == 'i') ADVANCE(37);
      if (lookahead == 'l') ADVANCE(38);
      if (lookahead == 'o') ADVANCE(39);
      END_STATE();
    case 11:
      if (lookahead == 'f') ADVANCE(40);
      if (lookahead == 'n') ADVANCE(41);
      END_STATE();
    case 12:
      if (lookahead == 'o') ADVANCE(42);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(43);
      END_STATE();
    case 14:
      if (lookahead == 'o') ADVANCE(44);
      END_STATE();
    case 15:
      if (lookahead == 'r') ADVANCE(45);
      if (lookahead == 'v') ADVANCE(46);
      END_STATE();
    case 16:
      if (lookahead == 'a') ADVANCE(47);
      if (lookahead == 'r') ADVANCE(48);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(49);
      END_STATE();
    case 18:
      if (lookahead == 'h') ADVANCE(50);
      if (lookahead == 'i') ADVANCE(51);
      if (lookahead == 'o') ADVANCE(52);
      if (lookahead == 't') ADVANCE(53);
      if (lookahead == 'u') ADVANCE(54);
      END_STATE();
    case 19:
      if (lookahead == 'n') ADVANCE(55);
      END_STATE();
    case 20:
      if (lookahead == 'a') ADVANCE(56);
      if (lookahead == 'p') ADVANCE(57);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(58);
      if (lookahead == 'i') ADVANCE(59);
      if (lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 22:
      if (lookahead == 'V') ADVANCE(3);
      if (lookahead == '\\') SKIP(4);
      if (lookahead == 'd') ADVANCE(61);
      if (lookahead == 'e') ADVANCE(62);
      if (lookahead == 'i') ADVANCE(63);
      if (lookahead == 'o') ADVANCE(64);
      if (lookahead == 'p') ADVANCE(65);
      if (lookahead == 's') ADVANCE(66);
      if (lookahead == 'u') ADVANCE(19);
      if (lookahead == 'v') ADVANCE(67);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      END_STATE();
    case 23:
      if (lookahead == 'A') ADVANCE(68);
      END_STATE();
    case 24:
      if (lookahead == 'V') ADVANCE(3);
      if (lookahead == '\\') SKIP(4);
      if (lookahead == 'd') ADVANCE(61);
      if (lookahead == 'e') ADVANCE(62);
      if (lookahead == 'i') ADVANCE(63);
      if (lookahead == 'o') ADVANCE(64);
      if (lookahead == 'p') ADVANCE(65);
      if (lookahead == 's') ADVANCE(66);
      if (lookahead == 'u') ADVANCE(19);
      if (lookahead == 'v') ADVANCE(67);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      END_STATE();
    case 25:
      if (lookahead == 's') ADVANCE(69);
      END_STATE();
    case 26:
      if (lookahead == 'd') ADVANCE(70);
      END_STATE();
    case 27:
      if (lookahead == 'd') ADVANCE(71);
      END_STATE();
    case 28:
      if (lookahead == 's') ADVANCE(72);
      END_STATE();
    case 29:
      if (lookahead == 'l') ADVANCE(73);
      END_STATE();
    case 30:
      if (lookahead == 'f') ADVANCE(74);
      END_STATE();
    case 31:
      if (lookahead == 'r') ADVANCE(75);
      END_STATE();
    case 32:
      if (lookahead == 's') ADVANCE(76);
      END_STATE();
    case 33:
      if (lookahead == 'd') ADVANCE(77);
      END_STATE();
    case 34:
      if (lookahead == 'r') ADVANCE(78);
      END_STATE();
    case 35:
      if (lookahead == 'a') ADVANCE(79);
      END_STATE();
    case 36:
      if (lookahead == 'p') ADVANCE(80);
      END_STATE();
    case 37:
      if (lookahead == 'l') ADVANCE(81);
      if (lookahead == 'n') ADVANCE(82);
      if (lookahead == 'r') ADVANCE(83);
      END_STATE();
    case 38:
      if (lookahead == 'a') ADVANCE(84);
      END_STATE();
    case 39:
      if (lookahead == 'r') ADVANCE(85);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_if);
      if (lookahead == 'd') ADVANCE(86);
      if (lookahead == 'e') ADVANCE(87);
      if (lookahead == 'n') ADVANCE(88);
      END_STATE();
    case 41:
      if (lookahead == 'c') ADVANCE(89);
      if (lookahead == 'f') ADVANCE(90);
      END_STATE();
    case 42:
      if (lookahead == 'i') ADVANCE(91);
      END_STATE();
    case 43:
      if (lookahead == 's') ADVANCE(92);
      END_STATE();
    case 44:
      if (lookahead == 't') ADVANCE(93);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == 'i') ADVANCE(94);
      END_STATE();
    case 46:
      if (lookahead == 'e') ADVANCE(95);
      END_STATE();
    case 47:
      if (lookahead == 't') ADVANCE(96);
      END_STATE();
    case 48:
      if (lookahead == 'i') ADVANCE(97);
      END_STATE();
    case 49:
      if (lookahead == 'a') ADVANCE(98);
      END_STATE();
    case 50:
      if (lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 51:
      if (lookahead == 'n') ADVANCE(100);
      END_STATE();
    case 52:
      if (lookahead == 'r') ADVANCE(101);
      END_STATE();
    case 53:
      if (lookahead == 'r') ADVANCE(102);
      END_STATE();
    case 54:
      if (lookahead == 'b') ADVANCE(103);
      if (lookahead == 'f') ADVANCE(104);
      END_STATE();
    case 55:
      if (lookahead == 'd') ADVANCE(105);
      if (lookahead == 'e') ADVANCE(106);
      END_STATE();
    case 56:
      if (lookahead == 'l') ADVANCE(107);
      END_STATE();
    case 57:
      if (lookahead == 'a') ADVANCE(108);
      END_STATE();
    case 58:
      if (lookahead == 'r') ADVANCE(109);
      END_STATE();
    case 59:
      if (lookahead == 'l') ADVANCE(110);
      END_STATE();
    case 60:
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 61:
      if (lookahead == 'e') ADVANCE(30);
      END_STATE();
    case 62:
      if (lookahead == 'l') ADVANCE(32);
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 'x') ADVANCE(36);
      END_STATE();
    case 63:
      if (lookahead == 'f') ADVANCE(112);
      if (lookahead == 'n') ADVANCE(113);
      END_STATE();
    case 64:
      if (lookahead == 'v') ADVANCE(46);
      END_STATE();
    case 65:
      if (lookahead == 'r') ADVANCE(48);
      END_STATE();
    case 66:
      if (lookahead == 'h') ADVANCE(50);
      if (lookahead == 'i') ADVANCE(51);
      END_STATE();
    case 67:
      if (lookahead == 'p') ADVANCE(57);
      END_STATE();
    case 68:
      if (lookahead == 'T') ADVANCE(114);
      END_STATE();
    case 69:
      if (lookahead == 'p') ADVANCE(115);
      END_STATE();
    case 70:
      if (lookahead == 'p') ADVANCE(116);
      if (lookahead == 's') ADVANCE(117);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(118);
      END_STATE();
    case 73:
      if (lookahead == 'l') ADVANCE(119);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(120);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_dir);
      END_STATE();
    case 76:
      if (lookahead == 'e') ADVANCE(121);
      END_STATE();
    case 77:
      if (lookahead == 'i') ADVANCE(122);
      END_STATE();
    case 78:
      if (lookahead == 'o') ADVANCE(123);
      END_STATE();
    case 79:
      if (lookahead == 'l') ADVANCE(124);
      END_STATE();
    case 80:
      if (lookahead == 'o') ADVANCE(125);
      END_STATE();
    case 81:
      if (lookahead == 'e') ADVANCE(126);
      if (lookahead == 't') ADVANCE(127);
      END_STATE();
    case 82:
      if (lookahead == 'd') ADVANCE(128);
      END_STATE();
    case 83:
      if (lookahead == 's') ADVANCE(129);
      END_STATE();
    case 84:
      if (lookahead == 'v') ADVANCE(130);
      END_STATE();
    case 85:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(132);
      END_STATE();
    case 87:
      if (lookahead == 'q') ADVANCE(133);
      END_STATE();
    case 88:
      if (lookahead == 'd') ADVANCE(134);
      if (lookahead == 'e') ADVANCE(135);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(136);
      END_STATE();
    case 90:
      if (lookahead == 'o') ADVANCE(137);
      END_STATE();
    case 91:
      if (lookahead == 'n') ADVANCE(138);
      END_STATE();
    case 92:
      if (lookahead == 't') ADVANCE(139);
      END_STATE();
    case 93:
      if (lookahead == 'd') ADVANCE(140);
      END_STATE();
    case 94:
      if (lookahead == 'g') ADVANCE(141);
      END_STATE();
    case 95:
      if (lookahead == 'r') ADVANCE(142);
      END_STATE();
    case 96:
      if (lookahead == 's') ADVANCE(143);
      END_STATE();
    case 97:
      if (lookahead == 'v') ADVANCE(144);
      END_STATE();
    case 98:
      if (lookahead == 'l') ADVANCE(145);
      END_STATE();
    case 99:
      if (lookahead == 'l') ADVANCE(146);
      END_STATE();
    case 100:
      if (lookahead == 'c') ADVANCE(147);
      END_STATE();
    case 101:
      if (lookahead == 't') ADVANCE(148);
      END_STATE();
    case 102:
      if (lookahead == 'i') ADVANCE(149);
      END_STATE();
    case 103:
      if (lookahead == 's') ADVANCE(150);
      END_STATE();
    case 104:
      if (lookahead == 'f') ADVANCE(151);
      END_STATE();
    case 105:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 106:
      if (lookahead == 'x') ADVANCE(153);
      END_STATE();
    case 107:
      if (lookahead == 'u') ADVANCE(154);
      END_STATE();
    case 108:
      if (lookahead == 't') ADVANCE(155);
      END_STATE();
    case 109:
      if (lookahead == 'n') ADVANCE(156);
      END_STATE();
    case 110:
      if (lookahead == 'd') ADVANCE(157);
      END_STATE();
    case 111:
      if (lookahead == 'd') ADVANCE(158);
      END_STATE();
    case 112:
      if (lookahead == 'd') ADVANCE(86);
      if (lookahead == 'e') ADVANCE(87);
      if (lookahead == 'n') ADVANCE(88);
      END_STATE();
    case 113:
      if (lookahead == 'c') ADVANCE(89);
      END_STATE();
    case 114:
      if (lookahead == 'H') ADVANCE(159);
      END_STATE();
    case 115:
      if (lookahead == 'a') ADVANCE(160);
      END_STATE();
    case 116:
      if (lookahead == 'r') ADVANCE(161);
      END_STATE();
    case 117:
      if (lookahead == 'u') ADVANCE(162);
      END_STATE();
    case 118:
      if (lookahead == 'n') ADVANCE(163);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_call);
      END_STATE();
    case 120:
      if (lookahead == 'n') ADVANCE(164);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 122:
      if (lookahead == 'f') ADVANCE(165);
      END_STATE();
    case 123:
      if (lookahead == 'r') ADVANCE(166);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_eval);
      END_STATE();
    case 125:
      if (lookahead == 'r') ADVANCE(167);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_file);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(168);
      END_STATE();
    case 128:
      if (lookahead == 's') ADVANCE(169);
      END_STATE();
    case 129:
      if (lookahead == 't') ADVANCE(170);
      END_STATE();
    case 130:
      if (lookahead == 'o') ADVANCE(171);
      END_STATE();
    case 131:
      if (lookahead == 'a') ADVANCE(172);
      END_STATE();
    case 132:
      if (lookahead == 'f') ADVANCE(173);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_ifeq);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(174);
      END_STATE();
    case 135:
      if (lookahead == 'q') ADVANCE(175);
      END_STATE();
    case 136:
      if (lookahead == 'u') ADVANCE(176);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_info);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_join);
      END_STATE();
    case 139:
      if (lookahead == 'w') ADVANCE(177);
      END_STATE();
    case 140:
      if (lookahead == 'i') ADVANCE(178);
      END_STATE();
    case 141:
      if (lookahead == 'i') ADVANCE(179);
      END_STATE();
    case 142:
      if (lookahead == 'r') ADVANCE(180);
      END_STATE();
    case 143:
      if (lookahead == 'u') ADVANCE(181);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(182);
      END_STATE();
    case 145:
      if (lookahead == 'p') ADVANCE(183);
      END_STATE();
    case 146:
      if (lookahead == 'l') ADVANCE(184);
      END_STATE();
    case 147:
      if (lookahead == 'l') ADVANCE(185);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_sort);
      END_STATE();
    case 149:
      if (lookahead == 'p') ADVANCE(186);
      END_STATE();
    case 150:
      if (lookahead == 't') ADVANCE(187);
      END_STATE();
    case 151:
      if (lookahead == 'i') ADVANCE(188);
      END_STATE();
    case 152:
      if (lookahead == 'f') ADVANCE(189);
      END_STATE();
    case 153:
      if (lookahead == 'p') ADVANCE(190);
      END_STATE();
    case 154:
      if (lookahead == 'e') ADVANCE(191);
      END_STATE();
    case 155:
      if (lookahead == 'h') ADVANCE(192);
      END_STATE();
    case 156:
      if (lookahead == 'i') ADVANCE(193);
      END_STATE();
    case 157:
      if (lookahead == 'c') ADVANCE(194);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_word);
      if (lookahead == 'l') ADVANCE(195);
      if (lookahead == 's') ADVANCE(196);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_VPATH);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 161:
      if (lookahead == 'e') ADVANCE(198);
      END_STATE();
    case 162:
      if (lookahead == 'f') ADVANCE(199);
      END_STATE();
    case 163:
      if (lookahead == 'a') ADVANCE(200);
      END_STATE();
    case 164:
      if (lookahead == 'e') ADVANCE(201);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_endif);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_error);
      END_STATE();
    case 167:
      if (lookahead == 't') ADVANCE(202);
      END_STATE();
    case 168:
      if (lookahead == 'r') ADVANCE(203);
      END_STATE();
    case 169:
      if (lookahead == 't') ADVANCE(204);
      END_STATE();
    case 170:
      if (lookahead == 'w') ADVANCE(205);
      END_STATE();
    case 171:
      if (lookahead == 'r') ADVANCE(206);
      END_STATE();
    case 172:
      if (lookahead == 'c') ADVANCE(207);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_ifdef);
      END_STATE();
    case 174:
      if (lookahead == 'f') ADVANCE(208);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_ifneq);
      END_STATE();
    case 176:
      if (lookahead == 'd') ADVANCE(209);
      END_STATE();
    case 177:
      if (lookahead == 'o') ADVANCE(210);
      END_STATE();
    case 178:
      if (lookahead == 'r') ADVANCE(211);
      END_STATE();
    case 179:
      if (lookahead == 'n') ADVANCE(212);
      END_STATE();
    case 180:
      if (lookahead == 'i') ADVANCE(213);
      END_STATE();
    case 181:
      if (lookahead == 'b') ADVANCE(214);
      END_STATE();
    case 182:
      if (lookahead == 't') ADVANCE(215);
      END_STATE();
    case 183:
      if (lookahead == 'a') ADVANCE(216);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_shell);
      END_STATE();
    case 185:
      if (lookahead == 'u') ADVANCE(217);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_strip);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_subst);
      END_STATE();
    case 188:
      if (lookahead == 'x') ADVANCE(218);
      END_STATE();
    case 189:
      if (lookahead == 'i') ADVANCE(219);
      END_STATE();
    case 190:
      if (lookahead == 'o') ADVANCE(220);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_value);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_vpath);
      END_STATE();
    case 193:
      if (lookahead == 'n') ADVANCE(221);
      END_STATE();
    case 194:
      if (lookahead == 'a') ADVANCE(222);
      END_STATE();
    case 195:
      if (lookahead == 'i') ADVANCE(223);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_words);
      END_STATE();
    case 197:
      if (lookahead == 'h') ADVANCE(224);
      END_STATE();
    case 198:
      if (lookahead == 'f') ADVANCE(225);
      END_STATE();
    case 199:
      if (lookahead == 'f') ADVANCE(226);
      END_STATE();
    case 200:
      if (lookahead == 'm') ADVANCE(227);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_define);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_filter);
      if (lookahead == '-') ADVANCE(228);
      END_STATE();
    case 204:
      if (lookahead == 'r') ADVANCE(229);
      END_STATE();
    case 205:
      if (lookahead == 'o') ADVANCE(230);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_flavor);
      END_STATE();
    case 207:
      if (lookahead == 'h') ADVANCE(231);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_ifndef);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(232);
      END_STATE();
    case 210:
      if (lookahead == 'r') ADVANCE(233);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_notdir);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_origin);
      END_STATE();
    case 213:
      if (lookahead == 'd') ADVANCE(234);
      END_STATE();
    case 214:
      if (lookahead == 's') ADVANCE(235);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 216:
      if (lookahead == 't') ADVANCE(237);
      END_STATE();
    case 217:
      if (lookahead == 'd') ADVANCE(238);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_suffix);
      END_STATE();
    case 219:
      if (lookahead == 'n') ADVANCE(239);
      END_STATE();
    case 220:
      if (lookahead == 'r') ADVANCE(240);
      END_STATE();
    case 221:
      if (lookahead == 'g') ADVANCE(241);
      END_STATE();
    case 222:
      if (lookahead == 'r') ADVANCE(242);
      END_STATE();
    case 223:
      if (lookahead == 's') ADVANCE(243);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_abspath);
      END_STATE();
    case 225:
      if (lookahead == 'i') ADVANCE(244);
      END_STATE();
    case 226:
      if (lookahead == 'i') ADVANCE(245);
      END_STATE();
    case 227:
      if (lookahead == 'e') ADVANCE(246);
      END_STATE();
    case 228:
      if (lookahead == 'o') ADVANCE(247);
      END_STATE();
    case 229:
      if (lookahead == 'i') ADVANCE(248);
      END_STATE();
    case 230:
      if (lookahead == 'r') ADVANCE(249);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_foreach);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_include);
      END_STATE();
    case 233:
      if (lookahead == 'd') ADVANCE(250);
      END_STATE();
    case 234:
      if (lookahead == 'e') ADVANCE(251);
      END_STATE();
    case 235:
      if (lookahead == 't') ADVANCE(252);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 237:
      if (lookahead == 'h') ADVANCE(253);
      END_STATE();
    case 238:
      if (lookahead == 'e') ADVANCE(254);
      END_STATE();
    case 239:
      if (lookahead == 'e') ADVANCE(255);
      END_STATE();
    case 240:
      if (lookahead == 't') ADVANCE(256);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_warning);
      END_STATE();
    case 242:
      if (lookahead == 'd') ADVANCE(257);
      END_STATE();
    case 243:
      if (lookahead == 't') ADVANCE(258);
      END_STATE();
    case 244:
      if (lookahead == 'x') ADVANCE(259);
      END_STATE();
    case 245:
      if (lookahead == 'x') ADVANCE(260);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_basename);
      END_STATE();
    case 247:
      if (lookahead == 'u') ADVANCE(261);
      END_STATE();
    case 248:
      if (lookahead == 'n') ADVANCE(262);
      END_STATE();
    case 249:
      if (lookahead == 'd') ADVANCE(263);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_lastword);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_patsubst);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(anon_sym_realpath);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(anon_sym_sinclude);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(anon_sym_undefine);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(anon_sym_unexport);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_wildcard);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_wordlist);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_addprefix);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_addsuffix);
      END_STATE();
    case 261:
      if (lookahead == 't') ADVANCE(264);
      END_STATE();
    case 262:
      if (lookahead == 'g') ADVANCE(265);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_firstword);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_filter_DASHout);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_findstring);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 106},
  [2] = {.lex_state = 104},
  [3] = {.lex_state = 104},
  [4] = {.lex_state = 104},
  [5] = {.lex_state = 104},
  [6] = {.lex_state = 104},
  [7] = {.lex_state = 104},
  [8] = {.lex_state = 104},
  [9] = {.lex_state = 104},
  [10] = {.lex_state = 104},
  [11] = {.lex_state = 104},
  [12] = {.lex_state = 104},
  [13] = {.lex_state = 48},
  [14] = {.lex_state = 48},
  [15] = {.lex_state = 48},
  [16] = {.lex_state = 48},
  [17] = {.lex_state = 48},
  [18] = {.lex_state = 48},
  [19] = {.lex_state = 48},
  [20] = {.lex_state = 48},
  [21] = {.lex_state = 48},
  [22] = {.lex_state = 48},
  [23] = {.lex_state = 48},
  [24] = {.lex_state = 48},
  [25] = {.lex_state = 106},
  [26] = {.lex_state = 106},
  [27] = {.lex_state = 104},
  [28] = {.lex_state = 104},
  [29] = {.lex_state = 104},
  [30] = {.lex_state = 104},
  [31] = {.lex_state = 104},
  [32] = {.lex_state = 104},
  [33] = {.lex_state = 104},
  [34] = {.lex_state = 104},
  [35] = {.lex_state = 104},
  [36] = {.lex_state = 104},
  [37] = {.lex_state = 104},
  [38] = {.lex_state = 104},
  [39] = {.lex_state = 104},
  [40] = {.lex_state = 104},
  [41] = {.lex_state = 104},
  [42] = {.lex_state = 104},
  [43] = {.lex_state = 104},
  [44] = {.lex_state = 104},
  [45] = {.lex_state = 104},
  [46] = {.lex_state = 104},
  [47] = {.lex_state = 104},
  [48] = {.lex_state = 104},
  [49] = {.lex_state = 104},
  [50] = {.lex_state = 104},
  [51] = {.lex_state = 104},
  [52] = {.lex_state = 104},
  [53] = {.lex_state = 104},
  [54] = {.lex_state = 104},
  [55] = {.lex_state = 104},
  [56] = {.lex_state = 104},
  [57] = {.lex_state = 104},
  [58] = {.lex_state = 104},
  [59] = {.lex_state = 104},
  [60] = {.lex_state = 104},
  [61] = {.lex_state = 104},
  [62] = {.lex_state = 104},
  [63] = {.lex_state = 104},
  [64] = {.lex_state = 104},
  [65] = {.lex_state = 104},
  [66] = {.lex_state = 104},
  [67] = {.lex_state = 104},
  [68] = {.lex_state = 104},
  [69] = {.lex_state = 104},
  [70] = {.lex_state = 104},
  [71] = {.lex_state = 104},
  [72] = {.lex_state = 104},
  [73] = {.lex_state = 104},
  [74] = {.lex_state = 104},
  [75] = {.lex_state = 46},
  [76] = {.lex_state = 46},
  [77] = {.lex_state = 58},
  [78] = {.lex_state = 58},
  [79] = {.lex_state = 58},
  [80] = {.lex_state = 58},
  [81] = {.lex_state = 58},
  [82] = {.lex_state = 58},
  [83] = {.lex_state = 46},
  [84] = {.lex_state = 46},
  [85] = {.lex_state = 11},
  [86] = {.lex_state = 14},
  [87] = {.lex_state = 104},
  [88] = {.lex_state = 104},
  [89] = {.lex_state = 104},
  [90] = {.lex_state = 104},
  [91] = {.lex_state = 104},
  [92] = {.lex_state = 104},
  [93] = {.lex_state = 104},
  [94] = {.lex_state = 104},
  [95] = {.lex_state = 104},
  [96] = {.lex_state = 12},
  [97] = {.lex_state = 104},
  [98] = {.lex_state = 104},
  [99] = {.lex_state = 104},
  [100] = {.lex_state = 104},
  [101] = {.lex_state = 62},
  [102] = {.lex_state = 62},
  [103] = {.lex_state = 104},
  [104] = {.lex_state = 104},
  [105] = {.lex_state = 104},
  [106] = {.lex_state = 62},
  [107] = {.lex_state = 104},
  [108] = {.lex_state = 104},
  [109] = {.lex_state = 104},
  [110] = {.lex_state = 104},
  [111] = {.lex_state = 104},
  [112] = {.lex_state = 104},
  [113] = {.lex_state = 104},
  [114] = {.lex_state = 104},
  [115] = {.lex_state = 104},
  [116] = {.lex_state = 104},
  [117] = {.lex_state = 104},
  [118] = {.lex_state = 104},
  [119] = {.lex_state = 104},
  [120] = {.lex_state = 104},
  [121] = {.lex_state = 104},
  [122] = {.lex_state = 104},
  [123] = {.lex_state = 104},
  [124] = {.lex_state = 104},
  [125] = {.lex_state = 104},
  [126] = {.lex_state = 104},
  [127] = {.lex_state = 104},
  [128] = {.lex_state = 104},
  [129] = {.lex_state = 104},
  [130] = {.lex_state = 104},
  [131] = {.lex_state = 104},
  [132] = {.lex_state = 104},
  [133] = {.lex_state = 104},
  [134] = {.lex_state = 62},
  [135] = {.lex_state = 47},
  [136] = {.lex_state = 104},
  [137] = {.lex_state = 104},
  [138] = {.lex_state = 104},
  [139] = {.lex_state = 104},
  [140] = {.lex_state = 104},
  [141] = {.lex_state = 104},
  [142] = {.lex_state = 104},
  [143] = {.lex_state = 104},
  [144] = {.lex_state = 104},
  [145] = {.lex_state = 104},
  [146] = {.lex_state = 104},
  [147] = {.lex_state = 104},
  [148] = {.lex_state = 104},
  [149] = {.lex_state = 104},
  [150] = {.lex_state = 104},
  [151] = {.lex_state = 104},
  [152] = {.lex_state = 104},
  [153] = {.lex_state = 104},
  [154] = {.lex_state = 104},
  [155] = {.lex_state = 104},
  [156] = {.lex_state = 104},
  [157] = {.lex_state = 104},
  [158] = {.lex_state = 104},
  [159] = {.lex_state = 47},
  [160] = {.lex_state = 104},
  [161] = {.lex_state = 104},
  [162] = {.lex_state = 104},
  [163] = {.lex_state = 104},
  [164] = {.lex_state = 104},
  [165] = {.lex_state = 104},
  [166] = {.lex_state = 104},
  [167] = {.lex_state = 104},
  [168] = {.lex_state = 104},
  [169] = {.lex_state = 104},
  [170] = {.lex_state = 104},
  [171] = {.lex_state = 104},
  [172] = {.lex_state = 104},
  [173] = {.lex_state = 104},
  [174] = {.lex_state = 104},
  [175] = {.lex_state = 104},
  [176] = {.lex_state = 16},
  [177] = {.lex_state = 104},
  [178] = {.lex_state = 104},
  [179] = {.lex_state = 104},
  [180] = {.lex_state = 104},
  [181] = {.lex_state = 104},
  [182] = {.lex_state = 104},
  [183] = {.lex_state = 18},
  [184] = {.lex_state = 104},
  [185] = {.lex_state = 104},
  [186] = {.lex_state = 104},
  [187] = {.lex_state = 104},
  [188] = {.lex_state = 50},
  [189] = {.lex_state = 104},
  [190] = {.lex_state = 51},
  [191] = {.lex_state = 48},
  [192] = {.lex_state = 104},
  [193] = {.lex_state = 104},
  [194] = {.lex_state = 48},
  [195] = {.lex_state = 104},
  [196] = {.lex_state = 48},
  [197] = {.lex_state = 51},
  [198] = {.lex_state = 51},
  [199] = {.lex_state = 104},
  [200] = {.lex_state = 48},
  [201] = {.lex_state = 50},
  [202] = {.lex_state = 51},
  [203] = {.lex_state = 48},
  [204] = {.lex_state = 48},
  [205] = {.lex_state = 48},
  [206] = {.lex_state = 104},
  [207] = {.lex_state = 51},
  [208] = {.lex_state = 104},
  [209] = {.lex_state = 48},
  [210] = {.lex_state = 50},
  [211] = {.lex_state = 104},
  [212] = {.lex_state = 48},
  [213] = {.lex_state = 48},
  [214] = {.lex_state = 65},
  [215] = {.lex_state = 48},
  [216] = {.lex_state = 65},
  [217] = {.lex_state = 51},
  [218] = {.lex_state = 65},
  [219] = {.lex_state = 65},
  [220] = {.lex_state = 106},
  [221] = {.lex_state = 51},
  [222] = {.lex_state = 106},
  [223] = {.lex_state = 106},
  [224] = {.lex_state = 106},
  [225] = {.lex_state = 106},
  [226] = {.lex_state = 106},
  [227] = {.lex_state = 106},
  [228] = {.lex_state = 106},
  [229] = {.lex_state = 106},
  [230] = {.lex_state = 106},
  [231] = {.lex_state = 106},
  [232] = {.lex_state = 106},
  [233] = {.lex_state = 106},
  [234] = {.lex_state = 106},
  [235] = {.lex_state = 106},
  [236] = {.lex_state = 106},
  [237] = {.lex_state = 106},
  [238] = {.lex_state = 106},
  [239] = {.lex_state = 106},
  [240] = {.lex_state = 106},
  [241] = {.lex_state = 106},
  [242] = {.lex_state = 106},
  [243] = {.lex_state = 106},
  [244] = {.lex_state = 106},
  [245] = {.lex_state = 106},
  [246] = {.lex_state = 106},
  [247] = {.lex_state = 106},
  [248] = {.lex_state = 106},
  [249] = {.lex_state = 106},
  [250] = {.lex_state = 106},
  [251] = {.lex_state = 106},
  [252] = {.lex_state = 106},
  [253] = {.lex_state = 106},
  [254] = {.lex_state = 106},
  [255] = {.lex_state = 62},
  [256] = {.lex_state = 106},
  [257] = {.lex_state = 106},
  [258] = {.lex_state = 106},
  [259] = {.lex_state = 106},
  [260] = {.lex_state = 51},
  [261] = {.lex_state = 59},
  [262] = {.lex_state = 106},
  [263] = {.lex_state = 106},
  [264] = {.lex_state = 106},
  [265] = {.lex_state = 106},
  [266] = {.lex_state = 106},
  [267] = {.lex_state = 106},
  [268] = {.lex_state = 106},
  [269] = {.lex_state = 106},
  [270] = {.lex_state = 106},
  [271] = {.lex_state = 106},
  [272] = {.lex_state = 106},
  [273] = {.lex_state = 106},
  [274] = {.lex_state = 106},
  [275] = {.lex_state = 106},
  [276] = {.lex_state = 51},
  [277] = {.lex_state = 106},
  [278] = {.lex_state = 106},
  [279] = {.lex_state = 106},
  [280] = {.lex_state = 106},
  [281] = {.lex_state = 106},
  [282] = {.lex_state = 106},
  [283] = {.lex_state = 59},
  [284] = {.lex_state = 106},
  [285] = {.lex_state = 106},
  [286] = {.lex_state = 106},
  [287] = {.lex_state = 106},
  [288] = {.lex_state = 106},
  [289] = {.lex_state = 59},
  [290] = {.lex_state = 106},
  [291] = {.lex_state = 50},
  [292] = {.lex_state = 106},
  [293] = {.lex_state = 106},
  [294] = {.lex_state = 106},
  [295] = {.lex_state = 106},
  [296] = {.lex_state = 106},
  [297] = {.lex_state = 50},
  [298] = {.lex_state = 106},
  [299] = {.lex_state = 106},
  [300] = {.lex_state = 106},
  [301] = {.lex_state = 50},
  [302] = {.lex_state = 106},
  [303] = {.lex_state = 62},
  [304] = {.lex_state = 106},
  [305] = {.lex_state = 106},
  [306] = {.lex_state = 106},
  [307] = {.lex_state = 57},
  [308] = {.lex_state = 106},
  [309] = {.lex_state = 59},
  [310] = {.lex_state = 106},
  [311] = {.lex_state = 106},
  [312] = {.lex_state = 106},
  [313] = {.lex_state = 106},
  [314] = {.lex_state = 106},
  [315] = {.lex_state = 106},
  [316] = {.lex_state = 106},
  [317] = {.lex_state = 106},
  [318] = {.lex_state = 106},
  [319] = {.lex_state = 65},
  [320] = {.lex_state = 47},
  [321] = {.lex_state = 57},
  [322] = {.lex_state = 65},
  [323] = {.lex_state = 65},
  [324] = {.lex_state = 57},
  [325] = {.lex_state = 57},
  [326] = {.lex_state = 47},
  [327] = {.lex_state = 65},
  [328] = {.lex_state = 50},
  [329] = {.lex_state = 60},
  [330] = {.lex_state = 57},
  [331] = {.lex_state = 59},
  [332] = {.lex_state = 59},
  [333] = {.lex_state = 59},
  [334] = {.lex_state = 59},
  [335] = {.lex_state = 60},
  [336] = {.lex_state = 60},
  [337] = {.lex_state = 60},
  [338] = {.lex_state = 57},
  [339] = {.lex_state = 57},
  [340] = {.lex_state = 57},
  [341] = {.lex_state = 57},
  [342] = {.lex_state = 57},
  [343] = {.lex_state = 57},
  [344] = {.lex_state = 57},
  [345] = {.lex_state = 59},
  [346] = {.lex_state = 57},
  [347] = {.lex_state = 57},
  [348] = {.lex_state = 57},
  [349] = {.lex_state = 52},
  [350] = {.lex_state = 59},
  [351] = {.lex_state = 57},
  [352] = {.lex_state = 57},
  [353] = {.lex_state = 57},
  [354] = {.lex_state = 57},
  [355] = {.lex_state = 57},
  [356] = {.lex_state = 52},
  [357] = {.lex_state = 60},
  [358] = {.lex_state = 57},
  [359] = {.lex_state = 60},
  [360] = {.lex_state = 57},
  [361] = {.lex_state = 57},
  [362] = {.lex_state = 57},
  [363] = {.lex_state = 57},
  [364] = {.lex_state = 57},
  [365] = {.lex_state = 60},
  [366] = {.lex_state = 57},
  [367] = {.lex_state = 57},
  [368] = {.lex_state = 57},
  [369] = {.lex_state = 57},
  [370] = {.lex_state = 57},
  [371] = {.lex_state = 57},
  [372] = {.lex_state = 57},
  [373] = {.lex_state = 57},
  [374] = {.lex_state = 57},
  [375] = {.lex_state = 57},
  [376] = {.lex_state = 57},
  [377] = {.lex_state = 80},
  [378] = {.lex_state = 57},
  [379] = {.lex_state = 57},
  [380] = {.lex_state = 57},
  [381] = {.lex_state = 57},
  [382] = {.lex_state = 57},
  [383] = {.lex_state = 57},
  [384] = {.lex_state = 57},
  [385] = {.lex_state = 57},
  [386] = {.lex_state = 57},
  [387] = {.lex_state = 57},
  [388] = {.lex_state = 57},
  [389] = {.lex_state = 57},
  [390] = {.lex_state = 57},
  [391] = {.lex_state = 57},
  [392] = {.lex_state = 57},
  [393] = {.lex_state = 57},
  [394] = {.lex_state = 57},
  [395] = {.lex_state = 57},
  [396] = {.lex_state = 57},
  [397] = {.lex_state = 80},
  [398] = {.lex_state = 57},
  [399] = {.lex_state = 57},
  [400] = {.lex_state = 57},
  [401] = {.lex_state = 57},
  [402] = {.lex_state = 57},
  [403] = {.lex_state = 57},
  [404] = {.lex_state = 57},
  [405] = {.lex_state = 57},
  [406] = {.lex_state = 57},
  [407] = {.lex_state = 57},
  [408] = {.lex_state = 59},
  [409] = {.lex_state = 57},
  [410] = {.lex_state = 57},
  [411] = {.lex_state = 57},
  [412] = {.lex_state = 57},
  [413] = {.lex_state = 57},
  [414] = {.lex_state = 57},
  [415] = {.lex_state = 57},
  [416] = {.lex_state = 57},
  [417] = {.lex_state = 59},
  [418] = {.lex_state = 57},
  [419] = {.lex_state = 57},
  [420] = {.lex_state = 59},
  [421] = {.lex_state = 57},
  [422] = {.lex_state = 57},
  [423] = {.lex_state = 57},
  [424] = {.lex_state = 57},
  [425] = {.lex_state = 57},
  [426] = {.lex_state = 57},
  [427] = {.lex_state = 57},
  [428] = {.lex_state = 59},
  [429] = {.lex_state = 57},
  [430] = {.lex_state = 57},
  [431] = {.lex_state = 57},
  [432] = {.lex_state = 57},
  [433] = {.lex_state = 59},
  [434] = {.lex_state = 57},
  [435] = {.lex_state = 57},
  [436] = {.lex_state = 57},
  [437] = {.lex_state = 80},
  [438] = {.lex_state = 57},
  [439] = {.lex_state = 57},
  [440] = {.lex_state = 57},
  [441] = {.lex_state = 57},
  [442] = {.lex_state = 57},
  [443] = {.lex_state = 57},
  [444] = {.lex_state = 57},
  [445] = {.lex_state = 52},
  [446] = {.lex_state = 59},
  [447] = {.lex_state = 57},
  [448] = {.lex_state = 57},
  [449] = {.lex_state = 57},
  [450] = {.lex_state = 57},
  [451] = {.lex_state = 57},
  [452] = {.lex_state = 57},
  [453] = {.lex_state = 11},
  [454] = {.lex_state = 57},
  [455] = {.lex_state = 57},
  [456] = {.lex_state = 57},
  [457] = {.lex_state = 57},
  [458] = {.lex_state = 57},
  [459] = {.lex_state = 11},
  [460] = {.lex_state = 57},
  [461] = {.lex_state = 59},
  [462] = {.lex_state = 57},
  [463] = {.lex_state = 57},
  [464] = {.lex_state = 57},
  [465] = {.lex_state = 59},
  [466] = {.lex_state = 57},
  [467] = {.lex_state = 57},
  [468] = {.lex_state = 52},
  [469] = {.lex_state = 57},
  [470] = {.lex_state = 57},
  [471] = {.lex_state = 57},
  [472] = {.lex_state = 57},
  [473] = {.lex_state = 57},
  [474] = {.lex_state = 57},
  [475] = {.lex_state = 57},
  [476] = {.lex_state = 57},
  [477] = {.lex_state = 59},
  [478] = {.lex_state = 57},
  [479] = {.lex_state = 57},
  [480] = {.lex_state = 57},
  [481] = {.lex_state = 57},
  [482] = {.lex_state = 57},
  [483] = {.lex_state = 57},
  [484] = {.lex_state = 57},
  [485] = {.lex_state = 57},
  [486] = {.lex_state = 57},
  [487] = {.lex_state = 57},
  [488] = {.lex_state = 59},
  [489] = {.lex_state = 59},
  [490] = {.lex_state = 57},
  [491] = {.lex_state = 11},
  [492] = {.lex_state = 59},
  [493] = {.lex_state = 57},
  [494] = {.lex_state = 14},
  [495] = {.lex_state = 57},
  [496] = {.lex_state = 57},
  [497] = {.lex_state = 57},
  [498] = {.lex_state = 57},
  [499] = {.lex_state = 57},
  [500] = {.lex_state = 57},
  [501] = {.lex_state = 57},
  [502] = {.lex_state = 57},
  [503] = {.lex_state = 14},
  [504] = {.lex_state = 57},
  [505] = {.lex_state = 14},
  [506] = {.lex_state = 57},
  [507] = {.lex_state = 57},
  [508] = {.lex_state = 57},
  [509] = {.lex_state = 57},
  [510] = {.lex_state = 16},
  [511] = {.lex_state = 57},
  [512] = {.lex_state = 12},
  [513] = {.lex_state = 12},
  [514] = {.lex_state = 57},
  [515] = {.lex_state = 18},
  [516] = {.lex_state = 16},
  [517] = {.lex_state = 57},
  [518] = {.lex_state = 18},
  [519] = {.lex_state = 16},
  [520] = {.lex_state = 57},
  [521] = {.lex_state = 18},
  [522] = {.lex_state = 57},
  [523] = {.lex_state = 57},
  [524] = {.lex_state = 57},
  [525] = {.lex_state = 57},
  [526] = {.lex_state = 57},
  [527] = {.lex_state = 12},
  [528] = {.lex_state = 57},
  [529] = {.lex_state = 57},
  [530] = {.lex_state = 57},
  [531] = {.lex_state = 57},
  [532] = {.lex_state = 57},
  [533] = {.lex_state = 57},
  [534] = {.lex_state = 57},
  [535] = {.lex_state = 57},
  [536] = {.lex_state = 57},
  [537] = {.lex_state = 57},
  [538] = {.lex_state = 57},
  [539] = {.lex_state = 57},
  [540] = {.lex_state = 57},
  [541] = {.lex_state = 57},
  [542] = {.lex_state = 57},
  [543] = {.lex_state = 57},
  [544] = {.lex_state = 2},
  [545] = {.lex_state = 57},
  [546] = {.lex_state = 57},
  [547] = {.lex_state = 57},
  [548] = {.lex_state = 2},
  [549] = {.lex_state = 57},
  [550] = {.lex_state = 57},
  [551] = {.lex_state = 57},
  [552] = {.lex_state = 57},
  [553] = {.lex_state = 57},
  [554] = {.lex_state = 2},
  [555] = {.lex_state = 57},
  [556] = {.lex_state = 57},
  [557] = {.lex_state = 57},
  [558] = {.lex_state = 57},
  [559] = {.lex_state = 57},
  [560] = {.lex_state = 57},
  [561] = {.lex_state = 57},
  [562] = {.lex_state = 57},
  [563] = {.lex_state = 57},
  [564] = {.lex_state = 57},
  [565] = {.lex_state = 2},
  [566] = {.lex_state = 57},
  [567] = {.lex_state = 57},
  [568] = {.lex_state = 57},
  [569] = {.lex_state = 57},
  [570] = {.lex_state = 57},
  [571] = {.lex_state = 57},
  [572] = {.lex_state = 57},
  [573] = {.lex_state = 57},
  [574] = {.lex_state = 57},
  [575] = {.lex_state = 57},
  [576] = {.lex_state = 57},
  [577] = {.lex_state = 57},
  [578] = {.lex_state = 57},
  [579] = {.lex_state = 57},
  [580] = {.lex_state = 57},
  [581] = {.lex_state = 57},
  [582] = {.lex_state = 57},
  [583] = {.lex_state = 57},
  [584] = {.lex_state = 57},
  [585] = {.lex_state = 57},
  [586] = {.lex_state = 57},
  [587] = {.lex_state = 57},
  [588] = {.lex_state = 57},
  [589] = {.lex_state = 57},
  [590] = {.lex_state = 57},
  [591] = {.lex_state = 57},
  [592] = {.lex_state = 2},
  [593] = {.lex_state = 57},
  [594] = {.lex_state = 57},
  [595] = {.lex_state = 57},
  [596] = {.lex_state = 57},
  [597] = {.lex_state = 57},
  [598] = {.lex_state = 88},
  [599] = {.lex_state = 85},
  [600] = {.lex_state = 87},
  [601] = {.lex_state = 83},
  [602] = {.lex_state = 88},
  [603] = {.lex_state = 88},
  [604] = {.lex_state = 88},
  [605] = {.lex_state = 88},
  [606] = {.lex_state = 88},
  [607] = {.lex_state = 88},
  [608] = {.lex_state = 87},
  [609] = {.lex_state = 87},
  [610] = {.lex_state = 83},
  [611] = {.lex_state = 87},
  [612] = {.lex_state = 87},
  [613] = {.lex_state = 87},
  [614] = {.lex_state = 87},
  [615] = {.lex_state = 83},
  [616] = {.lex_state = 87},
  [617] = {.lex_state = 85},
  [618] = {.lex_state = 88},
  [619] = {.lex_state = 88},
  [620] = {.lex_state = 88},
  [621] = {.lex_state = 85},
  [622] = {.lex_state = 88},
  [623] = {.lex_state = 87},
  [624] = {.lex_state = 88},
  [625] = {.lex_state = 88},
  [626] = {.lex_state = 88},
  [627] = {.lex_state = 87},
  [628] = {.lex_state = 88},
  [629] = {.lex_state = 88},
  [630] = {.lex_state = 88},
  [631] = {.lex_state = 88},
  [632] = {.lex_state = 87},
  [633] = {.lex_state = 88},
  [634] = {.lex_state = 88},
  [635] = {.lex_state = 88},
  [636] = {.lex_state = 88},
  [637] = {.lex_state = 85},
  [638] = {.lex_state = 87},
  [639] = {.lex_state = 88},
  [640] = {.lex_state = 83},
  [641] = {.lex_state = 85},
  [642] = {.lex_state = 83},
  [643] = {.lex_state = 88},
  [644] = {.lex_state = 88},
  [645] = {.lex_state = 88},
  [646] = {.lex_state = 84},
  [647] = {.lex_state = 86},
  [648] = {.lex_state = 89},
  [649] = {.lex_state = 69},
  [650] = {.lex_state = 86},
  [651] = {.lex_state = 82},
  [652] = {.lex_state = 69},
  [653] = {.lex_state = 70},
  [654] = {.lex_state = 86},
  [655] = {.lex_state = 89},
  [656] = {.lex_state = 86},
  [657] = {.lex_state = 89},
  [658] = {.lex_state = 84},
  [659] = {.lex_state = 84},
  [660] = {.lex_state = 86},
  [661] = {.lex_state = 86},
  [662] = {.lex_state = 86},
  [663] = {.lex_state = 86},
  [664] = {.lex_state = 86},
  [665] = {.lex_state = 86},
  [666] = {.lex_state = 86},
  [667] = {.lex_state = 86},
  [668] = {.lex_state = 86},
  [669] = {.lex_state = 86},
  [670] = {.lex_state = 89},
  [671] = {.lex_state = 86},
  [672] = {.lex_state = 86},
  [673] = {.lex_state = 86},
  [674] = {.lex_state = 86},
  [675] = {.lex_state = 86},
  [676] = {.lex_state = 86},
  [677] = {.lex_state = 89},
  [678] = {.lex_state = 89},
  [679] = {.lex_state = 86},
  [680] = {.lex_state = 86},
  [681] = {.lex_state = 86},
  [682] = {.lex_state = 86},
  [683] = {.lex_state = 51},
  [684] = {.lex_state = 86},
  [685] = {.lex_state = 89},
  [686] = {.lex_state = 84},
  [687] = {.lex_state = 70},
  [688] = {.lex_state = 86},
  [689] = {.lex_state = 51},
  [690] = {.lex_state = 89},
  [691] = {.lex_state = 82},
  [692] = {.lex_state = 82},
  [693] = {.lex_state = 82},
  [694] = {.lex_state = 89},
  [695] = {.lex_state = 86},
  [696] = {.lex_state = 89},
  [697] = {.lex_state = 82},
  [698] = {.lex_state = 70},
  [699] = {.lex_state = 82},
  [700] = {.lex_state = 89},
  [701] = {.lex_state = 89},
  [702] = {.lex_state = 69},
  [703] = {.lex_state = 51},
  [704] = {.lex_state = 89},
  [705] = {.lex_state = 86},
  [706] = {.lex_state = 51},
  [707] = {.lex_state = 86},
  [708] = {.lex_state = 86},
  [709] = {.lex_state = 89},
  [710] = {.lex_state = 89},
  [711] = {.lex_state = 89},
  [712] = {.lex_state = 86},
  [713] = {.lex_state = 89},
  [714] = {.lex_state = 84},
  [715] = {.lex_state = 86},
  [716] = {.lex_state = 68},
  [717] = {.lex_state = 68},
  [718] = {.lex_state = 91},
  [719] = {.lex_state = 69},
  [720] = {.lex_state = 68},
  [721] = {.lex_state = 91},
  [722] = {.lex_state = 72},
  [723] = {.lex_state = 86},
  [724] = {.lex_state = 69},
  [725] = {.lex_state = 70},
  [726] = {.lex_state = 68},
  [727] = {.lex_state = 91},
  [728] = {.lex_state = 71},
  [729] = {.lex_state = 70},
  [730] = {.lex_state = 72},
  [731] = {.lex_state = 68},
  [732] = {.lex_state = 91},
  [733] = {.lex_state = 69},
  [734] = {.lex_state = 68},
  [735] = {.lex_state = 69},
  [736] = {.lex_state = 68},
  [737] = {.lex_state = 91},
  [738] = {.lex_state = 70},
  [739] = {.lex_state = 86},
  [740] = {.lex_state = 69},
  [741] = {.lex_state = 71},
  [742] = {.lex_state = 70},
  [743] = {.lex_state = 91},
  [744] = {.lex_state = 69},
  [745] = {.lex_state = 86},
  [746] = {.lex_state = 91},
  [747] = {.lex_state = 68},
  [748] = {.lex_state = 91},
  [749] = {.lex_state = 72},
  [750] = {.lex_state = 91},
  [751] = {.lex_state = 68},
  [752] = {.lex_state = 71},
  [753] = {.lex_state = 69},
  [754] = {.lex_state = 86},
  [755] = {.lex_state = 34},
  [756] = {.lex_state = 72},
  [757] = {.lex_state = 69},
  [758] = {.lex_state = 34},
  [759] = {.lex_state = 51},
  [760] = {.lex_state = 34},
  [761] = {.lex_state = 34},
  [762] = {.lex_state = 50},
  [763] = {.lex_state = 50},
  [764] = {.lex_state = 50},
  [765] = {.lex_state = 34},
  [766] = {.lex_state = 34},
  [767] = {.lex_state = 69},
  [768] = {.lex_state = 69},
  [769] = {.lex_state = 50},
  [770] = {.lex_state = 69},
  [771] = {.lex_state = 51},
  [772] = {.lex_state = 72},
  [773] = {.lex_state = 34},
  [774] = {.lex_state = 72},
  [775] = {.lex_state = 50},
  [776] = {.lex_state = 50},
  [777] = {.lex_state = 71},
  [778] = {.lex_state = 71},
  [779] = {.lex_state = 50},
  [780] = {.lex_state = 50},
  [781] = {.lex_state = 34},
  [782] = {.lex_state = 50},
  [783] = {.lex_state = 50},
  [784] = {.lex_state = 34},
  [785] = {.lex_state = 51},
  [786] = {.lex_state = 34},
  [787] = {.lex_state = 71},
  [788] = {.lex_state = 50},
  [789] = {.lex_state = 71},
  [790] = {.lex_state = 51},
  [791] = {.lex_state = 51},
  [792] = {.lex_state = 34},
  [793] = {.lex_state = 51},
  [794] = {.lex_state = 51},
  [795] = {.lex_state = 34},
  [796] = {.lex_state = 72},
  [797] = {.lex_state = 50},
  [798] = {.lex_state = 51},
  [799] = {.lex_state = 50},
  [800] = {.lex_state = 51},
  [801] = {.lex_state = 57},
  [802] = {.lex_state = 57},
  [803] = {.lex_state = 69},
  [804] = {.lex_state = 57},
  [805] = {.lex_state = 57},
  [806] = {.lex_state = 57},
  [807] = {.lex_state = 57},
  [808] = {.lex_state = 57},
  [809] = {.lex_state = 69},
  [810] = {.lex_state = 57},
  [811] = {.lex_state = 57},
  [812] = {.lex_state = 59},
  [813] = {.lex_state = 69},
  [814] = {.lex_state = 57},
  [815] = {.lex_state = 57},
  [816] = {.lex_state = 69},
  [817] = {.lex_state = 69},
  [818] = {.lex_state = 57},
  [819] = {.lex_state = 57},
  [820] = {.lex_state = 57},
  [821] = {.lex_state = 60},
  [822] = {.lex_state = 60},
  [823] = {.lex_state = 60},
  [824] = {.lex_state = 60},
  [825] = {.lex_state = 60},
  [826] = {.lex_state = 60},
  [827] = {.lex_state = 60},
  [828] = {.lex_state = 60},
  [829] = {.lex_state = 60},
  [830] = {.lex_state = 60},
  [831] = {.lex_state = 60},
  [832] = {.lex_state = 60},
  [833] = {.lex_state = 60},
  [834] = {.lex_state = 58},
  [835] = {.lex_state = 74},
  [836] = {.lex_state = 74},
  [837] = {.lex_state = 46},
  [838] = {.lex_state = 58},
  [839] = {.lex_state = 74},
  [840] = {.lex_state = 46},
  [841] = {.lex_state = 74},
  [842] = {.lex_state = 83},
  [843] = {.lex_state = 83},
  [844] = {.lex_state = 83},
  [845] = {.lex_state = 75},
  [846] = {.lex_state = 75},
  [847] = {.lex_state = 85},
  [848] = {.lex_state = 85},
  [849] = {.lex_state = 85},
  [850] = {.lex_state = 85},
  [851] = {.lex_state = 85},
  [852] = {.lex_state = 83},
  [853] = {.lex_state = 83},
  [854] = {.lex_state = 75},
  [855] = {.lex_state = 83},
  [856] = {.lex_state = 85},
  [857] = {.lex_state = 85},
  [858] = {.lex_state = 85},
  [859] = {.lex_state = 85},
  [860] = {.lex_state = 83},
  [861] = {.lex_state = 75},
  [862] = {.lex_state = 85},
  [863] = {.lex_state = 83},
  [864] = {.lex_state = 85},
  [865] = {.lex_state = 75},
  [866] = {.lex_state = 75},
  [867] = {.lex_state = 83},
  [868] = {.lex_state = 83},
  [869] = {.lex_state = 85},
  [870] = {.lex_state = 83},
  [871] = {.lex_state = 83},
  [872] = {.lex_state = 83},
  [873] = {.lex_state = 85},
  [874] = {.lex_state = 75},
  [875] = {.lex_state = 83},
  [876] = {.lex_state = 83},
  [877] = {.lex_state = 85},
  [878] = {.lex_state = 75},
  [879] = {.lex_state = 85},
  [880] = {.lex_state = 47},
  [881] = {.lex_state = 84},
  [882] = {.lex_state = 2},
  [883] = {.lex_state = 47},
  [884] = {.lex_state = 47},
  [885] = {.lex_state = 86},
  [886] = {.lex_state = 47},
  [887] = {.lex_state = 57},
  [888] = {.lex_state = 86},
  [889] = {.lex_state = 57},
  [890] = {.lex_state = 47},
  [891] = {.lex_state = 89},
  [892] = {.lex_state = 62},
  [893] = {.lex_state = 89},
  [894] = {.lex_state = 47},
  [895] = {.lex_state = 62},
  [896] = {.lex_state = 86},
  [897] = {.lex_state = 70},
  [898] = {.lex_state = 89},
  [899] = {.lex_state = 57},
  [900] = {.lex_state = 70},
  [901] = {.lex_state = 89},
  [902] = {.lex_state = 89},
  [903] = {.lex_state = 86},
  [904] = {.lex_state = 86},
  [905] = {.lex_state = 84},
  [906] = {.lex_state = 86},
  [907] = {.lex_state = 84},
  [908] = {.lex_state = 86},
  [909] = {.lex_state = 86},
  [910] = {.lex_state = 86},
  [911] = {.lex_state = 57},
  [912] = {.lex_state = 84},
  [913] = {.lex_state = 84},
  [914] = {.lex_state = 89},
  [915] = {.lex_state = 69},
  [916] = {.lex_state = 69},
  [917] = {.lex_state = 62},
  [918] = {.lex_state = 84},
  [919] = {.lex_state = 84},
  [920] = {.lex_state = 86},
  [921] = {.lex_state = 84},
  [922] = {.lex_state = 62},
  [923] = {.lex_state = 84},
  [924] = {.lex_state = 84},
  [925] = {.lex_state = 89},
  [926] = {.lex_state = 89},
  [927] = {.lex_state = 57},
  [928] = {.lex_state = 89},
  [929] = {.lex_state = 62},
  [930] = {.lex_state = 89},
  [931] = {.lex_state = 62},
  [932] = {.lex_state = 57},
  [933] = {.lex_state = 62},
  [934] = {.lex_state = 84},
  [935] = {.lex_state = 62},
  [936] = {.lex_state = 84},
  [937] = {.lex_state = 47},
  [938] = {.lex_state = 89},
  [939] = {.lex_state = 84},
  [940] = {.lex_state = 89},
  [941] = {.lex_state = 89},
  [942] = {.lex_state = 47},
  [943] = {.lex_state = 84},
  [944] = {.lex_state = 86},
  [945] = {.lex_state = 84},
  [946] = {.lex_state = 89},
  [947] = {.lex_state = 89},
  [948] = {.lex_state = 86},
  [949] = {.lex_state = 2},
  [950] = {.lex_state = 86},
  [951] = {.lex_state = 86},
  [952] = {.lex_state = 86},
  [953] = {.lex_state = 91},
  [954] = {.lex_state = 62},
  [955] = {.lex_state = 68},
  [956] = {.lex_state = 60},
  [957] = {.lex_state = 62},
  [958] = {.lex_state = 62},
  [959] = {.lex_state = 62},
  [960] = {.lex_state = 62},
  [961] = {.lex_state = 91},
  [962] = {.lex_state = 62},
  [963] = {.lex_state = 62},
  [964] = {.lex_state = 62},
  [965] = {.lex_state = 68},
  [966] = {.lex_state = 91},
  [967] = {.lex_state = 91},
  [968] = {.lex_state = 62},
  [969] = {.lex_state = 62},
  [970] = {.lex_state = 62},
  [971] = {.lex_state = 62},
  [972] = {.lex_state = 62},
  [973] = {.lex_state = 62},
  [974] = {.lex_state = 68},
  [975] = {.lex_state = 62},
  [976] = {.lex_state = 62},
  [977] = {.lex_state = 68},
  [978] = {.lex_state = 62},
  [979] = {.lex_state = 62},
  [980] = {.lex_state = 68},
  [981] = {.lex_state = 68},
  [982] = {.lex_state = 91},
  [983] = {.lex_state = 91},
  [984] = {.lex_state = 68},
  [985] = {.lex_state = 68},
  [986] = {.lex_state = 57},
  [987] = {.lex_state = 91},
  [988] = {.lex_state = 62},
  [989] = {.lex_state = 62},
  [990] = {.lex_state = 60},
  [991] = {.lex_state = 68},
  [992] = {.lex_state = 91},
  [993] = {.lex_state = 71},
  [994] = {.lex_state = 71},
  [995] = {.lex_state = 62},
  [996] = {.lex_state = 91},
  [997] = {.lex_state = 62},
  [998] = {.lex_state = 68},
  [999] = {.lex_state = 62},
  [1000] = {.lex_state = 91},
  [1001] = {.lex_state = 62},
  [1002] = {.lex_state = 72},
  [1003] = {.lex_state = 72},
  [1004] = {.lex_state = 36},
  [1005] = {.lex_state = 36},
  [1006] = {.lex_state = 36},
  [1007] = {.lex_state = 36},
  [1008] = {.lex_state = 36},
  [1009] = {.lex_state = 36},
  [1010] = {.lex_state = 57},
  [1011] = {.lex_state = 57},
  [1012] = {.lex_state = 36},
  [1013] = {.lex_state = 57},
  [1014] = {.lex_state = 57},
  [1015] = {.lex_state = 57},
  [1016] = {.lex_state = 57},
  [1017] = {.lex_state = 36},
  [1018] = {.lex_state = 57},
  [1019] = {.lex_state = 36},
  [1020] = {.lex_state = 62},
  [1021] = {.lex_state = 106},
  [1022] = {.lex_state = 57},
  [1023] = {.lex_state = 57},
  [1024] = {.lex_state = 57},
  [1025] = {.lex_state = 57},
  [1026] = {.lex_state = 57},
  [1027] = {.lex_state = 57},
  [1028] = {.lex_state = 57},
  [1029] = {.lex_state = 36},
  [1030] = {.lex_state = 57},
  [1031] = {.lex_state = 57},
  [1032] = {.lex_state = 57},
  [1033] = {.lex_state = 57},
  [1034] = {.lex_state = 36},
  [1035] = {.lex_state = 57},
  [1036] = {.lex_state = 57},
  [1037] = {.lex_state = 57},
  [1038] = {.lex_state = 36},
  [1039] = {.lex_state = 36},
  [1040] = {.lex_state = 106},
  [1041] = {.lex_state = 36},
  [1042] = {.lex_state = 36},
  [1043] = {.lex_state = 106},
  [1044] = {.lex_state = 36},
  [1045] = {.lex_state = 36},
  [1046] = {.lex_state = 36},
  [1047] = {.lex_state = 36},
  [1048] = {.lex_state = 36},
  [1049] = {.lex_state = 36},
  [1050] = {.lex_state = 36},
  [1051] = {.lex_state = 106},
  [1052] = {.lex_state = 106},
  [1053] = {.lex_state = 36},
  [1054] = {.lex_state = 36},
  [1055] = {.lex_state = 36},
  [1056] = {.lex_state = 36},
  [1057] = {.lex_state = 36},
  [1058] = {.lex_state = 57},
  [1059] = {.lex_state = 36},
  [1060] = {.lex_state = 36},
  [1061] = {.lex_state = 36},
  [1062] = {.lex_state = 70},
  [1063] = {.lex_state = 106},
  [1064] = {.lex_state = 70},
  [1065] = {.lex_state = 70},
  [1066] = {.lex_state = 65},
  [1067] = {.lex_state = 59},
  [1068] = {.lex_state = 62},
  [1069] = {.lex_state = 59},
  [1070] = {.lex_state = 70},
  [1071] = {.lex_state = 70},
  [1072] = {.lex_state = 70},
  [1073] = {.lex_state = 70},
  [1074] = {.lex_state = 62},
  [1075] = {.lex_state = 70},
  [1076] = {.lex_state = 65},
  [1077] = {.lex_state = 65},
  [1078] = {.lex_state = 78},
  [1079] = {.lex_state = 78},
  [1080] = {.lex_state = 65},
  [1081] = {.lex_state = 62},
  [1082] = {.lex_state = 62},
  [1083] = {.lex_state = 62},
  [1084] = {.lex_state = 71},
  [1085] = {.lex_state = 106},
  [1086] = {.lex_state = 62},
  [1087] = {.lex_state = 62},
  [1088] = {.lex_state = 62},
  [1089] = {.lex_state = 57},
  [1090] = {.lex_state = 62},
  [1091] = {.lex_state = 57},
  [1092] = {.lex_state = 62},
  [1093] = {.lex_state = 62},
  [1094] = {.lex_state = 62},
  [1095] = {.lex_state = 106},
  [1096] = {.lex_state = 106},
  [1097] = {.lex_state = 106},
  [1098] = {.lex_state = 48},
  [1099] = {.lex_state = 0},
  [1100] = {.lex_state = 106},
  [1101] = {.lex_state = 62},
  [1102] = {.lex_state = 57},
  [1103] = {.lex_state = 62},
  [1104] = {.lex_state = 106},
  [1105] = {.lex_state = 62},
  [1106] = {.lex_state = 62},
  [1107] = {.lex_state = 62},
  [1108] = {.lex_state = 106},
  [1109] = {.lex_state = 62},
  [1110] = {.lex_state = 62},
  [1111] = {.lex_state = 57},
  [1112] = {.lex_state = 106},
  [1113] = {.lex_state = 62},
  [1114] = {.lex_state = 62},
  [1115] = {.lex_state = 106},
  [1116] = {.lex_state = 62},
  [1117] = {.lex_state = 62},
  [1118] = {.lex_state = 62},
  [1119] = {.lex_state = 0},
  [1120] = {.lex_state = 62},
  [1121] = {.lex_state = 62},
  [1122] = {.lex_state = 62},
  [1123] = {.lex_state = 106},
  [1124] = {.lex_state = 106},
  [1125] = {.lex_state = 62},
  [1126] = {.lex_state = 62},
  [1127] = {.lex_state = 57},
  [1128] = {.lex_state = 62},
  [1129] = {.lex_state = 106},
  [1130] = {.lex_state = 62},
  [1131] = {.lex_state = 57},
  [1132] = {.lex_state = 62},
  [1133] = {.lex_state = 62},
  [1134] = {.lex_state = 62},
  [1135] = {.lex_state = 106},
  [1136] = {.lex_state = 57},
  [1137] = {.lex_state = 0},
  [1138] = {.lex_state = 57},
  [1139] = {.lex_state = 106},
  [1140] = {.lex_state = 106},
  [1141] = {.lex_state = 57},
  [1142] = {.lex_state = 0},
  [1143] = {.lex_state = 106},
  [1144] = {.lex_state = 62},
  [1145] = {.lex_state = 62},
  [1146] = {.lex_state = 106},
  [1147] = {.lex_state = 106},
  [1148] = {.lex_state = 106},
  [1149] = {.lex_state = 106},
  [1150] = {.lex_state = 62},
  [1151] = {.lex_state = 62},
  [1152] = {.lex_state = 62},
  [1153] = {.lex_state = 62},
  [1154] = {.lex_state = 106},
  [1155] = {.lex_state = 62},
  [1156] = {.lex_state = 62},
  [1157] = {.lex_state = 62},
  [1158] = {.lex_state = 62},
  [1159] = {.lex_state = 106},
  [1160] = {.lex_state = 0},
  [1161] = {.lex_state = 62},
  [1162] = {.lex_state = 106},
  [1163] = {.lex_state = 62},
  [1164] = {.lex_state = 106},
  [1165] = {.lex_state = 106},
  [1166] = {.lex_state = 62},
  [1167] = {.lex_state = 62},
  [1168] = {.lex_state = 62},
  [1169] = {.lex_state = 106},
  [1170] = {.lex_state = 106},
  [1171] = {.lex_state = 62},
  [1172] = {.lex_state = 62},
  [1173] = {.lex_state = 0},
  [1174] = {.lex_state = 106},
  [1175] = {.lex_state = 106},
  [1176] = {.lex_state = 62},
  [1177] = {.lex_state = 62},
  [1178] = {.lex_state = 57},
  [1179] = {.lex_state = 62},
  [1180] = {.lex_state = 106},
  [1181] = {.lex_state = 62},
  [1182] = {.lex_state = 62},
  [1183] = {.lex_state = 62},
  [1184] = {.lex_state = 62},
  [1185] = {.lex_state = 62},
  [1186] = {.lex_state = 106},
  [1187] = {.lex_state = 62},
  [1188] = {.lex_state = 62},
  [1189] = {.lex_state = 62},
  [1190] = {.lex_state = 62},
  [1191] = {.lex_state = 0},
  [1192] = {.lex_state = 62},
  [1193] = {.lex_state = 106},
  [1194] = {.lex_state = 106},
  [1195] = {.lex_state = 106},
  [1196] = {.lex_state = 106},
  [1197] = {.lex_state = 62},
  [1198] = {.lex_state = 62},
  [1199] = {.lex_state = 62},
  [1200] = {.lex_state = 57},
  [1201] = {.lex_state = 62},
  [1202] = {.lex_state = 106},
  [1203] = {.lex_state = 106},
  [1204] = {.lex_state = 62},
  [1205] = {.lex_state = 0},
  [1206] = {.lex_state = 106},
  [1207] = {.lex_state = 106},
  [1208] = {.lex_state = 62},
  [1209] = {.lex_state = 106},
  [1210] = {.lex_state = 62},
  [1211] = {.lex_state = 106},
  [1212] = {.lex_state = 106},
  [1213] = {.lex_state = 0},
  [1214] = {.lex_state = 106},
  [1215] = {.lex_state = 106},
  [1216] = {.lex_state = 106},
  [1217] = {.lex_state = 62},
  [1218] = {.lex_state = 62},
  [1219] = {.lex_state = 62},
  [1220] = {.lex_state = 62},
  [1221] = {.lex_state = 57},
  [1222] = {.lex_state = 62},
  [1223] = {.lex_state = 62},
  [1224] = {.lex_state = 106},
  [1225] = {.lex_state = 106},
  [1226] = {.lex_state = 0},
  [1227] = {.lex_state = 62},
  [1228] = {.lex_state = 106},
  [1229] = {.lex_state = 62},
  [1230] = {.lex_state = 106},
  [1231] = {.lex_state = 106},
  [1232] = {.lex_state = 48},
  [1233] = {.lex_state = 62},
  [1234] = {.lex_state = 62},
  [1235] = {.lex_state = 62},
  [1236] = {.lex_state = 57},
  [1237] = {.lex_state = 62},
  [1238] = {.lex_state = 57},
  [1239] = {.lex_state = 62},
  [1240] = {.lex_state = 62},
  [1241] = {.lex_state = 62},
  [1242] = {.lex_state = 62},
  [1243] = {.lex_state = 62},
  [1244] = {.lex_state = 48},
  [1245] = {.lex_state = 62},
  [1246] = {.lex_state = 62},
  [1247] = {.lex_state = 62},
  [1248] = {.lex_state = 62},
  [1249] = {.lex_state = 106},
  [1250] = {.lex_state = 106},
  [1251] = {.lex_state = 62},
  [1252] = {.lex_state = 62},
  [1253] = {.lex_state = 62},
  [1254] = {.lex_state = 0},
  [1255] = {.lex_state = 106},
  [1256] = {.lex_state = 62},
  [1257] = {.lex_state = 62},
  [1258] = {.lex_state = 106},
  [1259] = {.lex_state = 57},
  [1260] = {.lex_state = 106},
  [1261] = {.lex_state = 62},
  [1262] = {.lex_state = 62},
  [1263] = {.lex_state = 57},
  [1264] = {.lex_state = 62},
  [1265] = {.lex_state = 106},
  [1266] = {.lex_state = 48},
  [1267] = {.lex_state = 62},
  [1268] = {.lex_state = 62},
  [1269] = {.lex_state = 62},
  [1270] = {.lex_state = 62},
  [1271] = {.lex_state = 62},
  [1272] = {.lex_state = 106},
  [1273] = {.lex_state = 62},
  [1274] = {.lex_state = 106},
  [1275] = {.lex_state = 62},
  [1276] = {.lex_state = 62},
  [1277] = {.lex_state = 62},
  [1278] = {.lex_state = 62},
  [1279] = {.lex_state = 62},
  [1280] = {.lex_state = 0},
  [1281] = {.lex_state = 62},
  [1282] = {.lex_state = 57},
  [1283] = {.lex_state = 62},
  [1284] = {.lex_state = 57},
  [1285] = {.lex_state = 62},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_word] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_AMP_COLON] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_VPATH] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_COLON_COLON_EQ] = ACTIONS(1),
    [anon_sym_QMARK_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_define] = ACTIONS(1),
    [anon_sym_endef] = ACTIONS(1),
    [anon_sym_include] = ACTIONS(1),
    [anon_sym_sinclude] = ACTIONS(1),
    [anon_sym_DASHinclude] = ACTIONS(1),
    [anon_sym_vpath] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_unexport] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [anon_sym_undefine] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_endif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_ifeq] = ACTIONS(1),
    [anon_sym_ifneq] = ACTIONS(1),
    [anon_sym_ifdef] = ACTIONS(1),
    [anon_sym_ifndef] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_AT2] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_PLUS2] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_PERCENT2] = ACTIONS(1),
    [anon_sym_LT2] = ACTIONS(1),
    [anon_sym_QMARK2] = ACTIONS(1),
    [anon_sym_CARET2] = ACTIONS(1),
    [anon_sym_SLASH2] = ACTIONS(1),
    [anon_sym_STAR2] = ACTIONS(1),
    [anon_sym_D] = ACTIONS(1),
    [anon_sym_F] = ACTIONS(1),
    [anon_sym_subst] = ACTIONS(1),
    [anon_sym_patsubst] = ACTIONS(1),
    [anon_sym_strip] = ACTIONS(1),
    [anon_sym_findstring] = ACTIONS(1),
    [anon_sym_filter] = ACTIONS(1),
    [anon_sym_filter_DASHout] = ACTIONS(1),
    [anon_sym_sort] = ACTIONS(1),
    [anon_sym_word] = ACTIONS(1),
    [anon_sym_words] = ACTIONS(1),
    [anon_sym_wordlist] = ACTIONS(1),
    [anon_sym_firstword] = ACTIONS(1),
    [anon_sym_lastword] = ACTIONS(1),
    [anon_sym_dir] = ACTIONS(1),
    [anon_sym_notdir] = ACTIONS(1),
    [anon_sym_suffix] = ACTIONS(1),
    [anon_sym_basename] = ACTIONS(1),
    [anon_sym_addsuffix] = ACTIONS(1),
    [anon_sym_addprefix] = ACTIONS(1),
    [anon_sym_join] = ACTIONS(1),
    [anon_sym_wildcard] = ACTIONS(1),
    [anon_sym_realpath] = ACTIONS(1),
    [anon_sym_abspath] = ACTIONS(1),
    [anon_sym_error] = ACTIONS(1),
    [anon_sym_warning] = ACTIONS(1),
    [anon_sym_info] = ACTIONS(1),
    [anon_sym_origin] = ACTIONS(1),
    [anon_sym_flavor] = ACTIONS(1),
    [anon_sym_foreach] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_call] = ACTIONS(1),
    [anon_sym_eval] = ACTIONS(1),
    [anon_sym_file] = ACTIONS(1),
    [anon_sym_value] = ACTIONS(1),
    [anon_sym_shell] = ACTIONS(1),
    [anon_sym_COLON2] = ACTIONS(1),
    [anon_sym_SEMI2] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_RPAREN2] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_makefile] = STATE(1280),
    [sym__thing] = STATE(26),
    [sym_rule] = STATE(26),
    [sym__ordinary_rule] = STATE(288),
    [sym__static_pattern_rule] = STATE(285),
    [sym__variable_definition] = STATE(26),
    [sym_VPATH_assignment] = STATE(26),
    [sym_RECIPEPREFIX_assignment] = STATE(26),
    [sym_variable_assignment] = STATE(26),
    [sym_shell_assignment] = STATE(26),
    [sym_define_directive] = STATE(26),
    [sym__directive] = STATE(26),
    [sym_include_directive] = STATE(26),
    [sym_vpath_directive] = STATE(26),
    [sym_export_directive] = STATE(26),
    [sym_unexport_directive] = STATE(26),
    [sym_override_directive] = STATE(26),
    [sym_undefine_directive] = STATE(26),
    [sym_private_directive] = STATE(26),
    [sym_conditional] = STATE(26),
    [sym__conditional_directives] = STATE(3),
    [sym_ifeq_directive] = STATE(3),
    [sym_ifneq_directive] = STATE(3),
    [sym_ifdef_directive] = STATE(3),
    [sym_ifndef_directive] = STATE(3),
    [sym__variable] = STATE(201),
    [sym_variable_reference] = STATE(201),
    [sym_substitution_reference] = STATE(201),
    [sym_automatic_variable] = STATE(201),
    [sym__function] = STATE(198),
    [sym_function_call] = STATE(198),
    [sym_shell_function] = STATE(198),
    [sym_list] = STATE(1052),
    [sym_concatenation] = STATE(201),
    [sym_string] = STATE(201),
    [sym_archive] = STATE(201),
    [aux_sym_makefile_repeat1] = STATE(26),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_word] = ACTIONS(7),
    [anon_sym_VPATH] = ACTIONS(9),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(11),
    [anon_sym_define] = ACTIONS(13),
    [anon_sym_include] = ACTIONS(15),
    [anon_sym_sinclude] = ACTIONS(15),
    [anon_sym_DASHinclude] = ACTIONS(15),
    [anon_sym_vpath] = ACTIONS(17),
    [anon_sym_export] = ACTIONS(19),
    [anon_sym_unexport] = ACTIONS(21),
    [anon_sym_override] = ACTIONS(23),
    [anon_sym_undefine] = ACTIONS(25),
    [anon_sym_private] = ACTIONS(27),
    [anon_sym_ifeq] = ACTIONS(29),
    [anon_sym_ifneq] = ACTIONS(31),
    [anon_sym_ifdef] = ACTIONS(33),
    [anon_sym_ifndef] = ACTIONS(35),
    [anon_sym_DOLLAR] = ACTIONS(37),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(39),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_SQUOTE] = ACTIONS(43),
    [sym_comment] = ACTIONS(3),
  },
  [2] = {
    [sym__thing] = STATE(6),
    [sym_rule] = STATE(6),
    [sym__ordinary_rule] = STATE(125),
    [sym__static_pattern_rule] = STATE(126),
    [sym__prefixed_recipe_line] = STATE(6),
    [sym__variable_definition] = STATE(6),
    [sym_VPATH_assignment] = STATE(6),
    [sym_RECIPEPREFIX_assignment] = STATE(6),
    [sym_variable_assignment] = STATE(6),
    [sym_shell_assignment] = STATE(6),
    [sym_define_directive] = STATE(6),
    [sym__directive] = STATE(6),
    [sym_include_directive] = STATE(6),
    [sym_vpath_directive] = STATE(6),
    [sym_export_directive] = STATE(6),
    [sym_unexport_directive] = STATE(6),
    [sym_override_directive] = STATE(6),
    [sym_undefine_directive] = STATE(6),
    [sym_private_directive] = STATE(6),
    [sym_conditional] = STATE(6),
    [sym_elsif_directive] = STATE(932),
    [sym_else_directive] = STATE(1131),
    [sym__conditional_directives] = STATE(5),
    [aux_sym__conditional_consequence] = STATE(6),
    [sym_ifeq_directive] = STATE(5),
    [sym_ifneq_directive] = STATE(5),
    [sym_ifdef_directive] = STATE(5),
    [sym_ifndef_directive] = STATE(5),
    [sym__variable] = STATE(201),
    [sym_variable_reference] = STATE(201),
    [sym_substitution_reference] = STATE(201),
    [sym_automatic_variable] = STATE(201),
    [sym__function] = STATE(217),
    [sym_function_call] = STATE(217),
    [sym_shell_function] = STATE(217),
    [sym_list] = STATE(1040),
    [sym_concatenation] = STATE(201),
    [sym_string] = STATE(201),
    [sym_archive] = STATE(201),
    [aux_sym_conditional_repeat1] = STATE(932),
    [sym_word] = ACTIONS(45),
    [anon_sym_VPATH] = ACTIONS(47),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(49),
    [anon_sym_define] = ACTIONS(51),
    [anon_sym_include] = ACTIONS(53),
    [anon_sym_sinclude] = ACTIONS(53),
    [anon_sym_DASHinclude] = ACTIONS(53),
    [anon_sym_vpath] = ACTIONS(55),
    [anon_sym_export] = ACTIONS(57),
    [anon_sym_unexport] = ACTIONS(59),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_undefine] = ACTIONS(63),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_endif] = ACTIONS(67),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_ifeq] = ACTIONS(29),
    [anon_sym_ifneq] = ACTIONS(31),
    [anon_sym_ifdef] = ACTIONS(33),
    [anon_sym_ifndef] = ACTIONS(35),
    [anon_sym_DOLLAR] = ACTIONS(37),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(73),
    [sym__recipeprefix] = ACTIONS(75),
    [sym_comment] = ACTIONS(77),
  },
  [3] = {
    [sym__thing] = STATE(4),
    [sym_rule] = STATE(4),
    [sym__ordinary_rule] = STATE(125),
    [sym__static_pattern_rule] = STATE(126),
    [sym__prefixed_recipe_line] = STATE(4),
    [sym__variable_definition] = STATE(4),
    [sym_VPATH_assignment] = STATE(4),
    [sym_RECIPEPREFIX_assignment] = STATE(4),
    [sym_variable_assignment] = STATE(4),
    [sym_shell_assignment] = STATE(4),
    [sym_define_directive] = STATE(4),
    [sym__directive] = STATE(4),
    [sym_include_directive] = STATE(4),
    [sym_vpath_directive] = STATE(4),
    [sym_export_directive] = STATE(4),
    [sym_unexport_directive] = STATE(4),
    [sym_override_directive] = STATE(4),
    [sym_undefine_directive] = STATE(4),
    [sym_private_directive] = STATE(4),
    [sym_conditional] = STATE(4),
    [sym_elsif_directive] = STATE(911),
    [sym_else_directive] = STATE(1259),
    [sym__conditional_directives] = STATE(5),
    [aux_sym__conditional_consequence] = STATE(4),
    [sym_ifeq_directive] = STATE(5),
    [sym_ifneq_directive] = STATE(5),
    [sym_ifdef_directive] = STATE(5),
    [sym_ifndef_directive] = STATE(5),
    [sym__variable] = STATE(201),
    [sym_variable_reference] = STATE(201),
    [sym_substitution_reference] = STATE(201),
    [sym_automatic_variable] = STATE(201),
    [sym__function] = STATE(217),
    [sym_function_call] = STATE(217),
    [sym_shell_function] = STATE(217),
    [sym_list] = STATE(1040),
    [sym_concatenation] = STATE(201),
    [sym_string] = STATE(201),
    [sym_archive] = STATE(201),
    [aux_sym_conditional_repeat1] = STATE(911),
    [sym_word] = ACTIONS(45),
    [anon_sym_VPATH] = ACTIONS(47),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(49),
    [anon_sym_define] = ACTIONS(51),
    [anon_sym_include] = ACTIONS(53),
    [anon_sym_sinclude] = ACTIONS(53),
    [anon_sym_DASHinclude] = ACTIONS(53),
    [anon_sym_vpath] = ACTIONS(55),
    [anon_sym_export] = ACTIONS(57),
    [anon_sym_unexport] = ACTIONS(59),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_undefine] = ACTIONS(63),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_endif] = ACTIONS(79),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_ifeq] = ACTIONS(29),
    [anon_sym_ifneq] = ACTIONS(31),
    [anon_sym_ifdef] = ACTIONS(33),
    [anon_sym_ifndef] = ACTIONS(35),
    [anon_sym_DOLLAR] = ACTIONS(37),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(73),
    [sym__recipeprefix] = ACTIONS(75),
    [sym_comment] = ACTIONS(77),
  },
  [4] = {
    [sym__thing] = STATE(10),
    [sym_rule] = STATE(10),
    [sym__ordinary_rule] = STATE(125),
    [sym__static_pattern_rule] = STATE(126),
    [sym__prefixed_recipe_line] = STATE(10),
    [sym__variable_definition] = STATE(10),
    [sym_VPATH_assignment] = STATE(10),
    [sym_RECIPEPREFIX_assignment] = STATE(10),
    [sym_variable_assignment] = STATE(10),
    [sym_shell_assignment] = STATE(10),
    [sym_define_directive] = STATE(10),
    [sym__directive] = STATE(10),
    [sym_include_directive] = STATE(10),
    [sym_vpath_directive] = STATE(10),
    [sym_export_directive] = STATE(10),
    [sym_unexport_directive] = STATE(10),
    [sym_override_directive] = STATE(10),
    [sym_undefine_directive] = STATE(10),
    [sym_private_directive] = STATE(10),
    [sym_conditional] = STATE(10),
    [sym_elsif_directive] = STATE(927),
    [sym_else_directive] = STATE(1238),
    [sym__conditional_directives] = STATE(5),
    [aux_sym__conditional_consequence] = STATE(10),
    [sym_ifeq_directive] = STATE(5),
    [sym_ifneq_directive] = STATE(5),
    [sym_ifdef_directive] = STATE(5),
    [sym_ifndef_directive] = STATE(5),
    [sym__variable] = STATE(201),
    [sym_variable_reference] = STATE(201),
    [sym_substitution_reference] = STATE(201),
    [sym_automatic_variable] = STATE(201),
    [sym__function] = STATE(217),
    [sym_function_call] = STATE(217),
    [sym_shell_function] = STATE(217),
    [sym_list] = STATE(1040),
    [sym_concatenation] = STATE(201),
    [sym_string] = STATE(201),
    [sym_archive] = STATE(201),
    [aux_sym_conditional_repeat1] = STATE(927),
    [sym_word] = ACTIONS(45),
    [anon_sym_VPATH] = ACTIONS(47),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(49),
    [anon_sym_define] = ACTIONS(51),
    [anon_sym_include] = ACTIONS(53),
    [anon_sym_sinclude] = ACTIONS(53),
    [anon_sym_DASHinclude] = ACTIONS(53),
    [anon_sym_vpath] = ACTIONS(55),
    [anon_sym_export] = ACTIONS(57),
    [anon_sym_unexport] = ACTIONS(59),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_undefine] = ACTIONS(63),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_endif] = ACTIONS(81),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_ifeq] = ACTIONS(29),
    [anon_sym_ifneq] = ACTIONS(31),
    [anon_sym_ifdef] = ACTIONS(33),
    [anon_sym_ifndef] = ACTIONS(35),
    [anon_sym_DOLLAR] = ACTIONS(37),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(73),
    [sym__recipeprefix] = ACTIONS(75),
    [sym_comment] = ACTIONS(77),
  },
  [5] = {
    [sym__thing] = STATE(7),
    [sym_rule] = STATE(7),
    [sym__ordinary_rule] = STATE(125),
    [sym__static_pattern_rule] = STATE(126),
    [sym__prefixed_recipe_line] = STATE(7),
    [sym__variable_definition] = STATE(7),
    [sym_VPATH_assignment] = STATE(7),
    [sym_RECIPEPREFIX_assignment] = STATE(7),
    [sym_variable_assignment] = STATE(7),
    [sym_shell_assignment] = STATE(7),
    [sym_define_directive] = STATE(7),
    [sym__directive] = STATE(7),
    [sym_include_directive] = STATE(7),
    [sym_vpath_directive] = STATE(7),
    [sym_export_directive] = STATE(7),
    [sym_unexport_directive] = STATE(7),
    [sym_override_directive] = STATE(7),
    [sym_undefine_directive] = STATE(7),
    [sym_private_directive] = STATE(7),
    [sym_conditional] = STATE(7),
    [sym_elsif_directive] = STATE(889),
    [sym_else_directive] = STATE(1127),
    [sym__conditional_directives] = STATE(5),
    [aux_sym__conditional_consequence] = STATE(7),
    [sym_ifeq_directive] = STATE(5),
    [sym_ifneq_directive] = STATE(5),
    [sym_ifdef_directive] = STATE(5),
    [sym_ifndef_directive] = STATE(5),
    [sym__variable] = STATE(201),
    [sym_variable_reference] = STATE(201),
    [sym_substitution_reference] = STATE(201),
    [sym_automatic_variable] = STATE(201),
    [sym__function] = STATE(217),
    [sym_function_call] = STATE(217),
    [sym_shell_function] = STATE(217),
    [sym_list] = STATE(1040),
    [sym_concatenation] = STATE(201),
    [sym_string] = STATE(201),
    [sym_archive] = STATE(201),
    [aux_sym_conditional_repeat1] = STATE(889),
    [sym_word] = ACTIONS(45),
    [anon_sym_VPATH] = ACTIONS(47),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(49),
    [anon_sym_define] = ACTIONS(51),
    [anon_sym_include] = ACTIONS(53),
    [anon_sym_sinclude] = ACTIONS(53),
    [anon_sym_DASHinclude] = ACTIONS(53),
    [anon_sym_vpath] = ACTIONS(55),
    [anon_sym_export] = ACTIONS(57),
    [anon_sym_unexport] = ACTIONS(59),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_undefine] = ACTIONS(63),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_endif] = ACTIONS(83),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_ifeq] = ACTIONS(29),
    [anon_sym_ifneq] = ACTIONS(31),
    [anon_sym_ifdef] = ACTIONS(33),
    [anon_sym_ifndef] = ACTIONS(35),
    [anon_sym_DOLLAR] = ACTIONS(37),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(73),
    [sym__recipeprefix] = ACTIONS(75),
    [sym_comment] = ACTIONS(77),
  },
  [6] = {
    [sym__thing] = STATE(10),
    [sym_rule] = STATE(10),
    [sym__ordinary_rule] = STATE(125),
    [sym__static_pattern_rule] = STATE(126),
    [sym__prefixed_recipe_line] = STATE(10),
    [sym__variable_definition] = STATE(10),
    [sym_VPATH_assignment] = STATE(10),
    [sym_RECIPEPREFIX_assignment] = STATE(10),
    [sym_variable_assignment] = STATE(10),
    [sym_shell_assignment] = STATE(10),
    [sym_define_directive] = STATE(10),
    [sym__directive] = STATE(10),
    [sym_include_directive] = STATE(10),
    [sym_vpath_directive] = STATE(10),
    [sym_export_directive] = STATE(10),
    [sym_unexport_directive] = STATE(10),
    [sym_override_directive] = STATE(10),
    [sym_undefine_directive] = STATE(10),
    [sym_private_directive] = STATE(10),
    [sym_conditional] = STATE(10),
    [sym_elsif_directive] = STATE(899),
    [sym_else_directive] = STATE(1136),
    [sym__conditional_directives] = STATE(5),
    [aux_sym__conditional_consequence] = STATE(10),
    [sym_ifeq_directive] = STATE(5),
    [sym_ifneq_directive] = STATE(5),
    [sym_ifdef_directive] = STATE(5),
    [sym_ifndef_directive] = STATE(5),
    [sym__variable] = STATE(201),
    [sym_variable_reference] = STATE(201),
    [sym_substitution_reference] = STATE(201),
    [sym_automatic_variable] = STATE(201),
    [sym__function] = STATE(217),
    [sym_function_call] = STATE(217),
    [sym_shell_function] = STATE(217),
    [sym_list] = STATE(1040),
    [sym_concatenation] = STATE(201),
    [sym_string] = STATE(201),
    [sym_archive] = STATE(201),
    [aux_sym_conditional_repeat1] = STATE(899),
    [sym_word] = ACTIONS(45),
    [anon_sym_VPATH] = ACTIONS(47),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(49),
    [anon_sym_define] = ACTIONS(51),
    [anon_sym_include] = ACTIONS(53),
    [anon_sym_sinclude] = ACTIONS(53),
    [anon_sym_DASHinclude] = ACTIONS(53),
    [anon_sym_vpath] = ACTIONS(55),
    [anon_sym_export] = ACTIONS(57),
    [anon_sym_unexport] = ACTIONS(59),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_undefine] = ACTIONS(63),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_endif] = ACTIONS(85),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_ifeq] = ACTIONS(29),
    [anon_sym_ifneq] = ACTIONS(31),
    [anon_sym_ifdef] = ACTIONS(33),
    [anon_sym_ifndef] = ACTIONS(35),
    [anon_sym_DOLLAR] = ACTIONS(37),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(73),
    [sym__recipeprefix] = ACTIONS(75),
    [sym_comment] = ACTIONS(77),
  },
  [7] = {
    [sym__thing] = STATE(10),
    [sym_rule] = STATE(10),
    [sym__ordinary_rule] = STATE(125),
    [sym__static_pattern_rule] = STATE(126),
    [sym__prefixed_recipe_line] = STATE(10),
    [sym__variable_definition] = STATE(10),
    [sym_VPATH_assignment] = STATE(10),
    [sym_RECIPEPREFIX_assignment] = STATE(10),
    [sym_variable_assignment] = STATE(10),
    [sym_shell_assignment] = STATE(10),
    [sym_define_directive] = STATE(10),
    [sym__directive] = STATE(10),
    [sym_include_directive] = STATE(10),
    [sym_vpath_directive] = STATE(10),
    [sym_export_directive] = STATE(10),
    [sym_unexport_directive] = STATE(10),
    [sym_override_directive] = STATE(10),
    [sym_undefine_directive] = STATE(10),
    [sym_private_directive] = STATE(10),
    [sym_conditional] = STATE(10),
    [sym_elsif_directive] = STATE(887),
    [sym_else_directive] = STATE(1089),
    [sym__conditional_directives] = STATE(5),
    [aux_sym__conditional_consequence] = STATE(10),
    [sym_ifeq_directive] = STATE(5),
    [sym_ifneq_directive] = STATE(5),
    [sym_ifdef_directive] = STATE(5),
    [sym_ifndef_directive] = STATE(5),
    [sym__variable] = STATE(201),
    [sym_variable_reference] = STATE(201),
    [sym_substitution_reference] = STATE(201),
    [sym_automatic_variable] = STATE(201),
    [sym__function] = STATE(217),
    [sym_function_call] = STATE(217),
    [sym_shell_function] = STATE(217),
    [sym_list] = STATE(1040),
    [sym_concatenation] = STATE(201),
    [sym_string] = STATE(201),
    [sym_archive] = STATE(201),
    [aux_sym_conditional_repeat1] = STATE(887),
    [sym_word] = ACTIONS(45),
    [anon_sym_VPATH] = ACTIONS(47),
    [anon_sym_DOTRECIPEPREFIX] = ACTIONS(49),
    [anon_sym_define] = ACTIONS(51),
    [anon_sym_include] = ACTIONS(53),
    [anon_sym_sinclude] = ACTIONS(53),
    [anon_sym_DASHinclude] = ACTIONS(53),
    [anon_sym_vpath] = ACTIONS(55),
    [anon_sym_export] = ACTIONS(57),
    [anon_sym_unexport] = ACTIONS(59),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_undefine] = ACTIONS(63),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_endif] = ACTIONS(87),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_ifeq] = ACTIONS(29),
    [anon_sym_ifneq] = ACTIONS(31),
    [anon_sym_ifdef] = ACTIONS(33),
    [anon_sym_ifndef] = ACTIONS(35),
    [anon_sym_DOLLAR] = ACTIONS(37),
    [anon_sym_DOLLAR_DOLLAR] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(73),
    [sym__recipeprefix] = ACTIONS(75),
    [sym_comment] = ACTIONS(77),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 28,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(45), 1,
      sym_word,
    ACTIONS(47), 1,
      anon_sym_VPATH,
    ACTIONS(49), 1,
      anon_sym_DOTRECIPEPREFIX,
    ACTIONS(51), 1,
      anon_sym_define,
    ACTIONS(55), 1,
      anon_sym_vpath,
    ACTIONS(57), 1,
      anon_sym_export,
    ACTIONS(59), 1,
      anon_sym_unexport,
    ACTIONS(61), 1,
      anon_sym_override,
    ACTIONS(63), 1,
      anon_sym_undefine,
    ACTIONS(65), 1,
      anon_sym_private,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(125), 1,
      sym__ordinary_rule,
    STATE(126), 1,
      sym__static_pattern_rule,
    STATE(1040), 1,
      sym_list,
    ACTIONS(37), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(89), 2,
      anon_sym_endif,
      anon_sym_else,
    ACTIONS(53), 3,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
    STATE(217), 3,
      sym__function,
      sym_function_call,
      sym_shell_function,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    STATE(201), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym_concatenation,
      sym_string,
      sym_archive,
    STATE(9), 19,
      sym__thing,
      sym_rule,
      sym__prefixed_recipe_line,
      sym__variable_definition,
      sym_VPATH_assignment,
      sym_RECIPEPREFIX_assignment,
      sym_variable_assignment,
      sym_shell_assignment,
      sym_define_directive,
      sym__directive,
      sym_include_directive,
      sym_vpath_directive,
      sym_export_directive,
      sym_unexport_directive,
      sym_override_directive,
      sym_undefine_directive,
      sym_private_directive,
      sym_conditional,
      aux_sym__conditional_consequence,
  [119] = 28,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(45), 1,
      sym_word,
    ACTIONS(47), 1,
      anon_sym_VPATH,
    ACTIONS(49), 1,
      anon_sym_DOTRECIPEPREFIX,
    ACTIONS(51), 1,
      anon_sym_define,
    ACTIONS(55), 1,
      anon_sym_vpath,
    ACTIONS(57), 1,
      anon_sym_export,
    ACTIONS(59), 1,
      anon_sym_unexport,
    ACTIONS(61), 1,
      anon_sym_override,
    ACTIONS(63), 1,
      anon_sym_undefine,
    ACTIONS(65), 1,
      anon_sym_private,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(125), 1,
      sym__ordinary_rule,
    STATE(126), 1,
      sym__static_pattern_rule,
    STATE(1040), 1,
      sym_list,
    ACTIONS(37), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(91), 2,
      anon_sym_endif,
      anon_sym_else,
    ACTIONS(53), 3,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
    STATE(217), 3,
      sym__function,
      sym_function_call,
      sym_shell_function,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    STATE(201), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym_concatenation,
      sym_string,
      sym_archive,
    STATE(10), 19,
      sym__thing,
      sym_rule,
      sym__prefixed_recipe_line,
      sym__variable_definition,
      sym_VPATH_assignment,
      sym_RECIPEPREFIX_assignment,
      sym_variable_assignment,
      sym_shell_assignment,
      sym_define_directive,
      sym__directive,
      sym_include_directive,
      sym_vpath_directive,
      sym_export_directive,
      sym_unexport_directive,
      sym_override_directive,
      sym_undefine_directive,
      sym_private_directive,
      sym_conditional,
      aux_sym__conditional_consequence,
  [238] = 28,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(93), 1,
      sym_word,
    ACTIONS(96), 1,
      anon_sym_VPATH,
    ACTIONS(99), 1,
      anon_sym_DOTRECIPEPREFIX,
    ACTIONS(102), 1,
      anon_sym_define,
    ACTIONS(108), 1,
      anon_sym_vpath,
    ACTIONS(111), 1,
      anon_sym_export,
    ACTIONS(114), 1,
      anon_sym_unexport,
    ACTIONS(117), 1,
      anon_sym_override,
    ACTIONS(120), 1,
      anon_sym_undefine,
    ACTIONS(123), 1,
      anon_sym_private,
    ACTIONS(128), 1,
      anon_sym_ifeq,
    ACTIONS(131), 1,
      anon_sym_ifneq,
    ACTIONS(134), 1,
      anon_sym_ifdef,
    ACTIONS(137), 1,
      anon_sym_ifndef,
    ACTIONS(143), 1,
      anon_sym_DQUOTE,
    ACTIONS(146), 1,
      anon_sym_SQUOTE,
    ACTIONS(149), 1,
      sym__recipeprefix,
    STATE(125), 1,
      sym__ordinary_rule,
    STATE(126), 1,
      sym__static_pattern_rule,
    STATE(1040), 1,
      sym_list,
    ACTIONS(126), 2,
      anon_sym_endif,
      anon_sym_else,
    ACTIONS(140), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(105), 3,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
    STATE(217), 3,
      sym__function,
      sym_function_call,
      sym_shell_function,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    STATE(201), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym_concatenation,
      sym_string,
      sym_archive,
    STATE(10), 19,
      sym__thing,
      sym_rule,
      sym__prefixed_recipe_line,
      sym__variable_definition,
      sym_VPATH_assignment,
      sym_RECIPEPREFIX_assignment,
      sym_variable_assignment,
      sym_shell_assignment,
      sym_define_directive,
      sym__directive,
      sym_include_directive,
      sym_vpath_directive,
      sym_export_directive,
      sym_unexport_directive,
      sym_override_directive,
      sym_undefine_directive,
      sym_private_directive,
      sym_conditional,
      aux_sym__conditional_consequence,
  [357] = 28,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(45), 1,
      sym_word,
    ACTIONS(47), 1,
      anon_sym_VPATH,
    ACTIONS(49), 1,
      anon_sym_DOTRECIPEPREFIX,
    ACTIONS(51), 1,
      anon_sym_define,
    ACTIONS(55), 1,
      anon_sym_vpath,
    ACTIONS(57), 1,
      anon_sym_export,
    ACTIONS(59), 1,
      anon_sym_unexport,
    ACTIONS(61), 1,
      anon_sym_override,
    ACTIONS(63), 1,
      anon_sym_undefine,
    ACTIONS(65), 1,
      anon_sym_private,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(152), 1,
      anon_sym_endif,
    STATE(125), 1,
      sym__ordinary_rule,
    STATE(126), 1,
      sym__static_pattern_rule,
    STATE(1040), 1,
      sym_list,
    ACTIONS(37), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(53), 3,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
    STATE(217), 3,
      sym__function,
      sym_function_call,
      sym_shell_function,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    STATE(201), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym_concatenation,
      sym_string,
      sym_archive,
    STATE(10), 19,
      sym__thing,
      sym_rule,
      sym__prefixed_recipe_line,
      sym__variable_definition,
      sym_VPATH_assignment,
      sym_RECIPEPREFIX_assignment,
      sym_variable_assignment,
      sym_shell_assignment,
      sym_define_directive,
      sym__directive,
      sym_include_directive,
      sym_vpath_directive,
      sym_export_directive,
      sym_unexport_directive,
      sym_override_directive,
      sym_undefine_directive,
      sym_private_directive,
      sym_conditional,
      aux_sym__conditional_consequence,
  [475] = 28,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(45), 1,
      sym_word,
    ACTIONS(47), 1,
      anon_sym_VPATH,
    ACTIONS(49), 1,
      anon_sym_DOTRECIPEPREFIX,
    ACTIONS(51), 1,
      anon_sym_define,
    ACTIONS(55), 1,
      anon_sym_vpath,
    ACTIONS(57), 1,
      anon_sym_export,
    ACTIONS(59), 1,
      anon_sym_unexport,
    ACTIONS(61), 1,
      anon_sym_override,
    ACTIONS(63), 1,
      anon_sym_undefine,
    ACTIONS(65), 1,
      anon_sym_private,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(154), 1,
      anon_sym_endif,
    STATE(125), 1,
      sym__ordinary_rule,
    STATE(126), 1,
      sym__static_pattern_rule,
    STATE(1040), 1,
      sym_list,
    ACTIONS(37), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(53), 3,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
    STATE(217), 3,
      sym__function,
      sym_function_call,
      sym_shell_function,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    STATE(201), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym_concatenation,
      sym_string,
      sym_archive,
    STATE(11), 19,
      sym__thing,
      sym_rule,
      sym__prefixed_recipe_line,
      sym__variable_definition,
      sym_VPATH_assignment,
      sym_RECIPEPREFIX_assignment,
      sym_variable_assignment,
      sym_shell_assignment,
      sym_define_directive,
      sym__directive,
      sym_include_directive,
      sym_vpath_directive,
      sym_export_directive,
      sym_unexport_directive,
      sym_override_directive,
      sym_undefine_directive,
      sym_private_directive,
      sym_conditional,
      aux_sym__conditional_consequence,
  [593] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(156), 1,
      sym_word,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(166), 1,
      anon_sym_shell,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(158), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(436), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(164), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [674] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(172), 1,
      sym_word,
    ACTIONS(178), 1,
      anon_sym_shell,
    ACTIONS(174), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(429), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(176), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [755] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(180), 1,
      sym_word,
    ACTIONS(186), 1,
      anon_sym_shell,
    ACTIONS(182), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(387), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(184), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [836] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(172), 1,
      sym_word,
    ACTIONS(190), 1,
      anon_sym_shell,
    ACTIONS(174), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(429), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(188), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [917] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(192), 1,
      sym_word,
    ACTIONS(198), 1,
      anon_sym_shell,
    ACTIONS(194), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(424), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(196), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [998] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(200), 1,
      sym_word,
    ACTIONS(206), 1,
      anon_sym_shell,
    ACTIONS(202), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(369), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(204), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [1079] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      sym_word,
    ACTIONS(214), 1,
      anon_sym_shell,
    ACTIONS(210), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(398), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(212), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [1160] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(216), 1,
      sym_word,
    ACTIONS(222), 1,
      anon_sym_shell,
    ACTIONS(218), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(385), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(220), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [1241] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(224), 1,
      sym_word,
    ACTIONS(230), 1,
      anon_sym_shell,
    ACTIONS(226), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(378), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(228), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [1322] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(232), 1,
      sym_word,
    ACTIONS(238), 1,
      anon_sym_shell,
    ACTIONS(234), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(411), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(236), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [1403] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(190), 1,
      anon_sym_shell,
    ACTIONS(240), 1,
      sym_word,
    ACTIONS(242), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(402), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(188), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [1484] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(244), 1,
      sym_word,
    ACTIONS(250), 1,
      anon_sym_shell,
    ACTIONS(246), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(399), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
    ACTIONS(248), 35,
      anon_sym_subst,
      anon_sym_patsubst,
      anon_sym_strip,
      anon_sym_findstring,
      anon_sym_filter,
      anon_sym_filter_DASHout,
      anon_sym_sort,
      anon_sym_word,
      anon_sym_words,
      anon_sym_wordlist,
      anon_sym_firstword,
      anon_sym_lastword,
      anon_sym_dir,
      anon_sym_notdir,
      anon_sym_suffix,
      anon_sym_basename,
      anon_sym_addsuffix,
      anon_sym_addprefix,
      anon_sym_join,
      anon_sym_wildcard,
      anon_sym_realpath,
      anon_sym_abspath,
      anon_sym_error,
      anon_sym_warning,
      anon_sym_info,
      anon_sym_origin,
      anon_sym_flavor,
      anon_sym_foreach,
      anon_sym_if,
      anon_sym_or,
      anon_sym_and,
      anon_sym_call,
      anon_sym_eval,
      anon_sym_file,
      anon_sym_value,
  [1565] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(252), 1,
      ts_builtin_sym_end,
    ACTIONS(254), 1,
      sym_word,
    ACTIONS(257), 1,
      anon_sym_VPATH,
    ACTIONS(260), 1,
      anon_sym_DOTRECIPEPREFIX,
    ACTIONS(263), 1,
      anon_sym_define,
    ACTIONS(269), 1,
      anon_sym_vpath,
    ACTIONS(272), 1,
      anon_sym_export,
    ACTIONS(275), 1,
      anon_sym_unexport,
    ACTIONS(278), 1,
      anon_sym_override,
    ACTIONS(281), 1,
      anon_sym_undefine,
    ACTIONS(284), 1,
      anon_sym_private,
    ACTIONS(287), 1,
      anon_sym_ifeq,
    ACTIONS(290), 1,
      anon_sym_ifneq,
    ACTIONS(293), 1,
      anon_sym_ifdef,
    ACTIONS(296), 1,
      anon_sym_ifndef,
    ACTIONS(299), 1,
      anon_sym_DOLLAR,
    ACTIONS(302), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(305), 1,
      anon_sym_DQUOTE,
    ACTIONS(308), 1,
      anon_sym_SQUOTE,
    STATE(285), 1,
      sym__static_pattern_rule,
    STATE(288), 1,
      sym__ordinary_rule,
    STATE(1052), 1,
      sym_list,
    ACTIONS(266), 3,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
    STATE(198), 3,
      sym__function,
      sym_function_call,
      sym_shell_function,
    STATE(3), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    STATE(201), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym_concatenation,
      sym_string,
      sym_archive,
    STATE(25), 18,
      sym__thing,
      sym_rule,
      sym__variable_definition,
      sym_VPATH_assignment,
      sym_RECIPEPREFIX_assignment,
      sym_variable_assignment,
      sym_shell_assignment,
      sym_define_directive,
      sym__directive,
      sym_include_directive,
      sym_vpath_directive,
      sym_export_directive,
      sym_unexport_directive,
      sym_override_directive,
      sym_undefine_directive,
      sym_private_directive,
      sym_conditional,
      aux_sym_makefile_repeat1,
  [1681] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_word,
    ACTIONS(9), 1,
      anon_sym_VPATH,
    ACTIONS(11), 1,
      anon_sym_DOTRECIPEPREFIX,
    ACTIONS(13), 1,
      anon_sym_define,
    ACTIONS(17), 1,
      anon_sym_vpath,
    ACTIONS(19), 1,
      anon_sym_export,
    ACTIONS(21), 1,
      anon_sym_unexport,
    ACTIONS(23), 1,
      anon_sym_override,
    ACTIONS(25), 1,
      anon_sym_undefine,
    ACTIONS(27), 1,
      anon_sym_private,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(37), 1,
      anon_sym_DOLLAR,
    ACTIONS(39), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(311), 1,
      ts_builtin_sym_end,
    STATE(285), 1,
      sym__static_pattern_rule,
    STATE(288), 1,
      sym__ordinary_rule,
    STATE(1052), 1,
      sym_list,
    ACTIONS(15), 3,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
    STATE(198), 3,
      sym__function,
      sym_function_call,
      sym_shell_function,
    STATE(3), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    STATE(201), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym_concatenation,
      sym_string,
      sym_archive,
    STATE(25), 18,
      sym__thing,
      sym_rule,
      sym__variable_definition,
      sym_VPATH_assignment,
      sym_RECIPEPREFIX_assignment,
      sym_variable_assignment,
      sym_shell_assignment,
      sym_define_directive,
      sym__directive,
      sym_include_directive,
      sym_vpath_directive,
      sym_export_directive,
      sym_unexport_directive,
      sym_override_directive,
      sym_undefine_directive,
      sym_private_directive,
      sym_conditional,
      aux_sym_makefile_repeat1,
  [1797] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(313), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [1849] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(315), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [1901] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(317), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [1953] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(319), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2005] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(323), 1,
      anon_sym_ifeq,
    ACTIONS(326), 1,
      anon_sym_ifneq,
    ACTIONS(329), 1,
      anon_sym_ifdef,
    ACTIONS(332), 1,
      anon_sym_ifndef,
    ACTIONS(335), 1,
      sym__recipeprefix,
    STATE(31), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(321), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2057] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(338), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2109] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(340), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2161] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(50), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(342), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2213] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(344), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2265] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(346), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2317] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(340), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2369] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(348), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2421] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(31), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(342), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2473] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(350), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2525] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(352), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2577] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(315), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2629] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(354), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2681] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(356), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2733] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(358), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2785] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(360), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2837] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(338), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2889] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(362), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2941] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(39), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(317), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [2993] = 9,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(75), 1,
      sym__recipeprefix,
    ACTIONS(77), 1,
      sym_comment,
    STATE(31), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(5), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(364), 19,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3045] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(366), 1,
      ts_builtin_sym_end,
    ACTIONS(368), 1,
      sym__recipeprefix,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(360), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3098] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(370), 1,
      ts_builtin_sym_end,
    STATE(62), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(342), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3151] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(372), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(338), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3204] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(374), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(317), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3257] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(376), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(356), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3310] = 10,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(323), 1,
      anon_sym_ifeq,
    ACTIONS(326), 1,
      anon_sym_ifneq,
    ACTIONS(329), 1,
      anon_sym_ifdef,
    ACTIONS(332), 1,
      anon_sym_ifndef,
    ACTIONS(378), 1,
      ts_builtin_sym_end,
    ACTIONS(380), 1,
      sym__recipeprefix,
    STATE(56), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(321), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3363] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(372), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(338), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3416] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(383), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(346), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3469] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(370), 1,
      ts_builtin_sym_end,
    STATE(56), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(342), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3522] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(385), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(348), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3575] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(387), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(319), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3628] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(389), 1,
      ts_builtin_sym_end,
    STATE(56), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(364), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3681] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(391), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(354), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3734] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(393), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(344), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3787] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(395), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(350), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3840] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(374), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(317), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3893] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(397), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(340), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3946] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(399), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(352), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [3999] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(397), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(340), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [4052] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(401), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(362), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [4105] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(403), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(358), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [4158] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(405), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(315), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [4211] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(405), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(315), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [4264] = 10,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(368), 1,
      sym__recipeprefix,
    ACTIONS(407), 1,
      ts_builtin_sym_end,
    STATE(59), 3,
      sym__prefixed_recipe_line,
      sym_conditional,
      aux_sym_recipe_repeat1,
    STATE(2), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
    ACTIONS(313), 17,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [4317] = 13,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(413), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(417), 1,
      anon_sym_BANG_EQ,
    ACTIONS(421), 1,
      anon_sym_LPAREN2,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(415), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4374] = 13,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(421), 1,
      anon_sym_LPAREN2,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(425), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(429), 1,
      anon_sym_BANG_EQ,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(427), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4431] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(435), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(437), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4488] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(449), 1,
      aux_sym__ordinary_rule_token1,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(451), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4545] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(453), 1,
      aux_sym__ordinary_rule_token1,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(455), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4602] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(457), 1,
      aux_sym__ordinary_rule_token1,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(459), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4659] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(411), 1,
      anon_sym_COLON,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(461), 1,
      aux_sym__ordinary_rule_token1,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(427), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4714] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(411), 1,
      anon_sym_COLON,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(463), 1,
      aux_sym__ordinary_rule_token1,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(415), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4769] = 12,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      anon_sym_COLON,
    ACTIONS(421), 1,
      anon_sym_LPAREN2,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(465), 1,
      aux_sym__ordinary_rule_token1,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(427), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4821] = 12,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(411), 1,
      anon_sym_COLON,
    ACTIONS(421), 1,
      anon_sym_LPAREN2,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(467), 1,
      aux_sym__ordinary_rule_token1,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(415), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [4873] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(473), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(475), 1,
      anon_sym_LPAREN2,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(479), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(483), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(485), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(469), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(481), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
    STATE(610), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [4922] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(491), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(493), 1,
      anon_sym_LPAREN2,
    ACTIONS(495), 1,
      anon_sym_LBRACE,
    ACTIONS(497), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(501), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(503), 1,
      aux_sym_text_token1,
    ACTIONS(487), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(499), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
    STATE(621), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [4971] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(507), 1,
      sym__recipeprefix,
    ACTIONS(505), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5003] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(399), 1,
      sym__recipeprefix,
    ACTIONS(352), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5035] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(511), 1,
      sym__recipeprefix,
    ACTIONS(509), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5067] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(515), 1,
      sym__recipeprefix,
    ACTIONS(513), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5099] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(519), 1,
      sym__recipeprefix,
    ACTIONS(517), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5131] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(523), 1,
      sym__recipeprefix,
    ACTIONS(521), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5163] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(527), 1,
      sym__recipeprefix,
    ACTIONS(525), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5195] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(531), 1,
      sym__recipeprefix,
    ACTIONS(529), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5227] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(535), 1,
      sym__recipeprefix,
    ACTIONS(533), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5259] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(537), 1,
      aux_sym__thing_token1,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(541), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(543), 1,
      anon_sym_LPAREN2,
    ACTIONS(545), 1,
      anon_sym_LBRACE,
    ACTIONS(547), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(551), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(553), 1,
      aux_sym_text_token1,
    ACTIONS(549), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
    STATE(670), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [5307] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(405), 1,
      sym__recipeprefix,
    ACTIONS(315), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5339] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(407), 1,
      sym__recipeprefix,
    ACTIONS(313), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5371] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(366), 1,
      sym__recipeprefix,
    ACTIONS(360), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5403] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(405), 1,
      sym__recipeprefix,
    ACTIONS(315), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5435] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(559), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(561), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [5479] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(559), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(563), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [5523] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(567), 1,
      sym__recipeprefix,
    ACTIONS(565), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5555] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(376), 1,
      sym__recipeprefix,
    ACTIONS(356), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5587] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(571), 1,
      sym__recipeprefix,
    ACTIONS(569), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5619] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(559), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(573), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [5663] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(577), 1,
      sym__recipeprefix,
    ACTIONS(575), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5695] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(581), 1,
      sym__recipeprefix,
    ACTIONS(579), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5727] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(585), 1,
      sym__recipeprefix,
    ACTIONS(583), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5759] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(403), 1,
      sym__recipeprefix,
    ACTIONS(358), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5791] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(589), 1,
      sym__recipeprefix,
    ACTIONS(587), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5823] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(593), 1,
      sym__recipeprefix,
    ACTIONS(591), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5855] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(597), 1,
      sym__recipeprefix,
    ACTIONS(595), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5887] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(601), 1,
      sym__recipeprefix,
    ACTIONS(599), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5919] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(605), 1,
      sym__recipeprefix,
    ACTIONS(603), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5951] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(401), 1,
      sym__recipeprefix,
    ACTIONS(362), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [5983] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(609), 1,
      sym__recipeprefix,
    ACTIONS(607), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6015] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(613), 1,
      sym__recipeprefix,
    ACTIONS(611), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6047] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(617), 1,
      sym__recipeprefix,
    ACTIONS(615), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6079] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(621), 1,
      sym__recipeprefix,
    ACTIONS(619), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6111] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(625), 1,
      sym__recipeprefix,
    ACTIONS(623), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6143] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(629), 1,
      sym__recipeprefix,
    ACTIONS(627), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6175] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(372), 1,
      sym__recipeprefix,
    ACTIONS(338), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6207] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(387), 1,
      sym__recipeprefix,
    ACTIONS(319), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6239] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(633), 1,
      sym__recipeprefix,
    ACTIONS(631), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6271] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(637), 1,
      sym__recipeprefix,
    ACTIONS(635), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6303] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(641), 1,
      sym__recipeprefix,
    ACTIONS(639), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6335] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(645), 1,
      sym__recipeprefix,
    ACTIONS(643), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6367] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(391), 1,
      sym__recipeprefix,
    ACTIONS(354), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6399] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(372), 1,
      sym__recipeprefix,
    ACTIONS(338), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6431] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(649), 1,
      sym__recipeprefix,
    ACTIONS(647), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6463] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(653), 1,
      sym__recipeprefix,
    ACTIONS(651), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6495] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(657), 1,
      sym__recipeprefix,
    ACTIONS(655), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6527] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(559), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(659), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [6571] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(557), 1,
      anon_sym_AMP_COLON,
    ACTIONS(661), 1,
      sym_word,
    ACTIONS(665), 1,
      anon_sym_BANG_EQ,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(559), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(663), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(301), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [6619] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(671), 1,
      sym__recipeprefix,
    ACTIONS(669), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6651] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(675), 1,
      sym__recipeprefix,
    ACTIONS(673), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6683] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(679), 1,
      sym__recipeprefix,
    ACTIONS(677), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6715] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(683), 1,
      sym__recipeprefix,
    ACTIONS(681), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6747] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(687), 1,
      sym__recipeprefix,
    ACTIONS(685), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6779] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(691), 1,
      sym__recipeprefix,
    ACTIONS(689), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6811] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(695), 1,
      sym__recipeprefix,
    ACTIONS(693), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6843] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(699), 1,
      sym__recipeprefix,
    ACTIONS(697), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6875] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(703), 1,
      sym__recipeprefix,
    ACTIONS(701), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6907] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(707), 1,
      sym__recipeprefix,
    ACTIONS(705), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6939] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(711), 1,
      sym__recipeprefix,
    ACTIONS(709), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [6971] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(715), 1,
      sym__recipeprefix,
    ACTIONS(713), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7003] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(719), 1,
      sym__recipeprefix,
    ACTIONS(717), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7035] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(397), 1,
      sym__recipeprefix,
    ACTIONS(340), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7067] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(723), 1,
      sym__recipeprefix,
    ACTIONS(721), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7099] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(727), 1,
      sym__recipeprefix,
    ACTIONS(725), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7131] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(374), 1,
      sym__recipeprefix,
    ACTIONS(317), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7163] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(397), 1,
      sym__recipeprefix,
    ACTIONS(340), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7195] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(731), 1,
      sym__recipeprefix,
    ACTIONS(729), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7227] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(735), 1,
      sym__recipeprefix,
    ACTIONS(733), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7259] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(393), 1,
      sym__recipeprefix,
    ACTIONS(344), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7291] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(385), 1,
      sym__recipeprefix,
    ACTIONS(348), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7323] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(383), 1,
      sym__recipeprefix,
    ACTIONS(346), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7355] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(557), 1,
      anon_sym_AMP_COLON,
    ACTIONS(661), 1,
      sym_word,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(739), 1,
      anon_sym_BANG_EQ,
    ACTIONS(559), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(737), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(301), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [7403] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(743), 1,
      sym__recipeprefix,
    ACTIONS(741), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7435] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(747), 1,
      sym__recipeprefix,
    ACTIONS(745), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7467] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(751), 1,
      sym__recipeprefix,
    ACTIONS(749), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7499] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(374), 1,
      sym__recipeprefix,
    ACTIONS(317), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7531] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(755), 1,
      sym__recipeprefix,
    ACTIONS(753), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7563] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(759), 1,
      sym__recipeprefix,
    ACTIONS(757), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7595] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(763), 1,
      sym__recipeprefix,
    ACTIONS(761), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7627] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(767), 1,
      sym__recipeprefix,
    ACTIONS(765), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7659] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(771), 1,
      sym__recipeprefix,
    ACTIONS(769), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7691] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(775), 1,
      sym__recipeprefix,
    ACTIONS(773), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7723] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(779), 1,
      sym__recipeprefix,
    ACTIONS(777), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7755] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(783), 1,
      sym__recipeprefix,
    ACTIONS(781), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7787] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(787), 1,
      sym__recipeprefix,
    ACTIONS(785), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7819] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(791), 1,
      sym__recipeprefix,
    ACTIONS(789), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7851] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(395), 1,
      sym__recipeprefix,
    ACTIONS(350), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7883] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(795), 1,
      sym__recipeprefix,
    ACTIONS(793), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7915] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(469), 1,
      aux_sym_list_token1,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(799), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(801), 1,
      anon_sym_LPAREN2,
    ACTIONS(803), 1,
      anon_sym_LBRACE,
    ACTIONS(805), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(809), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(811), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(807), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
    STATE(658), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [7963] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(815), 1,
      sym__recipeprefix,
    ACTIONS(813), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [7995] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(819), 1,
      sym__recipeprefix,
    ACTIONS(817), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8027] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(823), 1,
      sym__recipeprefix,
    ACTIONS(821), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8059] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(827), 1,
      sym__recipeprefix,
    ACTIONS(825), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8091] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(831), 1,
      sym__recipeprefix,
    ACTIONS(829), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8123] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(835), 1,
      sym__recipeprefix,
    ACTIONS(833), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8155] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(487), 1,
      anon_sym_RPAREN,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(839), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(841), 1,
      anon_sym_LPAREN2,
    ACTIONS(843), 1,
      anon_sym_LBRACE,
    ACTIONS(845), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(849), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(851), 1,
      aux_sym_text_token1,
    ACTIONS(847), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
    STATE(668), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [8203] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(855), 1,
      sym__recipeprefix,
    ACTIONS(853), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8235] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(859), 1,
      sym__recipeprefix,
    ACTIONS(857), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8267] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(863), 1,
      sym__recipeprefix,
    ACTIONS(861), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8299] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(867), 1,
      sym__recipeprefix,
    ACTIONS(865), 23,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_endif,
      anon_sym_else,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8331] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(421), 1,
      anon_sym_LPAREN2,
    ACTIONS(871), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(869), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [8366] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(751), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(749), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8397] = 12,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(873), 1,
      aux_sym__ordinary_rule_token1,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(411), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [8446] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(875), 1,
      sym_word,
    ACTIONS(877), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(412), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [8487] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(823), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(821), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8518] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(755), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(753), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8549] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(879), 1,
      sym_word,
    ACTIONS(881), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(427), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [8590] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(679), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(677), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8621] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(883), 1,
      sym_word,
    ACTIONS(885), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(438), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [8662] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(871), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(869), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [8697] = 11,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(887), 1,
      aux_sym__thing_token1,
    ACTIONS(889), 1,
      aux_sym__ordinary_rule_token1,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [8744] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(511), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(509), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [8775] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(891), 1,
      sym_word,
    ACTIONS(893), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(405), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [8816] = 11,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(433), 1,
      anon_sym_RPAREN2,
    ACTIONS(889), 1,
      aux_sym__ordinary_rule_token1,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [8863] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(441), 1,
      anon_sym_LPAREN2,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(895), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(897), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [8906] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(899), 1,
      sym_word,
    ACTIONS(901), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(415), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [8947] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(903), 1,
      sym_word,
    ACTIONS(905), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(413), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [8988] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(907), 1,
      sym_word,
    ACTIONS(909), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(401), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9029] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(683), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(681), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [9060] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(433), 1,
      aux_sym__thing_token1,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(873), 1,
      aux_sym__ordinary_rule_token1,
    STATE(838), 1,
      aux_sym_list_repeat1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [9107] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(657), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(655), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [9138] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(911), 1,
      sym_word,
    ACTIONS(913), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(389), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9179] = 9,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(421), 1,
      anon_sym_LPAREN2,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(895), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(897), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [9222] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(609), 2,
      ts_builtin_sym_end,
      sym__recipeprefix,
    ACTIONS(607), 21,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [9253] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(915), 1,
      sym_word,
    ACTIONS(917), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(380), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9294] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(919), 1,
      sym_word,
    ACTIONS(921), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(372), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9335] = 14,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(925), 1,
      aux_sym__thing_token1,
    ACTIONS(927), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(929), 1,
      anon_sym_PIPE,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    STATE(174), 1,
      sym_recipe,
    STATE(895), 1,
      sym__normal_prerequisites,
    STATE(1020), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9388] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(933), 1,
      sym_word,
    ACTIONS(935), 8,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_PERCENT2,
      anon_sym_LT2,
      anon_sym_QMARK2,
      anon_sym_CARET2,
      anon_sym_SLASH2,
      anon_sym_STAR2,
    STATE(386), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9429] = 14,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(925), 1,
      aux_sym__thing_token1,
    ACTIONS(929), 1,
      anon_sym_PIPE,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(937), 1,
      sym_word,
    ACTIONS(939), 1,
      aux_sym__ordinary_rule_token1,
    STATE(174), 1,
      sym_recipe,
    STATE(892), 1,
      sym__normal_prerequisites,
    STATE(971), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9482] = 11,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(889), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(941), 1,
      aux_sym__thing_token1,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(411), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [9529] = 14,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(943), 1,
      aux_sym__thing_token1,
    ACTIONS(945), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(947), 1,
      anon_sym_PIPE,
    STATE(287), 1,
      sym_recipe,
    STATE(935), 1,
      sym__normal_prerequisites,
    STATE(1020), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9582] = 14,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(943), 1,
      aux_sym__thing_token1,
    ACTIONS(947), 1,
      anon_sym_PIPE,
    ACTIONS(949), 1,
      sym_word,
    ACTIONS(951), 1,
      aux_sym__ordinary_rule_token1,
    STATE(287), 1,
      sym_recipe,
    STATE(933), 1,
      sym__normal_prerequisites,
    STATE(972), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [9635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(639), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9665] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(953), 1,
      sym_word,
    ACTIONS(963), 1,
      anon_sym_DQUOTE,
    ACTIONS(966), 1,
      anon_sym_SQUOTE,
    ACTIONS(960), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(956), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(958), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    STATE(221), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [9705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(567), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(565), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9735] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(867), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(865), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(515), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(513), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9795] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(521), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9825] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(527), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(525), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(827), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(825), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(649), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(647), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9915] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(735), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(733), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(374), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(317), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [9975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(765), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(761), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10035] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(399), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10065] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(831), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(829), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(813), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(795), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(793), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10155] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(745), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(755), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(753), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10215] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(751), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(749), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(577), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(575), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10275] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(769), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10305] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(346), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(507), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(505), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(759), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(757), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(819), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(817), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(393), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(344), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(743), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(741), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(773), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(385), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(348), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10545] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(374), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(317), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(731), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(729), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10605] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(721), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(779), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(777), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10665] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(687), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(685), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10695] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(969), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [10737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(675), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(673), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10767] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(340), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(725), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(855), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(853), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10857] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(971), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(973), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    STATE(221), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [10897] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(975), 1,
      sym_word,
    ACTIONS(977), 1,
      aux_sym__thing_token1,
    ACTIONS(979), 1,
      anon_sym_PIPE,
    STATE(157), 1,
      sym_recipe,
    STATE(922), 1,
      sym__normal_prerequisites,
    STATE(968), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [10947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(657), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(655), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [10977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(340), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11007] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(719), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(717), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(863), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(861), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(671), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(669), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(683), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(681), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(715), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(713), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11157] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(653), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(781), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(519), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(517), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(372), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(338), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(531), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(529), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11307] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(535), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(533), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11337] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(315), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11367] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(431), 1,
      sym_word,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(895), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(897), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    STATE(260), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [11407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(787), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(785), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11437] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(711), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(709), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11467] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(376), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(356), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(791), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(789), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(313), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(372), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(338), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11587] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(981), 1,
      aux_sym__thing_token1,
    ACTIONS(983), 1,
      anon_sym_PIPE,
    STATE(249), 1,
      sym_recipe,
    STATE(917), 1,
      sym__normal_prerequisites,
    STATE(1020), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [11637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(366), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(637), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(635), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11697] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(315), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(395), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(350), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11757] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(631), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11787] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(981), 1,
      aux_sym__thing_token1,
    ACTIONS(983), 1,
      anon_sym_PIPE,
    ACTIONS(985), 1,
      sym_word,
    STATE(249), 1,
      sym_recipe,
    STATE(929), 1,
      sym__normal_prerequisites,
    STATE(988), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [11837] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(569), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11867] = 8,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(971), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(973), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    STATE(297), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [11907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(579), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11937] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(585), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(583), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [11997] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(621), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(619), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(821), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12057] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(987), 1,
      sym_word,
    ACTIONS(993), 1,
      anon_sym_DQUOTE,
    ACTIONS(996), 1,
      anon_sym_SQUOTE,
    ACTIONS(990), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(956), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(958), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    STATE(297), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [12097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(587), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(362), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12157] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(835), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(833), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12187] = 8,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(895), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(897), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [12227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(607), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12257] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(999), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [12299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(611), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12329] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(617), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(615), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(707), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(705), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12389] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(869), 1,
      anon_sym_DOLLAR,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(871), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [12423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(703), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(701), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12453] = 13,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(977), 1,
      aux_sym__thing_token1,
    ACTIONS(979), 1,
      anon_sym_PIPE,
    STATE(157), 1,
      sym_recipe,
    STATE(931), 1,
      sym__normal_prerequisites,
    STATE(1020), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [12503] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(699), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(697), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(695), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(693), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(691), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(689), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12593] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(387), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(319), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(391), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(354), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12653] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(629), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(627), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12683] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(645), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(643), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(625), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(623), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(859), 4,
      ts_builtin_sym_end,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(857), 18,
      anon_sym_VPATH,
      anon_sym_DOTRECIPEPREFIX,
      anon_sym_define,
      anon_sym_include,
      anon_sym_sinclude,
      anon_sym_DASHinclude,
      anon_sym_vpath,
      anon_sym_export,
      anon_sym_unexport,
      anon_sym_override,
      anon_sym_undefine,
      anon_sym_private,
      anon_sym_ifeq,
      anon_sym_ifneq,
      anon_sym_ifdef,
      anon_sym_ifndef,
      anon_sym_DOLLAR,
      sym_word,
  [12773] = 12,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1003), 1,
      aux_sym__thing_token1,
    ACTIONS(1005), 1,
      aux_sym__ordinary_rule_token1,
    STATE(110), 1,
      sym_recipe,
    STATE(999), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [12820] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(661), 1,
      sym_word,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(663), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(301), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [12861] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_define,
    ACTIONS(25), 1,
      anon_sym_undefine,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1007), 1,
      sym_word,
    STATE(1272), 1,
      sym_list,
    STATE(244), 3,
      sym_variable_assignment,
      sym_define_directive,
      sym_undefine_directive,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [12906] = 12,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1009), 1,
      aux_sym__thing_token1,
    ACTIONS(1011), 1,
      aux_sym__ordinary_rule_token1,
    STATE(124), 1,
      sym_recipe,
    STATE(960), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [12953] = 12,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1013), 1,
      aux_sym__thing_token1,
    ACTIONS(1015), 1,
      aux_sym__ordinary_rule_token1,
    STATE(294), 1,
      sym_recipe,
    STATE(975), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13000] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      sym_word,
    ACTIONS(1020), 1,
      anon_sym_DOLLAR,
    ACTIONS(1023), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1026), 1,
      anon_sym_DQUOTE,
    ACTIONS(1029), 1,
      anon_sym_SQUOTE,
    ACTIONS(956), 5,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(324), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13039] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(971), 5,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(324), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13078] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(661), 1,
      sym_word,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(737), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
    STATE(301), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13119] = 12,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1034), 1,
      aux_sym__thing_token1,
    ACTIONS(1036), 1,
      aux_sym__ordinary_rule_token1,
    STATE(313), 1,
      sym_recipe,
    STATE(962), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13166] = 11,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(73), 1,
      anon_sym_SQUOTE,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(409), 1,
      sym_word,
    ACTIONS(421), 1,
      anon_sym_LPAREN2,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(433), 1,
      anon_sym_RPAREN2,
    ACTIONS(889), 1,
      aux_sym__ordinary_rule_token1,
    STATE(837), 1,
      aux_sym_list_repeat1,
    ACTIONS(419), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(291), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13211] = 10,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1040), 1,
      aux_sym__thing_token1,
    ACTIONS(1044), 1,
      anon_sym_LPAREN2,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    STATE(956), 1,
      aux_sym_paths_repeat1,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1046), 2,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13254] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(51), 1,
      anon_sym_define,
    ACTIONS(63), 1,
      anon_sym_undefine,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1052), 1,
      sym_word,
    STATE(1265), 1,
      sym_list,
    STATE(165), 3,
      sym_variable_assignment,
      sym_define_directive,
      sym_undefine_directive,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13299] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1054), 1,
      aux_sym__thing_token1,
    STATE(156), 1,
      sym_recipe,
    STATE(969), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13343] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1056), 1,
      aux_sym__thing_token1,
    STATE(99), 1,
      sym_recipe,
    STATE(954), 1,
      sym_list,
    STATE(1184), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13387] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1058), 1,
      aux_sym__thing_token1,
    STATE(284), 1,
      sym_recipe,
    STATE(976), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13431] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(1060), 1,
      aux_sym__thing_token1,
    STATE(246), 1,
      sym_recipe,
    STATE(979), 1,
      sym_list,
    STATE(1233), 1,
      sym__attached_recipe_line,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13475] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1044), 1,
      anon_sym_LPAREN2,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1062), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13513] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1044), 1,
      anon_sym_LPAREN2,
    ACTIONS(871), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(869), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13545] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1040), 1,
      aux_sym__thing_token1,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    STATE(956), 1,
      aux_sym_paths_repeat1,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1046), 2,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13585] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1064), 1,
      anon_sym_COLON,
    ACTIONS(1066), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13626] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1068), 1,
      anon_sym_COLON,
    ACTIONS(1070), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13667] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1066), 1,
      anon_sym_RBRACE,
    ACTIONS(1072), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13708] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1074), 1,
      anon_sym_COLON,
    ACTIONS(1076), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13749] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1076), 1,
      anon_sym_RBRACE,
    ACTIONS(1078), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13790] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1080), 1,
      anon_sym_COLON,
    ACTIONS(1082), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13831] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1082), 1,
      anon_sym_RBRACE,
    ACTIONS(1084), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13872] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(1086), 1,
      aux_sym__thing_token1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1088), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [13909] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1090), 1,
      anon_sym_COLON,
    ACTIONS(1092), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13950] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1094), 1,
      anon_sym_COLON,
    ACTIONS(1096), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [13991] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1092), 1,
      anon_sym_RBRACE,
    ACTIONS(1098), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14032] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1088), 1,
      anon_sym_COLON,
    ACTIONS(1100), 1,
      sym_word,
    ACTIONS(1086), 3,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_RPAREN2,
    STATE(301), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [14071] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(555), 1,
      sym_word,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(559), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [14108] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1102), 1,
      anon_sym_COLON,
    ACTIONS(1104), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14149] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1106), 1,
      anon_sym_COLON,
    ACTIONS(1108), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14190] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1096), 1,
      anon_sym_RPAREN,
    ACTIONS(1110), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14231] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1108), 1,
      anon_sym_RPAREN,
    ACTIONS(1112), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14272] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1104), 1,
      anon_sym_RBRACE,
    ACTIONS(1114), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14313] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1100), 1,
      sym_word,
    ACTIONS(557), 3,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_RPAREN2,
    STATE(301), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [14352] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1062), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14387] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1070), 1,
      anon_sym_RBRACE,
    ACTIONS(1116), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14428] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(971), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    STATE(365), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14463] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1118), 1,
      anon_sym_COLON,
    ACTIONS(1120), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14504] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1122), 1,
      anon_sym_COLON,
    ACTIONS(1124), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14545] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1126), 1,
      anon_sym_COLON,
    ACTIONS(1128), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14586] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1120), 1,
      anon_sym_RBRACE,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14627] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1124), 1,
      anon_sym_RPAREN,
    ACTIONS(1132), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14668] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1134), 1,
      sym_word,
    ACTIONS(1140), 1,
      anon_sym_DQUOTE,
    ACTIONS(1143), 1,
      anon_sym_SQUOTE,
    ACTIONS(1137), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(956), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    STATE(365), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14703] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1128), 1,
      anon_sym_RBRACE,
    ACTIONS(1146), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14744] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1148), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14782] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1150), 1,
      anon_sym_COMMA,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14820] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1064), 1,
      anon_sym_COLON,
    ACTIONS(1066), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14858] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1152), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14896] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1154), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14934] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1066), 1,
      anon_sym_RBRACE,
    ACTIONS(1072), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [14972] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1156), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15010] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1156), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15048] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1158), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15086] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1160), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15124] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1162), 1,
      aux_sym__thing_token1,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    STATE(565), 1,
      sym_shell_text_with_split,
    STATE(1062), 1,
      sym__shell_text_without_split,
    STATE(1172), 1,
      sym_recipe_line,
    ACTIONS(1164), 3,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [15166] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1068), 1,
      anon_sym_COLON,
    ACTIONS(1070), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15204] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1172), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15242] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1070), 1,
      anon_sym_RBRACE,
    ACTIONS(1116), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15280] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1174), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15318] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1176), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15356] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1174), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15394] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1178), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15432] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1074), 1,
      anon_sym_COLON,
    ACTIONS(1076), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15470] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1076), 1,
      anon_sym_RBRACE,
    ACTIONS(1078), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15508] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1118), 1,
      anon_sym_COLON,
    ACTIONS(1120), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15546] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1180), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15584] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1120), 1,
      anon_sym_RBRACE,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15622] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1182), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15660] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1184), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15698] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1186), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15736] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1188), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15774] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1182), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15812] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1186), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15850] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1190), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15888] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1192), 1,
      aux_sym__thing_token1,
    STATE(565), 1,
      sym_shell_text_with_split,
    STATE(1062), 1,
      sym__shell_text_without_split,
    STATE(1086), 1,
      sym_recipe_line,
    ACTIONS(1164), 3,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [15930] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1126), 1,
      anon_sym_COLON,
    ACTIONS(1128), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [15968] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1080), 1,
      anon_sym_COLON,
    ACTIONS(1082), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16006] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1194), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16044] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1128), 1,
      anon_sym_RBRACE,
    ACTIONS(1146), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16082] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1090), 1,
      anon_sym_COLON,
    ACTIONS(1092), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16120] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1196), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16158] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1198), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16196] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1082), 1,
      anon_sym_RBRACE,
    ACTIONS(1084), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16234] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1198), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16272] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1200), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16310] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(1202), 1,
      sym_word,
    ACTIONS(1204), 1,
      aux_sym__thing_token1,
    STATE(154), 1,
      sym_variable_assignment,
    STATE(1068), 1,
      sym_list,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [16348] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1206), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16386] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1206), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16424] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1124), 1,
      anon_sym_RPAREN,
    ACTIONS(1132), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16462] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1094), 1,
      anon_sym_COLON,
    ACTIONS(1096), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16500] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1122), 1,
      anon_sym_COLON,
    ACTIONS(1124), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16538] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1208), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16576] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1092), 1,
      anon_sym_RBRACE,
    ACTIONS(1098), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16614] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1210), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16652] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(1212), 1,
      sym_word,
    ACTIONS(1214), 1,
      aux_sym__thing_token1,
    STATE(251), 1,
      sym_variable_assignment,
    STATE(1074), 1,
      sym_list,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [16690] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1216), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16728] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1218), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16766] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1044), 1,
      anon_sym_LPAREN2,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1220), 1,
      aux_sym__thing_token1,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16802] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1222), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16840] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1148), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16878] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1224), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16916] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1096), 1,
      anon_sym_RPAREN,
    ACTIONS(1110), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16954] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1224), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [16992] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1226), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17030] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1106), 1,
      anon_sym_COLON,
    ACTIONS(1108), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17068] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1044), 1,
      anon_sym_LPAREN2,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1228), 1,
      aux_sym__thing_token1,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17104] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1108), 1,
      anon_sym_RPAREN,
    ACTIONS(1112), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17142] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1208), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17180] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1230), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17218] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1232), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17256] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1044), 1,
      anon_sym_LPAREN2,
    ACTIONS(1234), 1,
      aux_sym__thing_token1,
    ACTIONS(869), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17286] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1152), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17324] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1236), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17362] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1102), 1,
      anon_sym_COLON,
    ACTIONS(1104), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17400] = 11,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1238), 1,
      aux_sym__thing_token1,
    STATE(565), 1,
      sym_shell_text_with_split,
    STATE(1062), 1,
      sym__shell_text_without_split,
    STATE(1242), 1,
      sym_recipe_line,
    ACTIONS(1164), 3,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [17442] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1104), 1,
      anon_sym_RBRACE,
    ACTIONS(1114), 1,
      anon_sym_COLON,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17480] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1240), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17518] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1242), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17556] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1244), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17594] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1232), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17632] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1246), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17670] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1198), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17705] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1248), 1,
      sym_word,
    ACTIONS(1250), 1,
      anon_sym_LPAREN,
    STATE(1269), 1,
      sym__conditional_args_cmp,
    STATE(523), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [17742] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(1252), 1,
      aux_sym__thing_token1,
    STATE(1082), 1,
      sym_list,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [17777] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1242), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17812] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1244), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17847] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1240), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17882] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1152), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17917] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1230), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17952] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1232), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [17987] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_LPAREN2,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(479), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1258), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1254), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1256), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
    ACTIONS(481), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [18022] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1260), 1,
      sym_word,
    STATE(168), 1,
      sym_variable_assignment,
    STATE(1265), 1,
      sym_list,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [18059] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1152), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18094] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1218), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18129] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1156), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18164] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1150), 1,
      anon_sym_COMMA,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18199] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_LPAREN2,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(479), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1262), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1264), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
    ACTIONS(481), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [18232] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1236), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18267] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1234), 1,
      aux_sym__thing_token1,
    ACTIONS(869), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18294] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1158), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18329] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1206), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18364] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1232), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18399] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1228), 1,
      aux_sym__thing_token1,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18432] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1226), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18467] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1208), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18502] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1248), 1,
      sym_word,
    ACTIONS(1250), 1,
      anon_sym_LPAREN,
    STATE(1270), 1,
      sym__conditional_args_cmp,
    STATE(523), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [18539] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1266), 1,
      sym_word,
    STATE(241), 1,
      sym_variable_assignment,
    STATE(1272), 1,
      sym_list,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [18576] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1160), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18611] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1224), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18646] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1224), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18681] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1222), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18716] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1172), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18751] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1148), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18786] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1176), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18821] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_word,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1220), 1,
      aux_sym__thing_token1,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(359), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18854] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1148), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18889] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1174), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18924] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1178), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18959] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1174), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [18994] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1210), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19029] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1208), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19064] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1156), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19099] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1200), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19134] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1001), 1,
      anon_sym_LPAREN2,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      sym_word,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    STATE(325), 1,
      aux_sym_concatenation_repeat1,
    STATE(461), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [19171] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1188), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19206] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1276), 1,
      sym_word,
    ACTIONS(1278), 1,
      aux_sym__thing_token1,
    STATE(1252), 1,
      sym_paths,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(337), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [19241] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1048), 1,
      anon_sym_DQUOTE,
    ACTIONS(1050), 1,
      anon_sym_SQUOTE,
    ACTIONS(1276), 1,
      sym_word,
    ACTIONS(1280), 1,
      aux_sym__thing_token1,
    STATE(1132), 1,
      sym_paths,
    ACTIONS(1042), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(337), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [19276] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1206), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19311] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(475), 1,
      anon_sym_LPAREN2,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(479), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1282), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1284), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
    ACTIONS(481), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [19344] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_DQUOTE,
    ACTIONS(447), 1,
      anon_sym_SQUOTE,
    ACTIONS(923), 1,
      sym_word,
    ACTIONS(1286), 1,
      aux_sym__thing_token1,
    STATE(1273), 1,
      sym_list,
    ACTIONS(439), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [19379] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1246), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19414] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(493), 1,
      anon_sym_LPAREN2,
    ACTIONS(495), 1,
      anon_sym_LBRACE,
    ACTIONS(497), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1288), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
    ACTIONS(499), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [19445] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1180), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19480] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1154), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19515] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1198), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19550] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1184), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19585] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1186), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19620] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1216), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19655] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1196), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19690] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1190), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19725] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(493), 1,
      anon_sym_LPAREN2,
    ACTIONS(495), 1,
      anon_sym_LBRACE,
    ACTIONS(497), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1290), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
    ACTIONS(499), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [19756] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1182), 1,
      anon_sym_RPAREN,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19791] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(493), 1,
      anon_sym_LPAREN2,
    ACTIONS(495), 1,
      anon_sym_LBRACE,
    ACTIONS(497), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1294), 1,
      aux_sym_text_token1,
    ACTIONS(1292), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
    ACTIONS(499), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [19824] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1186), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19859] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1182), 1,
      anon_sym_RBRACE,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19894] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1032), 1,
      sym_word,
    ACTIONS(1194), 1,
      anon_sym_EQ,
    STATE(325), 11,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
      aux_sym_concatenation_repeat1,
  [19929] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    ACTIONS(1296), 1,
      sym_word,
    STATE(1090), 1,
      sym_paths,
    STATE(337), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [19963] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(801), 1,
      anon_sym_LPAREN2,
    ACTIONS(803), 1,
      anon_sym_LBRACE,
    ACTIONS(805), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1282), 1,
      aux_sym_list_token1,
    ACTIONS(1284), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
    ACTIONS(807), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [19995] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1298), 1,
      sym_word,
    STATE(1098), 1,
      sym_list,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20029] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(543), 1,
      anon_sym_LPAREN2,
    ACTIONS(545), 1,
      anon_sym_LBRACE,
    ACTIONS(547), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1300), 1,
      aux_sym__thing_token1,
    ACTIONS(1290), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
    ACTIONS(549), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20061] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(543), 1,
      anon_sym_LPAREN2,
    ACTIONS(545), 1,
      anon_sym_LBRACE,
    ACTIONS(547), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1302), 1,
      aux_sym__thing_token1,
    ACTIONS(1304), 1,
      aux_sym_text_token1,
    ACTIONS(1292), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
    ACTIONS(549), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20095] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(1275), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20129] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(841), 1,
      anon_sym_LPAREN2,
    ACTIONS(843), 1,
      anon_sym_LBRACE,
    ACTIONS(845), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1288), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
    ACTIONS(847), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20159] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(801), 1,
      anon_sym_LPAREN2,
    ACTIONS(803), 1,
      anon_sym_LBRACE,
    ACTIONS(805), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1262), 1,
      aux_sym_list_token1,
    ACTIONS(1264), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
    ACTIONS(807), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20191] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    ACTIONS(1296), 1,
      sym_word,
    STATE(1229), 1,
      sym_paths,
    STATE(337), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20225] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(841), 1,
      anon_sym_LPAREN2,
    ACTIONS(843), 1,
      anon_sym_LBRACE,
    ACTIONS(845), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1294), 1,
      aux_sym_text_token1,
    ACTIONS(1292), 4,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
    ACTIONS(847), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20257] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(801), 1,
      anon_sym_LPAREN2,
    ACTIONS(803), 1,
      anon_sym_LBRACE,
    ACTIONS(805), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1254), 1,
      aux_sym_list_token1,
    ACTIONS(1314), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1256), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
    ACTIONS(807), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20291] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(964), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20325] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(841), 1,
      anon_sym_LPAREN2,
    ACTIONS(843), 1,
      anon_sym_LBRACE,
    ACTIONS(845), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1290), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
    ACTIONS(847), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20355] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1316), 1,
      sym_word,
    ACTIONS(1318), 1,
      anon_sym_COMMA,
    STATE(458), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20389] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      sym_word,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    STATE(325), 1,
      aux_sym_concatenation_repeat1,
    STATE(461), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20423] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    ACTIONS(1296), 1,
      sym_word,
    STATE(1257), 1,
      sym_paths,
    STATE(337), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20457] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1298), 1,
      sym_word,
    STATE(1232), 1,
      sym_list,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20491] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1320), 1,
      sym_word,
    ACTIONS(1322), 1,
      anon_sym_RPAREN,
    STATE(501), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20525] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(543), 1,
      anon_sym_LPAREN2,
    ACTIONS(545), 1,
      anon_sym_LBRACE,
    ACTIONS(547), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1324), 1,
      aux_sym__thing_token1,
    ACTIONS(1288), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
    ACTIONS(549), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [20557] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(997), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20591] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(970), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20625] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(989), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20659] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1298), 1,
      sym_word,
    STATE(1266), 1,
      sym_list,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20693] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(963), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20727] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(1192), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20761] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(959), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20795] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(958), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20829] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    ACTIONS(1296), 1,
      sym_word,
    STATE(1176), 1,
      sym_paths,
    STATE(337), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20863] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(995), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20897] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1298), 1,
      sym_word,
    STATE(1244), 1,
      sym_list,
    STATE(201), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20931] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(1001), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20965] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(978), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [20999] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1326), 1,
      sym_word,
    ACTIONS(1328), 1,
      anon_sym_RPAREN,
    STATE(482), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21033] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(973), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21067] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1306), 1,
      sym_word,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    STATE(957), 1,
      sym_list,
    STATE(207), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21101] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1330), 1,
      sym__recipeprefix,
    STATE(1073), 1,
      sym__shell_text_without_split,
    STATE(554), 2,
      sym_shell_text_with_split,
      aux_sym_recipe_line_repeat1,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [21136] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1332), 1,
      sym_word,
    STATE(474), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21167] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1334), 1,
      sym_word,
    STATE(479), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21198] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1336), 1,
      sym_word,
    STATE(456), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21229] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1338), 1,
      sym__recipeprefix,
    STATE(1064), 1,
      sym__shell_text_without_split,
    STATE(554), 2,
      sym_shell_text_with_split,
      aux_sym_recipe_line_repeat1,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [21264] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1340), 1,
      sym_word,
    STATE(448), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21295] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1342), 1,
      sym_word,
    STATE(464), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21326] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 1,
      anon_sym_DOLLAR,
    ACTIONS(1308), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1310), 1,
      anon_sym_DQUOTE,
    ACTIONS(1312), 1,
      anon_sym_SQUOTE,
    ACTIONS(1344), 1,
      sym_word,
    STATE(276), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21357] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1346), 1,
      sym_word,
    STATE(493), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21388] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1348), 1,
      sym_word,
    STATE(447), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21419] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1350), 1,
      anon_sym_DOLLAR,
    ACTIONS(1353), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1356), 1,
      sym__recipeprefix,
    ACTIONS(1359), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1362), 1,
      anon_sym_SLASH_SLASH,
    STATE(1084), 1,
      sym__shell_text_without_split,
    STATE(554), 2,
      sym_shell_text_with_split,
      aux_sym_recipe_line_repeat1,
    STATE(646), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [21454] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1365), 1,
      sym_word,
    STATE(455), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21485] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1367), 1,
      sym_word,
    STATE(450), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21516] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    ACTIONS(1369), 1,
      sym_word,
    STATE(477), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21547] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    ACTIONS(1371), 1,
      sym_word,
    STATE(465), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21578] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1373), 1,
      sym_word,
    STATE(472), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21609] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1375), 1,
      sym_word,
    STATE(471), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21640] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1377), 1,
      sym_word,
    STATE(449), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21671] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1379), 1,
      sym_word,
    STATE(451), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21702] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      anon_sym_DOLLAR,
    ACTIONS(1270), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1272), 1,
      anon_sym_DQUOTE,
    ACTIONS(1274), 1,
      anon_sym_SQUOTE,
    ACTIONS(1381), 1,
      sym_word,
    STATE(357), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21733] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1383), 1,
      sym_word,
    STATE(466), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21764] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1385), 1,
      sym__recipeprefix,
    STATE(1072), 1,
      sym__shell_text_without_split,
    STATE(544), 2,
      sym_shell_text_with_split,
      aux_sym_recipe_line_repeat1,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [21799] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1387), 1,
      sym_word,
    STATE(473), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21830] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1389), 1,
      sym_word,
    STATE(499), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21861] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1391), 1,
      sym_word,
    STATE(506), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21892] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1393), 1,
      sym_word,
    STATE(497), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21923] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1395), 1,
      sym_word,
    STATE(500), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21954] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1397), 1,
      sym_word,
    STATE(444), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [21985] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1399), 1,
      sym_word,
    STATE(485), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22016] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1401), 1,
      sym_word,
    STATE(496), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22047] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1403), 1,
      sym_word,
    STATE(462), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22078] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1405), 1,
      sym_word,
    STATE(475), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22109] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1407), 1,
      sym_word,
    STATE(478), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22140] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1409), 1,
      sym_word,
    STATE(470), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22171] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1411), 1,
      sym_word,
    STATE(476), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22202] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1413), 1,
      sym_word,
    STATE(480), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22233] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1415), 1,
      sym_word,
    STATE(483), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22264] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1417), 1,
      sym_word,
    STATE(487), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22295] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1419), 1,
      sym_word,
    STATE(467), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22326] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1421), 1,
      sym_word,
    STATE(452), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22357] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1423), 1,
      sym_word,
    STATE(502), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22388] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1425), 1,
      sym_word,
    STATE(508), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22419] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(419), 1,
      anon_sym_DOLLAR,
    ACTIONS(667), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1100), 1,
      sym_word,
    STATE(301), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22450] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1427), 1,
      sym_word,
    STATE(460), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22481] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1429), 1,
      sym_word,
    STATE(490), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22512] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1431), 1,
      sym_word,
    STATE(463), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22543] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1433), 1,
      sym_word,
    STATE(481), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22574] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1435), 1,
      sym_word,
    STATE(457), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22605] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1437), 1,
      sym__recipeprefix,
    STATE(1075), 1,
      sym__shell_text_without_split,
    STATE(548), 2,
      sym_shell_text_with_split,
      aux_sym_recipe_line_repeat1,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [22640] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1439), 1,
      sym_word,
    STATE(484), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22671] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1441), 1,
      sym_word,
    STATE(507), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22702] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1443), 1,
      sym_word,
    STATE(498), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22733] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1445), 1,
      sym_word,
    STATE(504), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22764] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_DOLLAR,
    ACTIONS(162), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(168), 1,
      anon_sym_DQUOTE,
    ACTIONS(170), 1,
      anon_sym_SQUOTE,
    ACTIONS(1447), 1,
      sym_word,
    STATE(495), 10,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      sym_concatenation,
      sym_string,
      sym_archive,
  [22795] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1449), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1215), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [22829] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(491), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(501), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1459), 1,
      aux_sym_text_token1,
    ACTIONS(1457), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(617), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [22859] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1461), 1,
      aux_sym__thing_token1,
    ACTIONS(1463), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1118), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [22893] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1473), 1,
      anon_sym_DOLLAR,
    ACTIONS(1476), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1479), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1482), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1471), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(601), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [22923] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1485), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1193), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [22957] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1493), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1195), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [22991] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1495), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1143), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23025] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1497), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1147), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23059] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1499), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1255), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23093] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1501), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1258), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23127] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1503), 1,
      aux_sym__thing_token1,
    ACTIONS(1505), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1152), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23161] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1507), 1,
      aux_sym__thing_token1,
    ACTIONS(1509), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1217), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23195] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(473), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(485), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1513), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1511), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(601), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [23225] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1515), 1,
      aux_sym__thing_token1,
    ACTIONS(1517), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1241), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23259] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1519), 1,
      aux_sym__thing_token1,
    ACTIONS(1521), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1243), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23293] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1523), 1,
      aux_sym__thing_token1,
    ACTIONS(1525), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1083), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23327] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1527), 1,
      aux_sym__thing_token1,
    ACTIONS(1529), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1158), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23361] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(473), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(485), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1533), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1531), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(601), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [23391] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1535), 1,
      aux_sym__thing_token1,
    ACTIONS(1537), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1126), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23425] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1541), 1,
      anon_sym_DOLLAR,
    ACTIONS(1544), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1547), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1550), 1,
      aux_sym_text_token1,
    ACTIONS(1539), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(617), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [23455] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1553), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1153), 1,
      sym__shell_command,
    STATE(1171), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23489] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1555), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1135), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23523] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1557), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1162), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23557] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(491), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(501), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1561), 1,
      aux_sym_text_token1,
    ACTIONS(1559), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(617), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [23587] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1563), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1164), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23621] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1565), 1,
      aux_sym__thing_token1,
    ACTIONS(1567), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1190), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23655] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1569), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1171), 1,
      sym_text,
    STATE(1189), 1,
      sym__shell_command,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23689] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1571), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1274), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23723] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1573), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1112), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23757] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1575), 1,
      aux_sym__thing_token1,
    ACTIONS(1577), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1110), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23791] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1579), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1230), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23825] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1581), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1228), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23859] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1583), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1174), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23893] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1585), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1171), 1,
      sym_text,
    STATE(1246), 1,
      sym__shell_command,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23927] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1587), 1,
      aux_sym__thing_token1,
    ACTIONS(1589), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1247), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23961] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1591), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1114), 1,
      sym__shell_command,
    STATE(1171), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [23995] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1593), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1207), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24029] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1595), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1175), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24063] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1597), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1115), 1,
      sym__shell_command,
    STATE(1129), 1,
      sym_text,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24097] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(491), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(501), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(503), 1,
      aux_sym_text_token1,
    ACTIONS(487), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(621), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [24127] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1599), 1,
      aux_sym__thing_token1,
    ACTIONS(1601), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1128), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24161] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    ACTIONS(1603), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1096), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24195] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(473), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(485), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1607), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1605), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(615), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [24225] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(491), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(501), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1611), 1,
      aux_sym_text_token1,
    ACTIONS(1609), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(599), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [24255] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(473), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(483), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(485), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(469), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(610), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [24285] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1613), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1214), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24319] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1615), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1097), 1,
      sym__shell_command,
    STATE(1129), 1,
      sym_text,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24353] = 9,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    ACTIONS(1617), 1,
      aux_sym__ordinary_rule_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1206), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24387] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(799), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(811), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1605), 1,
      aux_sym_list_token1,
    ACTIONS(1619), 1,
      aux_sym__shell_text_without_split_token1,
    STATE(714), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [24416] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1159), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24447] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1621), 1,
      aux_sym__thing_token1,
    STATE(1092), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24478] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1625), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1627), 1,
      anon_sym_SLASH_SLASH,
    STATE(652), 1,
      aux_sym_text_repeat1,
    ACTIONS(1623), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(858), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24507] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1123), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24538] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    STATE(592), 1,
      sym_shell_text_with_split,
    STATE(1071), 1,
      sym__shell_text_without_split,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24569] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1625), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1627), 1,
      anon_sym_SLASH_SLASH,
    STATE(702), 1,
      aux_sym_text_repeat1,
    ACTIONS(1629), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(858), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24598] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1631), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1633), 1,
      anon_sym_SLASH_SLASH,
    STATE(698), 1,
      aux_sym__shell_text_without_split_repeat1,
    ACTIONS(1605), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(855), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24627] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1202), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24658] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1635), 1,
      aux_sym__thing_token1,
    ACTIONS(1637), 1,
      anon_sym_DOLLAR,
    ACTIONS(1640), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1643), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1646), 1,
      aux_sym_text_token1,
    STATE(655), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [24687] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1124), 1,
      sym__shell_command,
    STATE(1129), 1,
      sym_text,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24718] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(541), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(551), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1629), 1,
      aux_sym__thing_token1,
    ACTIONS(1649), 1,
      aux_sym_text_token1,
    STATE(655), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [24747] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(799), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(811), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1511), 1,
      aux_sym_list_token1,
    ACTIONS(1651), 1,
      aux_sym__shell_text_without_split_token1,
    STATE(659), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [24776] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1471), 1,
      aux_sym_list_token1,
    ACTIONS(1653), 1,
      anon_sym_DOLLAR,
    ACTIONS(1656), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1659), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1662), 1,
      anon_sym_SLASH_SLASH,
    STATE(659), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [24805] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1203), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24836] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1140), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24867] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1249), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24898] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(487), 1,
      anon_sym_RPAREN,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(839), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(849), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(851), 1,
      aux_sym_text_token1,
    STATE(668), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [24927] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(839), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(849), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1609), 1,
      anon_sym_RPAREN,
    ACTIONS(1665), 1,
      aux_sym_text_token1,
    STATE(671), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [24956] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1144), 1,
      sym__shell_command,
    STATE(1171), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [24987] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1100), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25018] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1211), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25049] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(839), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(849), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1559), 1,
      anon_sym_RPAREN,
    ACTIONS(1667), 1,
      aux_sym_text_token1,
    STATE(680), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [25078] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1212), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25109] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(541), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(551), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1669), 1,
      aux_sym__thing_token1,
    ACTIONS(1671), 1,
      aux_sym_text_token1,
    STATE(655), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [25138] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(839), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(849), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1457), 1,
      anon_sym_RPAREN,
    ACTIONS(1673), 1,
      aux_sym_text_token1,
    STATE(680), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [25167] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1104), 1,
      sym__shell_command,
    STATE(1129), 1,
      sym_text,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25198] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1224), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25229] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1139), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25260] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1169), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25291] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1225), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25322] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1675), 1,
      aux_sym__thing_token1,
    STATE(1145), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25353] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1677), 1,
      aux_sym__thing_token1,
    STATE(1106), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25384] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1250), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25415] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_RPAREN,
    ACTIONS(1679), 1,
      anon_sym_DOLLAR,
    ACTIONS(1682), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1685), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1688), 1,
      aux_sym_text_token1,
    STATE(680), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [25444] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1146), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25475] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1171), 1,
      sym_text,
    STATE(1187), 1,
      sym__shell_command,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25506] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1693), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1691), 10,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [25527] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1148), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25558] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1695), 1,
      aux_sym__thing_token1,
    STATE(1109), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25589] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(469), 1,
      aux_sym_list_token1,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(799), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(809), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(811), 1,
      anon_sym_SLASH_SLASH,
    STATE(658), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [25618] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1699), 1,
      anon_sym_DOLLAR,
    ACTIONS(1702), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1705), 1,
      anon_sym_SLASH_SLASH,
    STATE(687), 1,
      aux_sym__shell_text_without_split_repeat1,
    ACTIONS(1697), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(855), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25647] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1170), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25678] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1710), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1708), 10,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [25699] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1712), 1,
      aux_sym__thing_token1,
    STATE(1134), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25730] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    STATE(882), 1,
      sym_shell_text_with_split,
    STATE(1065), 1,
      sym__shell_text_without_split,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25761] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1714), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1716), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1718), 1,
      anon_sym_SLASH_SLASH,
    STATE(882), 1,
      sym_shell_text_with_split,
    STATE(1084), 1,
      sym__shell_text_without_split,
    STATE(646), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25792] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    STATE(882), 1,
      sym_shell_text_with_split,
    STATE(1064), 1,
      sym__shell_text_without_split,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25823] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1720), 1,
      aux_sym__thing_token1,
    STATE(1197), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25854] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1154), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25885] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1722), 1,
      aux_sym__thing_token1,
    STATE(1188), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25916] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    STATE(882), 1,
      sym_shell_text_with_split,
    STATE(1070), 1,
      sym__shell_text_without_split,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25947] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1631), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1633), 1,
      anon_sym_SLASH_SLASH,
    STATE(687), 1,
      aux_sym__shell_text_without_split_repeat1,
    ACTIONS(1531), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(855), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [25976] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1166), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1168), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1170), 1,
      anon_sym_SLASH_SLASH,
    STATE(882), 1,
      sym_shell_text_with_split,
    STATE(1073), 1,
      sym__shell_text_without_split,
    STATE(640), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26007] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1724), 1,
      aux_sym__thing_token1,
    STATE(1245), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26038] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(541), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(551), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1623), 1,
      aux_sym__thing_token1,
    ACTIONS(1726), 1,
      aux_sym_text_token1,
    STATE(657), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [26067] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1730), 1,
      anon_sym_DOLLAR,
    ACTIONS(1733), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1736), 1,
      anon_sym_SLASH_SLASH,
    STATE(702), 1,
      aux_sym_text_repeat1,
    ACTIONS(1728), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(858), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26096] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1741), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1739), 10,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [26117] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1743), 1,
      aux_sym__thing_token1,
    STATE(1285), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26148] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1155), 1,
      sym__shell_command,
    STATE(1171), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26179] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1747), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1745), 10,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [26200] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1043), 1,
      sym_text,
    STATE(1186), 1,
      sym_arguments,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26231] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1487), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1489), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1491), 1,
      aux_sym_text_token1,
    STATE(1129), 1,
      sym_text,
    STATE(1194), 1,
      sym__shell_command,
    STATE(664), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26262] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1749), 1,
      aux_sym__thing_token1,
    STATE(1283), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26293] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1751), 1,
      aux_sym__thing_token1,
    STATE(1125), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26324] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(537), 1,
      aux_sym__thing_token1,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(541), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(551), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(553), 1,
      aux_sym_text_token1,
    STATE(670), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym_text_repeat2,
  [26353] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1171), 1,
      sym_text,
    STATE(1199), 1,
      sym__shell_command,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26384] = 8,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    ACTIONS(1753), 1,
      aux_sym__thing_token1,
    STATE(1279), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26415] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(799), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(811), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1531), 1,
      aux_sym_list_token1,
    ACTIONS(1755), 1,
      aux_sym__shell_text_without_split_token1,
    STATE(659), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__shell_text_without_split_repeat2,
  [26444] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1087), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26472] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1759), 1,
      anon_sym_DQUOTE,
    ACTIONS(1761), 1,
      aux_sym__string_token1,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(736), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26496] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1763), 1,
      anon_sym_DQUOTE,
    ACTIONS(1765), 1,
      aux_sym__string_token1,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(720), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26520] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1763), 1,
      anon_sym_SQUOTE,
    ACTIONS(1769), 1,
      aux_sym__string_token1,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(721), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26544] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1773), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1775), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1771), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(848), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26570] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1761), 1,
      aux_sym__string_token1,
    ACTIONS(1777), 1,
      anon_sym_DQUOTE,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(736), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26594] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1777), 1,
      anon_sym_SQUOTE,
    ACTIONS(1779), 1,
      aux_sym__string_token1,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(748), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26618] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1623), 1,
      aux_sym__thing_token1,
    ACTIONS(1781), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1783), 1,
      anon_sym_SLASH_SLASH,
    STATE(730), 1,
      aux_sym_text_repeat1,
    STATE(941), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26646] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1227), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26674] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1773), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1775), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1785), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(848), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26700] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1787), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1789), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1531), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(867), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26726] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1791), 1,
      anon_sym_DQUOTE,
    ACTIONS(1793), 1,
      aux_sym__string_token1,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(731), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26750] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1791), 1,
      anon_sym_SQUOTE,
    ACTIONS(1795), 1,
      aux_sym__string_token1,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(732), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26774] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1605), 1,
      aux_sym_list_token1,
    ACTIONS(1797), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1799), 1,
      anon_sym_SLASH_SLASH,
    STATE(741), 1,
      aux_sym__shell_text_without_split_repeat1,
    STATE(912), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26802] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1787), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1789), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1801), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(867), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26828] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1629), 1,
      aux_sym__thing_token1,
    ACTIONS(1781), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1783), 1,
      anon_sym_SLASH_SLASH,
    STATE(749), 1,
      aux_sym_text_repeat1,
    STATE(941), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26856] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1761), 1,
      aux_sym__string_token1,
    ACTIONS(1803), 1,
      anon_sym_DQUOTE,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(736), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26880] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1779), 1,
      aux_sym__string_token1,
    ACTIONS(1803), 1,
      anon_sym_SQUOTE,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(748), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26904] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1773), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1775), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1669), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(848), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26930] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1805), 1,
      anon_sym_DQUOTE,
    ACTIONS(1807), 1,
      aux_sym__string_token1,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(716), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [26954] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1728), 1,
      anon_sym_RPAREN,
    ACTIONS(1809), 1,
      anon_sym_DOLLAR,
    ACTIONS(1812), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1815), 1,
      anon_sym_SLASH_SLASH,
    STATE(735), 1,
      aux_sym_text_repeat1,
    STATE(948), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [26982] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_DQUOTE,
    ACTIONS(1823), 1,
      aux_sym__string_token1,
    ACTIONS(1818), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(736), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27006] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1805), 1,
      anon_sym_SQUOTE,
    ACTIONS(1826), 1,
      aux_sym__string_token1,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(743), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27030] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1787), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1789), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1511), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(867), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27056] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1451), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1453), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1455), 1,
      aux_sym_text_token1,
    STATE(1063), 1,
      sym_text,
    STATE(641), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27084] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1623), 1,
      anon_sym_RPAREN,
    ACTIONS(1828), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1830), 1,
      anon_sym_SLASH_SLASH,
    STATE(744), 1,
      aux_sym_text_repeat1,
    STATE(948), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27112] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1531), 1,
      aux_sym_list_token1,
    ACTIONS(1797), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1799), 1,
      anon_sym_SLASH_SLASH,
    STATE(752), 1,
      aux_sym__shell_text_without_split_repeat1,
    STATE(912), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27140] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1787), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1789), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1832), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    STATE(867), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27166] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1759), 1,
      anon_sym_SQUOTE,
    ACTIONS(1779), 1,
      aux_sym__string_token1,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(748), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27190] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1629), 1,
      anon_sym_RPAREN,
    ACTIONS(1828), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1830), 1,
      anon_sym_SLASH_SLASH,
    STATE(735), 1,
      aux_sym_text_repeat1,
    STATE(948), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27218] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1256), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27246] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1779), 1,
      aux_sym__string_token1,
    ACTIONS(1834), 1,
      anon_sym_SQUOTE,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(748), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27270] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1761), 1,
      aux_sym__string_token1,
    ACTIONS(1834), 1,
      anon_sym_DQUOTE,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(736), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27294] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_SQUOTE,
    ACTIONS(1839), 1,
      aux_sym__string_token1,
    ACTIONS(1836), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(748), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27318] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1728), 1,
      aux_sym__thing_token1,
    ACTIONS(1842), 1,
      anon_sym_DOLLAR,
    ACTIONS(1845), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1848), 1,
      anon_sym_SLASH_SLASH,
    STATE(749), 1,
      aux_sym_text_repeat1,
    STATE(941), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27346] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1851), 1,
      anon_sym_SQUOTE,
    ACTIONS(1853), 1,
      aux_sym__string_token1,
    ACTIONS(1767), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(746), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27370] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1851), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      aux_sym__string_token1,
    ACTIONS(1757), 2,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
    STATE(747), 8,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
      aux_sym__string,
  [27394] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1697), 1,
      aux_sym_list_token1,
    ACTIONS(1857), 1,
      anon_sym_DOLLAR,
    ACTIONS(1860), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1863), 1,
      anon_sym_SLASH_SLASH,
    STATE(752), 1,
      aux_sym__shell_text_without_split_repeat1,
    STATE(912), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27422] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1773), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1775), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1629), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(848), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27448] = 7,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1465), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1467), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1469), 1,
      aux_sym_text_token1,
    STATE(1167), 1,
      sym_text,
    STATE(701), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27476] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1866), 1,
      anon_sym_LPAREN2,
    ACTIONS(1868), 1,
      anon_sym_LBRACE,
    ACTIONS(1870), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1872), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [27499] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1771), 1,
      aux_sym__thing_token1,
    ACTIONS(1874), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1876), 1,
      anon_sym_SLASH_SLASH,
    STATE(926), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27524] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1629), 1,
      anon_sym_RPAREN,
    ACTIONS(1878), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1880), 1,
      anon_sym_SLASH_SLASH,
    STATE(952), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27549] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1882), 1,
      anon_sym_LPAREN2,
    ACTIONS(1884), 1,
      anon_sym_LBRACE,
    ACTIONS(1886), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1888), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [27572] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1892), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1890), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27591] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1894), 1,
      anon_sym_LPAREN2,
    ACTIONS(1896), 1,
      anon_sym_LBRACE,
    ACTIONS(1898), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1900), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [27614] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1902), 1,
      anon_sym_LPAREN2,
    ACTIONS(1904), 1,
      anon_sym_LBRACE,
    ACTIONS(1906), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1908), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [27637] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1912), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1910), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27656] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1916), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1914), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27675] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1920), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1918), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27694] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1896), 1,
      anon_sym_LBRACE,
    ACTIONS(1898), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1922), 1,
      anon_sym_LPAREN2,
    ACTIONS(1900), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [27717] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1924), 1,
      anon_sym_LPAREN2,
    ACTIONS(1926), 1,
      anon_sym_LBRACE,
    ACTIONS(1928), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1930), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [27740] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1785), 1,
      anon_sym_RPAREN,
    ACTIONS(1878), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1880), 1,
      anon_sym_SLASH_SLASH,
    STATE(952), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27765] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1771), 1,
      anon_sym_RPAREN,
    ACTIONS(1878), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1880), 1,
      anon_sym_SLASH_SLASH,
    STATE(952), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27790] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1934), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1932), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27809] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1669), 1,
      anon_sym_RPAREN,
    ACTIONS(1878), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1880), 1,
      anon_sym_SLASH_SLASH,
    STATE(952), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27834] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1938), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1936), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27853] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1669), 1,
      aux_sym__thing_token1,
    ACTIONS(1874), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1876), 1,
      anon_sym_SLASH_SLASH,
    STATE(926), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27878] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(543), 1,
      anon_sym_LPAREN2,
    ACTIONS(547), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1940), 1,
      anon_sym_LBRACE,
    ACTIONS(549), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [27901] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1629), 1,
      aux_sym__thing_token1,
    ACTIONS(1874), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1876), 1,
      anon_sym_SLASH_SLASH,
    STATE(926), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27926] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1741), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1739), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27945] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1747), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1745), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [27964] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1801), 1,
      aux_sym_list_token1,
    ACTIONS(1942), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1944), 1,
      anon_sym_SLASH_SLASH,
    STATE(924), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [27989] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1832), 1,
      aux_sym_list_token1,
    ACTIONS(1942), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1944), 1,
      anon_sym_SLASH_SLASH,
    STATE(924), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28014] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1938), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1936), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28033] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1948), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1946), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28052] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(479), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1950), 1,
      anon_sym_LPAREN2,
    ACTIONS(1952), 1,
      anon_sym_LBRACE,
    ACTIONS(481), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [28075] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1710), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1708), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28094] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1693), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1691), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28113] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1954), 1,
      anon_sym_LPAREN2,
    ACTIONS(1956), 1,
      anon_sym_LBRACE,
    ACTIONS(1958), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1960), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [28136] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1964), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1962), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28155] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(493), 1,
      anon_sym_LPAREN2,
    ACTIONS(497), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1966), 1,
      anon_sym_LBRACE,
    ACTIONS(499), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [28178] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1531), 1,
      aux_sym_list_token1,
    ACTIONS(1942), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1944), 1,
      anon_sym_SLASH_SLASH,
    STATE(924), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28203] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1970), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1968), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28222] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1511), 1,
      aux_sym_list_token1,
    ACTIONS(1942), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1944), 1,
      anon_sym_SLASH_SLASH,
    STATE(924), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28247] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1970), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1968), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28266] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1948), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1946), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28285] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(841), 1,
      anon_sym_LPAREN2,
    ACTIONS(845), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1972), 1,
      anon_sym_LBRACE,
    ACTIONS(847), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [28308] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1934), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1932), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28327] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1920), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1918), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28346] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(805), 1,
      aux_sym_variable_reference_token1,
    ACTIONS(1974), 1,
      anon_sym_LPAREN2,
    ACTIONS(1976), 1,
      anon_sym_LBRACE,
    ACTIONS(807), 8,
      anon_sym_AT2,
      anon_sym_PERCENT,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_CARET,
      anon_sym_PLUS2,
      anon_sym_SLASH,
      anon_sym_STAR,
  [28369] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1785), 1,
      aux_sym__thing_token1,
    ACTIONS(1874), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1876), 1,
      anon_sym_SLASH_SLASH,
    STATE(926), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28394] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1964), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1962), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28413] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1916), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1914), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28432] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1892), 3,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
      anon_sym_RPAREN2,
    ACTIONS(1890), 8,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28451] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1912), 3,
      aux_sym__thing_token1,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(1910), 8,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1932), 1,
      anon_sym_DOLLAR,
    ACTIONS(1934), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28488] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1745), 1,
      anon_sym_DOLLAR,
    ACTIONS(1747), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28506] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(797), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1980), 1,
      anon_sym_SLASH_SLASH,
    STATE(924), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1910), 1,
      anon_sym_DOLLAR,
    ACTIONS(1912), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1914), 1,
      anon_sym_DOLLAR,
    ACTIONS(1916), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28564] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1918), 1,
      anon_sym_DOLLAR,
    ACTIONS(1920), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1936), 1,
      anon_sym_DOLLAR,
    ACTIONS(1938), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1946), 1,
      anon_sym_DOLLAR,
    ACTIONS(1948), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28618] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_DOLLAR,
    ACTIONS(1773), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1775), 1,
      anon_sym_SLASH_SLASH,
    STATE(848), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1968), 1,
      anon_sym_DOLLAR,
    ACTIONS(1970), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1962), 1,
      anon_sym_DOLLAR,
    ACTIONS(1964), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28676] = 7,
    ACTIONS(29), 1,
      anon_sym_ifeq,
    ACTIONS(31), 1,
      anon_sym_ifneq,
    ACTIONS(33), 1,
      anon_sym_ifdef,
    ACTIONS(35), 1,
      anon_sym_ifndef,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1982), 1,
      aux_sym__thing_token1,
    STATE(8), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
  [28702] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_DOLLAR,
    ACTIONS(1984), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1986), 1,
      anon_sym_SLASH_SLASH,
    STATE(926), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1691), 1,
      anon_sym_DOLLAR,
    ACTIONS(1693), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1708), 1,
      anon_sym_DOLLAR,
    ACTIONS(1710), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28760] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 1,
      anon_sym_DOLLAR,
    ACTIONS(1988), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1990), 1,
      anon_sym_SLASH_SLASH,
    STATE(867), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28782] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 1,
      anon_sym_DOLLAR,
    ACTIONS(1878), 1,
      anon_sym_DOLLAR_DOLLAR,
    ACTIONS(1880), 1,
      anon_sym_SLASH_SLASH,
    STATE(952), 7,
      sym__variable,
      sym_variable_reference,
      sym_substitution_reference,
      sym_automatic_variable,
      sym__function,
      sym_function_call,
      sym_shell_function,
  [28804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1890), 1,
      anon_sym_DOLLAR,
    ACTIONS(1892), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1739), 1,
      anon_sym_DOLLAR,
    ACTIONS(1741), 9,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28840] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1992), 1,
      anon_sym_ifeq,
    ACTIONS(1994), 1,
      anon_sym_ifneq,
    ACTIONS(1996), 1,
      anon_sym_ifdef,
    ACTIONS(1998), 1,
      anon_sym_ifndef,
    STATE(8), 5,
      sym__conditional_directives,
      sym_ifeq_directive,
      sym_ifneq_directive,
      sym_ifdef_directive,
      sym_ifndef_directive,
  [28863] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1970), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1968), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28879] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1892), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1890), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28895] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1912), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1910), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28911] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1916), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1914), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28927] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1920), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1918), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28943] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1934), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1932), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28959] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1938), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1936), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28975] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1948), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1946), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [28991] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1964), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1962), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [29007] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1693), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1691), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [29023] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1710), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1708), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [29039] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1747), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1745), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [29055] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1741), 3,
      aux_sym__thing_token1,
      anon_sym_COLON2,
      anon_sym_SEMI2,
    ACTIONS(1739), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_word,
  [29071] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(895), 1,
      aux_sym__thing_token1,
    STATE(834), 1,
      aux_sym_list_repeat1,
    ACTIONS(2000), 2,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(897), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [29090] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2003), 1,
      aux_sym__thing_token1,
    ACTIONS(2005), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2007), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29107] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2009), 1,
      aux_sym__thing_token1,
    ACTIONS(2011), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2013), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29124] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(423), 1,
      aux_sym_list_token1,
    ACTIONS(557), 1,
      anon_sym_RPAREN2,
    ACTIONS(2015), 1,
      aux_sym__ordinary_rule_token1,
    STATE(840), 1,
      aux_sym_list_repeat1,
    ACTIONS(559), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
  [29145] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(443), 1,
      aux_sym_list_token1,
    ACTIONS(557), 1,
      aux_sym__thing_token1,
    ACTIONS(2017), 1,
      aux_sym__ordinary_rule_token1,
    STATE(834), 1,
      aux_sym_list_repeat1,
    ACTIONS(559), 3,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [29166] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2019), 1,
      aux_sym__thing_token1,
    ACTIONS(2021), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2023), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29183] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(895), 1,
      anon_sym_RPAREN2,
    STATE(840), 1,
      aux_sym_list_repeat1,
    ACTIONS(2025), 2,
      aux_sym__ordinary_rule_token1,
      aux_sym_list_token1,
    ACTIONS(897), 3,
      anon_sym_COLON,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
  [29202] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2028), 1,
      aux_sym__thing_token1,
    ACTIONS(2030), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2032), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29219] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1892), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1890), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29233] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1741), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1739), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29247] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1693), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1691), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29261] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2034), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2036), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29275] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2038), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2040), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29289] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1936), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29301] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1539), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29313] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1288), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29325] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1914), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29337] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1910), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29349] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1262), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1264), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29363] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1258), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1254), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1256), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [29379] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2042), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2044), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29393] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2050), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(2046), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(2048), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [29409] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1294), 1,
      aux_sym_text_token1,
    ACTIONS(1292), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [29423] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1946), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29435] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2054), 1,
      aux_sym_text_token1,
    ACTIONS(2052), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [29449] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1290), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29461] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1710), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1708), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29475] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2056), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(437), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29489] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1962), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29501] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1747), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1745), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29515] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1739), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29527] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2058), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(455), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29541] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2060), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(459), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29555] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1471), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(2062), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29569] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1282), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1284), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29583] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1708), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29595] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1912), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1910), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29609] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1916), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1914), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29623] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1938), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1936), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29637] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1745), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29649] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2064), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(451), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29663] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1948), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1946), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29677] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1964), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(1962), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29691] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1691), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29703] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2066), 1,
      aux_sym__ordinary_rule_token1,
    ACTIONS(2068), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29717] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1890), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29729] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2070), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29740] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1693), 1,
      aux_sym_list_token1,
    ACTIONS(1691), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29753] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2072), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      sym__recipeprefix,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [29764] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2074), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29775] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2076), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29786] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1914), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29797] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29808] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2080), 1,
      anon_sym_endif,
    ACTIONS(2082), 1,
      anon_sym_else,
    STATE(1102), 1,
      sym_else_directive,
    STATE(986), 2,
      sym_elsif_directive,
      aux_sym_conditional_repeat1,
  [29825] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1936), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29836] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_else,
    ACTIONS(2084), 1,
      anon_sym_endif,
    STATE(1091), 1,
      sym_else_directive,
    STATE(986), 2,
      sym_elsif_directive,
      aux_sym_conditional_repeat1,
  [29853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2086), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29864] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1710), 1,
      aux_sym__thing_token1,
    ACTIONS(1708), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29877] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2088), 1,
      aux_sym__thing_token1,
    ACTIONS(2090), 1,
      anon_sym_PIPE,
    STATE(153), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [29896] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1693), 1,
      aux_sym__thing_token1,
    ACTIONS(1691), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2092), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [29920] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2094), 1,
      aux_sym__thing_token1,
    ACTIONS(2096), 1,
      anon_sym_PIPE,
    STATE(149), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [29939] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1946), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29950] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1697), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(2098), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [29963] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1964), 1,
      aux_sym__thing_token1,
    ACTIONS(1962), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [29976] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_else,
    ACTIONS(2100), 1,
      anon_sym_endif,
    STATE(1141), 1,
      sym_else_directive,
    STATE(986), 2,
      sym_elsif_directive,
      aux_sym_conditional_repeat1,
  [29993] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2102), 2,
      aux_sym__thing_token1,
      aux_sym_list_token1,
    ACTIONS(2104), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30006] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1747), 1,
      aux_sym__thing_token1,
    ACTIONS(1745), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30019] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1741), 1,
      aux_sym__thing_token1,
    ACTIONS(1739), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30032] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1962), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30043] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1691), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30054] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1262), 1,
      aux_sym_list_token1,
    ACTIONS(1264), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30067] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1708), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30078] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1254), 1,
      aux_sym_list_token1,
    ACTIONS(1314), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(1256), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30093] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1745), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30104] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1739), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30115] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1890), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30126] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_else,
    ACTIONS(2106), 1,
      anon_sym_endif,
    STATE(1236), 1,
      sym_else_directive,
    STATE(986), 2,
      sym_elsif_directive,
      aux_sym_conditional_repeat1,
  [30143] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2046), 1,
      aux_sym_list_token1,
    ACTIONS(2108), 1,
      aux_sym__shell_text_without_split_token1,
    ACTIONS(2048), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30158] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1912), 1,
      aux_sym_list_token1,
    ACTIONS(1910), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30171] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1892), 1,
      aux_sym__thing_token1,
    ACTIONS(1890), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2112), 1,
      anon_sym_DOLLAR,
    ACTIONS(2110), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2114), 1,
      anon_sym_DOLLAR,
    ACTIONS(1728), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30210] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2116), 1,
      aux_sym__thing_token1,
    ACTIONS(2118), 1,
      anon_sym_PIPE,
    STATE(272), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30229] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1916), 1,
      aux_sym_list_token1,
    ACTIONS(1914), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30242] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1938), 1,
      aux_sym_list_token1,
    ACTIONS(1936), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30255] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1910), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30266] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1948), 1,
      aux_sym_list_token1,
    ACTIONS(1946), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30279] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2120), 1,
      aux_sym__thing_token1,
    ACTIONS(2122), 1,
      anon_sym_PIPE,
    STATE(130), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30298] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1282), 1,
      aux_sym_list_token1,
    ACTIONS(1284), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30311] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1471), 1,
      aux_sym_list_token1,
    ACTIONS(2062), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30324] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1948), 1,
      aux_sym__thing_token1,
    ACTIONS(1946), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30337] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1635), 1,
      aux_sym__thing_token1,
    ACTIONS(1539), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30350] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_else,
    ACTIONS(2124), 1,
      anon_sym_endif,
    STATE(1178), 1,
      sym_else_directive,
    STATE(986), 2,
      sym_elsif_directive,
      aux_sym_conditional_repeat1,
  [30367] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1324), 1,
      aux_sym__thing_token1,
    ACTIONS(1288), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30380] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2126), 1,
      aux_sym__thing_token1,
    ACTIONS(2128), 1,
      anon_sym_PIPE,
    STATE(282), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30399] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1938), 1,
      aux_sym__thing_token1,
    ACTIONS(1936), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30412] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2130), 1,
      aux_sym__thing_token1,
    ACTIONS(2132), 1,
      anon_sym_PIPE,
    STATE(123), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30431] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2082), 1,
      anon_sym_else,
    ACTIONS(2134), 1,
      anon_sym_endif,
    STATE(1138), 1,
      sym_else_directive,
    STATE(986), 2,
      sym_elsif_directive,
      aux_sym_conditional_repeat1,
  [30448] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2136), 1,
      aux_sym__thing_token1,
    ACTIONS(2138), 1,
      anon_sym_PIPE,
    STATE(257), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30467] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1710), 1,
      aux_sym_list_token1,
    ACTIONS(1708), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30480] = 6,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2140), 1,
      aux_sym__thing_token1,
    ACTIONS(2142), 1,
      anon_sym_PIPE,
    STATE(263), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30499] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1747), 1,
      aux_sym_list_token1,
    ACTIONS(1745), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30512] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2144), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [30523] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1300), 1,
      aux_sym__thing_token1,
    ACTIONS(1290), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30536] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1964), 1,
      aux_sym_list_token1,
    ACTIONS(1962), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30549] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1302), 1,
      aux_sym__thing_token1,
    ACTIONS(1304), 1,
      aux_sym_text_token1,
    ACTIONS(1292), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30564] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2146), 1,
      aux_sym__thing_token1,
    ACTIONS(2148), 1,
      aux_sym_text_token1,
    ACTIONS(2052), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30579] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2150), 5,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_COLON_COLON_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_PLUS_EQ,
  [30590] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1741), 1,
      aux_sym_list_token1,
    ACTIONS(1739), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30603] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1288), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30614] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1892), 1,
      aux_sym_list_token1,
    ACTIONS(1890), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30627] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1912), 1,
      aux_sym__thing_token1,
    ACTIONS(1910), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30640] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1916), 1,
      aux_sym__thing_token1,
    ACTIONS(1914), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30653] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2054), 1,
      aux_sym_text_token1,
    ACTIONS(2052), 4,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30666] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2152), 5,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      sym__recipeprefix,
      aux_sym__shell_text_without_split_token1,
      anon_sym_SLASH_SLASH,
  [30677] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1294), 1,
      aux_sym_text_token1,
    ACTIONS(1292), 4,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [30690] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1290), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30701] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1539), 5,
      anon_sym_RPAREN,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
      aux_sym_text_token1,
  [30712] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1914), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [30722] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2154), 1,
      aux_sym__thing_token1,
    STATE(88), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30738] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1890), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [30748] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2156), 1,
      aux_sym__thing_token1,
    STATE(990), 1,
      aux_sym_paths_repeat1,
    ACTIONS(1046), 2,
      anon_sym_COLON2,
      anon_sym_SEMI2,
  [30762] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2158), 1,
      aux_sym__thing_token1,
    STATE(299), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30778] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2160), 1,
      aux_sym__thing_token1,
    STATE(286), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30794] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2162), 1,
      aux_sym__thing_token1,
    STATE(97), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30810] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2164), 1,
      aux_sym__thing_token1,
    STATE(98), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30826] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1745), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [30836] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2166), 1,
      aux_sym__thing_token1,
    STATE(281), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30852] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2168), 1,
      aux_sym__thing_token1,
    STATE(100), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30868] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2170), 1,
      aux_sym__thing_token1,
    STATE(275), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [30884] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1739), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [30894] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1739), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [30904] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1890), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [30914] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2172), 1,
      aux_sym__thing_token1,
    ACTIONS(2174), 1,
      anon_sym_COLON,
    ACTIONS(2176), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [30928] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2178), 1,
      aux_sym__thing_token1,
    STATE(104), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30944] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2180), 1,
      aux_sym__thing_token1,
    STATE(116), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [30960] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2172), 1,
      aux_sym__thing_token1,
    ACTIONS(2182), 1,
      anon_sym_COLON,
    ACTIONS(2176), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [30974] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2172), 1,
      aux_sym__thing_token1,
    ACTIONS(2184), 1,
      anon_sym_COLON,
    ACTIONS(2176), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [30988] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2186), 1,
      aux_sym__thing_token1,
    STATE(250), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [31004] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1745), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31014] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2188), 1,
      aux_sym__thing_token1,
    STATE(242), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [31030] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2190), 1,
      aux_sym__thing_token1,
    STATE(233), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [31046] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1910), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31056] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2192), 1,
      aux_sym__thing_token1,
    STATE(230), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [31072] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2194), 1,
      aux_sym__thing_token1,
    STATE(279), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [31088] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1708), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31098] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1691), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31108] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1910), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [31118] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1936), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [31128] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1962), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31138] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1946), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31148] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2196), 1,
      anon_sym_endif,
    ACTIONS(2198), 1,
      anon_sym_else,
    STATE(986), 2,
      sym_elsif_directive,
      aux_sym_conditional_repeat1,
  [31162] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1708), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [31172] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2172), 1,
      aux_sym__thing_token1,
    ACTIONS(2201), 1,
      anon_sym_COLON,
    ACTIONS(2176), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [31186] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2203), 1,
      aux_sym__thing_token1,
    STATE(314), 1,
      sym_recipe,
    STATE(1233), 1,
      sym__attached_recipe_line,
  [31202] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1062), 1,
      aux_sym__thing_token1,
    STATE(990), 1,
      aux_sym_paths_repeat1,
    ACTIONS(2205), 2,
      anon_sym_COLON2,
      anon_sym_SEMI2,
  [31216] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1936), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31226] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1691), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [31236] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1697), 1,
      aux_sym_list_token1,
    ACTIONS(2098), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [31248] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2102), 1,
      aux_sym_list_token1,
    ACTIONS(2104), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [31260] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2208), 1,
      aux_sym__thing_token1,
    STATE(152), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [31276] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1962), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [31286] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2210), 1,
      aux_sym__thing_token1,
    STATE(129), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [31302] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1914), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_DQUOTE,
      aux_sym__string_token1,
  [31312] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2212), 1,
      aux_sym__thing_token1,
    STATE(158), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [31328] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1946), 4,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SQUOTE,
      aux_sym__string_token1,
  [31338] = 5,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2214), 1,
      aux_sym__thing_token1,
    STATE(163), 1,
      sym_recipe,
    STATE(1184), 1,
      sym__attached_recipe_line,
  [31354] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2110), 1,
      aux_sym__thing_token1,
    ACTIONS(2112), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [31366] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(1728), 1,
      aux_sym__thing_token1,
    ACTIONS(2114), 3,
      anon_sym_DOLLAR,
      anon_sym_DOLLAR_DOLLAR,
      anon_sym_SLASH_SLASH,
  [31378] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2216), 1,
      anon_sym_endef,
    ACTIONS(2218), 1,
      sym__rawline,
    STATE(1005), 1,
      aux_sym_define_directive_repeat1,
  [31391] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2220), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31404] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2222), 1,
      anon_sym_endef,
    ACTIONS(2224), 1,
      sym__rawline,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31417] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2227), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31430] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2229), 1,
      anon_sym_endef,
    STATE(1053), 1,
      aux_sym_define_directive_repeat1,
  [31443] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2231), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2233), 1,
      anon_sym_RBRACE,
    ACTIONS(2235), 2,
      anon_sym_D,
      anon_sym_F,
  [31467] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2233), 1,
      anon_sym_RPAREN,
    ACTIONS(2237), 2,
      anon_sym_D,
      anon_sym_F,
  [31478] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2239), 1,
      anon_sym_endef,
    STATE(1059), 1,
      aux_sym_define_directive_repeat1,
  [31491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2241), 1,
      anon_sym_RPAREN,
    ACTIONS(2243), 2,
      anon_sym_D,
      anon_sym_F,
  [31502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2241), 1,
      anon_sym_RBRACE,
    ACTIONS(2245), 2,
      anon_sym_D,
      anon_sym_F,
  [31513] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2247), 1,
      anon_sym_RPAREN,
    ACTIONS(2249), 2,
      anon_sym_D,
      anon_sym_F,
  [31524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2251), 1,
      anon_sym_RPAREN,
    ACTIONS(2253), 2,
      anon_sym_D,
      anon_sym_F,
  [31535] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2255), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2247), 1,
      anon_sym_RBRACE,
    ACTIONS(2257), 2,
      anon_sym_D,
      anon_sym_F,
  [31559] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2259), 1,
      anon_sym_endef,
    STATE(1054), 1,
      aux_sym_define_directive_repeat1,
  [31572] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2172), 1,
      aux_sym__thing_token1,
    ACTIONS(2176), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [31583] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2261), 1,
      anon_sym_COMMA,
    ACTIONS(2263), 1,
      anon_sym_RPAREN,
    STATE(1051), 1,
      aux_sym_arguments_repeat1,
  [31596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2251), 1,
      anon_sym_RBRACE,
    ACTIONS(2265), 2,
      anon_sym_D,
      anon_sym_F,
  [31607] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2267), 1,
      anon_sym_RBRACE,
    ACTIONS(2269), 2,
      anon_sym_D,
      anon_sym_F,
  [31618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2267), 1,
      anon_sym_RPAREN,
    ACTIONS(2271), 2,
      anon_sym_D,
      anon_sym_F,
  [31629] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2273), 1,
      anon_sym_RPAREN,
    ACTIONS(2275), 2,
      anon_sym_D,
      anon_sym_F,
  [31640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2277), 1,
      anon_sym_RBRACE,
    ACTIONS(2279), 2,
      anon_sym_D,
      anon_sym_F,
  [31651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2277), 1,
      anon_sym_RPAREN,
    ACTIONS(2281), 2,
      anon_sym_D,
      anon_sym_F,
  [31662] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2283), 1,
      anon_sym_RPAREN,
    ACTIONS(2285), 2,
      anon_sym_D,
      anon_sym_F,
  [31673] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2287), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2289), 1,
      anon_sym_RPAREN,
    ACTIONS(2291), 2,
      anon_sym_D,
      anon_sym_F,
  [31697] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2289), 1,
      anon_sym_RBRACE,
    ACTIONS(2293), 2,
      anon_sym_D,
      anon_sym_F,
  [31708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2283), 1,
      anon_sym_RBRACE,
    ACTIONS(2295), 2,
      anon_sym_D,
      anon_sym_F,
  [31719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2297), 1,
      anon_sym_RBRACE,
    ACTIONS(2299), 2,
      anon_sym_D,
      anon_sym_F,
  [31730] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2301), 1,
      anon_sym_endef,
    STATE(1017), 1,
      aux_sym_define_directive_repeat1,
  [31743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2303), 1,
      anon_sym_RPAREN,
    ACTIONS(2305), 2,
      anon_sym_D,
      anon_sym_F,
  [31754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2297), 1,
      anon_sym_RPAREN,
    ACTIONS(2307), 2,
      anon_sym_D,
      anon_sym_F,
  [31765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2303), 1,
      anon_sym_RBRACE,
    ACTIONS(2309), 2,
      anon_sym_D,
      anon_sym_F,
  [31776] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2311), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31789] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2313), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2315), 1,
      anon_sym_COLON,
    ACTIONS(2317), 2,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
  [31813] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2319), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31826] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2321), 1,
      anon_sym_endef,
    STATE(1029), 1,
      aux_sym_define_directive_repeat1,
  [31839] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2261), 1,
      anon_sym_COMMA,
    ACTIONS(2323), 1,
      anon_sym_RPAREN,
    STATE(1021), 1,
      aux_sym_arguments_repeat1,
  [31852] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2325), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31865] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2327), 1,
      anon_sym_endef,
    STATE(1009), 1,
      aux_sym_define_directive_repeat1,
  [31878] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2329), 1,
      anon_sym_endef,
    STATE(1038), 1,
      aux_sym_define_directive_repeat1,
  [31891] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2331), 1,
      anon_sym_endef,
    STATE(1007), 1,
      aux_sym_define_directive_repeat1,
  [31904] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2333), 1,
      anon_sym_endef,
    STATE(1055), 1,
      aux_sym_define_directive_repeat1,
  [31917] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2335), 1,
      anon_sym_endef,
    STATE(1039), 1,
      aux_sym_define_directive_repeat1,
  [31930] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2337), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31943] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2339), 1,
      anon_sym_COMMA,
    ACTIONS(2342), 1,
      anon_sym_RPAREN,
    STATE(1051), 1,
      aux_sym_arguments_repeat1,
  [31956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2344), 1,
      anon_sym_COLON,
    ACTIONS(2346), 2,
      anon_sym_AMP_COLON,
      anon_sym_COLON_COLON,
  [31967] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2348), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31980] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2350), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [31993] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2352), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [32006] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2354), 1,
      anon_sym_endef,
    STATE(1050), 1,
      aux_sym_define_directive_repeat1,
  [32019] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2356), 1,
      anon_sym_endef,
    STATE(1044), 1,
      aux_sym_define_directive_repeat1,
  [32032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2273), 1,
      anon_sym_RBRACE,
    ACTIONS(2358), 2,
      anon_sym_D,
      anon_sym_F,
  [32043] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2360), 1,
      anon_sym_endef,
    STATE(1006), 1,
      aux_sym_define_directive_repeat1,
  [32056] = 4,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym__rawline,
    ACTIONS(2362), 1,
      anon_sym_endef,
    STATE(1041), 1,
      aux_sym_define_directive_repeat1,
  [32069] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2364), 2,
      anon_sym_endef,
      sym__rawline,
  [32077] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2366), 1,
      aux_sym__thing_token1,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
  [32087] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2370), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [32095] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
    ACTIONS(2372), 1,
      aux_sym__thing_token1,
  [32105] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
    ACTIONS(2374), 1,
      aux_sym__thing_token1,
  [32115] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2376), 1,
      aux_sym__thing_token1,
    ACTIONS(2378), 1,
      aux_sym__ordinary_rule_token1,
  [32125] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2380), 1,
      sym_word,
    ACTIONS(2382), 1,
      aux_sym__thing_token1,
  [32135] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2384), 1,
      aux_sym__thing_token1,
    ACTIONS(2386), 1,
      anon_sym_COLON,
  [32145] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2388), 1,
      sym_word,
    ACTIONS(2390), 1,
      aux_sym__thing_token1,
  [32155] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
    ACTIONS(2392), 1,
      aux_sym__thing_token1,
  [32165] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
    ACTIONS(2394), 1,
      aux_sym__thing_token1,
  [32175] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
    ACTIONS(2396), 1,
      aux_sym__thing_token1,
  [32185] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
    ACTIONS(2398), 1,
      aux_sym__thing_token1,
  [32195] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2400), 1,
      aux_sym__thing_token1,
    ACTIONS(2402), 1,
      anon_sym_COLON,
  [32205] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
    ACTIONS(2404), 1,
      aux_sym__thing_token1,
  [32215] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2406), 1,
      aux_sym__thing_token1,
    ACTIONS(2408), 1,
      aux_sym__ordinary_rule_token1,
  [32225] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2410), 1,
      aux_sym__thing_token1,
    ACTIONS(2412), 1,
      aux_sym__ordinary_rule_token1,
  [32235] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2414), 1,
      sym_word,
    ACTIONS(2416), 1,
      aux_sym__ordinary_rule_token1,
  [32245] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2418), 1,
      sym_word,
    ACTIONS(2420), 1,
      aux_sym__ordinary_rule_token1,
  [32255] = 3,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2422), 1,
      aux_sym__thing_token1,
    ACTIONS(2424), 1,
      aux_sym__ordinary_rule_token1,
  [32265] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2426), 1,
      aux_sym__thing_token1,
  [32272] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2428), 1,
      aux_sym__thing_token1,
  [32279] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2430), 1,
      aux_sym__thing_token1,
  [32286] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2368), 1,
      aux_sym_list_token1,
  [32293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2432), 1,
      anon_sym_RPAREN,
  [32300] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2434), 1,
      aux_sym__thing_token1,
  [32307] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2436), 1,
      aux_sym__thing_token1,
  [32314] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2438), 1,
      aux_sym__thing_token1,
  [32321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2080), 1,
      anon_sym_endif,
  [32328] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2440), 1,
      aux_sym__thing_token1,
  [32335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2442), 1,
      anon_sym_endif,
  [32342] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2444), 1,
      aux_sym__thing_token1,
  [32349] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2446), 1,
      aux_sym__thing_token1,
  [32356] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2448), 1,
      aux_sym__thing_token1,
  [32363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2450), 1,
      anon_sym_RPAREN,
  [32370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2452), 1,
      anon_sym_RPAREN,
  [32377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2454), 1,
      anon_sym_RPAREN,
  [32384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2456), 1,
      anon_sym_RPAREN2,
  [32391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2450), 1,
      anon_sym_RBRACE,
  [32398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2458), 1,
      anon_sym_RPAREN,
  [32405] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2460), 1,
      aux_sym__thing_token1,
  [32412] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2462), 1,
      anon_sym_endif,
  [32419] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2464), 1,
      aux_sym__thing_token1,
  [32426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2466), 1,
      anon_sym_RPAREN,
  [32433] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2468), 1,
      aux_sym__thing_token1,
  [32440] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2470), 1,
      aux_sym__thing_token1,
  [32447] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2472), 1,
      aux_sym__thing_token1,
  [32454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2474), 1,
      anon_sym_RPAREN,
  [32461] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2476), 1,
      aux_sym__thing_token1,
  [32468] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2478), 1,
      aux_sym__thing_token1,
  [32475] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2480), 1,
      sym_word,
  [32482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2482), 1,
      anon_sym_RPAREN,
  [32489] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2484), 1,
      aux_sym__thing_token1,
  [32496] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2486), 1,
      aux_sym__thing_token1,
  [32503] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2488), 1,
      anon_sym_RPAREN,
  [32510] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2490), 1,
      aux_sym__thing_token1,
  [32517] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2492), 1,
      aux_sym__thing_token1,
  [32524] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2494), 1,
      aux_sym__thing_token1,
  [32531] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2474), 1,
      anon_sym_RBRACE,
  [32538] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2496), 1,
      aux_sym__thing_token1,
  [32545] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2498), 1,
      aux_sym__thing_token1,
  [32552] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2500), 1,
      aux_sym__thing_token1,
  [32559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2502), 1,
      anon_sym_RPAREN,
  [32566] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2504), 1,
      anon_sym_RPAREN,
  [32573] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2506), 1,
      aux_sym__thing_token1,
  [32580] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2508), 1,
      aux_sym__thing_token1,
  [32587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2084), 1,
      anon_sym_endif,
  [32594] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2510), 1,
      aux_sym__thing_token1,
  [32601] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2512), 1,
      anon_sym_RPAREN,
  [32608] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2514), 1,
      aux_sym__thing_token1,
  [32615] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2134), 1,
      anon_sym_endif,
  [32622] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2516), 1,
      aux_sym__thing_token1,
  [32629] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2518), 1,
      aux_sym__thing_token1,
  [32636] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2520), 1,
      aux_sym__thing_token1,
  [32643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2522), 1,
      anon_sym_RPAREN,
  [32650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2100), 1,
      anon_sym_endif,
  [32657] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2432), 1,
      anon_sym_RBRACE,
  [32664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2524), 1,
      anon_sym_endif,
  [32671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2526), 1,
      anon_sym_RPAREN,
  [32678] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2528), 1,
      anon_sym_RPAREN,
  [32685] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2530), 1,
      anon_sym_endif,
  [32692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2532), 1,
      anon_sym_RBRACE,
  [32699] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2534), 1,
      anon_sym_RPAREN,
  [32706] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2536), 1,
      aux_sym__thing_token1,
  [32713] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2538), 1,
      aux_sym__thing_token1,
  [32720] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2540), 1,
      anon_sym_RPAREN,
  [32727] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2542), 1,
      anon_sym_RPAREN,
  [32734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2544), 1,
      anon_sym_RPAREN,
  [32741] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2532), 1,
      anon_sym_RPAREN,
  [32748] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2546), 1,
      aux_sym__thing_token1,
  [32755] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2548), 1,
      aux_sym__thing_token1,
  [32762] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2550), 1,
      aux_sym__thing_token1,
  [32769] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2552), 1,
      aux_sym__thing_token1,
  [32776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2554), 1,
      anon_sym_RPAREN,
  [32783] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2556), 1,
      aux_sym__thing_token1,
  [32790] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2558), 1,
      aux_sym__thing_token1,
  [32797] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2560), 1,
      aux_sym__thing_token1,
  [32804] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2562), 1,
      aux_sym__thing_token1,
  [32811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2564), 1,
      anon_sym_RPAREN,
  [32818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2566), 1,
      anon_sym_RBRACE,
  [32825] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2568), 1,
      aux_sym__thing_token1,
  [32832] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2570), 1,
      anon_sym_RPAREN,
  [32839] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2572), 1,
      aux_sym__thing_token1,
  [32846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2574), 1,
      anon_sym_RPAREN,
  [32853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2566), 1,
      anon_sym_RPAREN,
  [32860] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2576), 1,
      aux_sym__thing_token1,
  [32867] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2578), 1,
      aux_sym__thing_token1,
  [32874] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2580), 1,
      aux_sym__thing_token1,
  [32881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2582), 1,
      anon_sym_RPAREN,
  [32888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2584), 1,
      anon_sym_RPAREN,
  [32895] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2512), 1,
      aux_sym__thing_token1,
  [32902] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2586), 1,
      aux_sym__thing_token1,
  [32909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2588), 1,
      anon_sym_RBRACE,
  [32916] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2590), 1,
      anon_sym_RPAREN,
  [32923] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2592), 1,
      anon_sym_RPAREN,
  [32930] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2594), 1,
      aux_sym__thing_token1,
  [32937] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2596), 1,
      aux_sym__thing_token1,
  [32944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2598), 1,
      anon_sym_endif,
  [32951] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2600), 1,
      aux_sym__thing_token1,
  [32958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2588), 1,
      anon_sym_RPAREN,
  [32965] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2602), 1,
      aux_sym__thing_token1,
  [32972] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2604), 1,
      aux_sym__thing_token1,
  [32979] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2606), 1,
      aux_sym__thing_token1,
  [32986] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2608), 1,
      aux_sym__thing_token1,
  [32993] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2610), 1,
      aux_sym__thing_token1,
  [33000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2612), 1,
      anon_sym_RPAREN,
  [33007] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2614), 1,
      aux_sym__thing_token1,
  [33014] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2616), 1,
      aux_sym__thing_token1,
  [33021] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2618), 1,
      aux_sym__thing_token1,
  [33028] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2620), 1,
      aux_sym__thing_token1,
  [33035] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2622), 1,
      anon_sym_RBRACE,
  [33042] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2624), 1,
      aux_sym__thing_token1,
  [33049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2626), 1,
      anon_sym_RPAREN,
  [33056] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2628), 1,
      anon_sym_RPAREN,
  [33063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2630), 1,
      anon_sym_RPAREN,
  [33070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2622), 1,
      anon_sym_RPAREN,
  [33077] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2632), 1,
      aux_sym__thing_token1,
  [33084] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2634), 1,
      aux_sym__thing_token1,
  [33091] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2636), 1,
      aux_sym__thing_token1,
  [33098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2638), 1,
      sym_word,
  [33105] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2640), 1,
      aux_sym__thing_token1,
  [33112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2642), 1,
      anon_sym_RPAREN,
  [33119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2644), 1,
      anon_sym_RPAREN,
  [33126] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2646), 1,
      aux_sym__thing_token1,
  [33133] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2648), 1,
      anon_sym_RBRACE,
  [33140] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2650), 1,
      anon_sym_RPAREN,
  [33147] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2652), 1,
      anon_sym_RPAREN,
  [33154] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2654), 1,
      aux_sym__thing_token1,
  [33161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2648), 1,
      anon_sym_RPAREN,
  [33168] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2656), 1,
      aux_sym__thing_token1,
  [33175] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2658), 1,
      anon_sym_RPAREN,
  [33182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2660), 1,
      anon_sym_RPAREN,
  [33189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2662), 1,
      anon_sym_RBRACE,
  [33196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      anon_sym_RPAREN,
  [33203] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2666), 1,
      anon_sym_RPAREN,
  [33210] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2662), 1,
      anon_sym_RPAREN,
  [33217] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2668), 1,
      aux_sym__thing_token1,
  [33224] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2670), 1,
      aux_sym__thing_token1,
  [33231] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2672), 1,
      aux_sym__thing_token1,
  [33238] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2674), 1,
      aux_sym__thing_token1,
  [33245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2676), 1,
      sym_word,
  [33252] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2678), 1,
      aux_sym__thing_token1,
  [33259] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2680), 1,
      aux_sym__thing_token1,
  [33266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2682), 1,
      anon_sym_RPAREN,
  [33273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2684), 1,
      anon_sym_RPAREN,
  [33280] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2686), 1,
      anon_sym_RBRACE,
  [33287] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2688), 1,
      aux_sym__thing_token1,
  [33294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2690), 1,
      anon_sym_RPAREN,
  [33301] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2692), 1,
      aux_sym__thing_token1,
  [33308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2694), 1,
      anon_sym_RPAREN,
  [33315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2686), 1,
      anon_sym_RPAREN,
  [33322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2696), 1,
      anon_sym_RPAREN2,
  [33329] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2698), 1,
      aux_sym__thing_token1,
  [33336] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2700), 1,
      aux_sym__thing_token1,
  [33343] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2702), 1,
      aux_sym__thing_token1,
  [33350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2704), 1,
      anon_sym_endif,
  [33357] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2706), 1,
      aux_sym__thing_token1,
  [33364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2124), 1,
      anon_sym_endif,
  [33371] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2708), 1,
      aux_sym__thing_token1,
  [33378] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2710), 1,
      aux_sym__thing_token1,
  [33385] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2712), 1,
      aux_sym__thing_token1,
  [33392] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2714), 1,
      aux_sym__thing_token1,
  [33399] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2716), 1,
      aux_sym__thing_token1,
  [33406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2718), 1,
      anon_sym_RPAREN2,
  [33413] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2720), 1,
      aux_sym__thing_token1,
  [33420] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2722), 1,
      aux_sym__thing_token1,
  [33427] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2724), 1,
      aux_sym__thing_token1,
  [33434] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2726), 1,
      aux_sym__thing_token1,
  [33441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2728), 1,
      anon_sym_RPAREN,
  [33448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2730), 1,
      anon_sym_RPAREN,
  [33455] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2732), 1,
      aux_sym__thing_token1,
  [33462] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2734), 1,
      aux_sym__thing_token1,
  [33469] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2736), 1,
      aux_sym__thing_token1,
  [33476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2738), 1,
      anon_sym_RBRACE,
  [33483] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2740), 1,
      anon_sym_RPAREN,
  [33490] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2742), 1,
      aux_sym__thing_token1,
  [33497] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2744), 1,
      aux_sym__thing_token1,
  [33504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2746), 1,
      anon_sym_RPAREN,
  [33511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2106), 1,
      anon_sym_endif,
  [33518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2738), 1,
      anon_sym_RPAREN,
  [33525] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2748), 1,
      aux_sym__thing_token1,
  [33532] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2750), 1,
      aux_sym__thing_token1,
  [33539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2752), 1,
      sym_word,
  [33546] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2754), 1,
      aux_sym__thing_token1,
  [33553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2756), 1,
      anon_sym_COLON,
  [33560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2758), 1,
      anon_sym_RPAREN2,
  [33567] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2760), 1,
      aux_sym__thing_token1,
  [33574] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2762), 1,
      aux_sym__thing_token1,
  [33581] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2764), 1,
      aux_sym__thing_token1,
  [33588] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2766), 1,
      aux_sym__thing_token1,
  [33595] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2768), 1,
      aux_sym__thing_token1,
  [33602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2770), 1,
      anon_sym_COLON,
  [33609] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2772), 1,
      aux_sym__thing_token1,
  [33616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2774), 1,
      anon_sym_RPAREN,
  [33623] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2776), 1,
      aux_sym__thing_token1,
  [33630] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2778), 1,
      aux_sym__thing_token1,
  [33637] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2780), 1,
      aux_sym__thing_token1,
  [33644] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2782), 1,
      aux_sym__thing_token1,
  [33651] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2784), 1,
      aux_sym__thing_token1,
  [33658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2786), 1,
      ts_builtin_sym_end,
  [33665] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2788), 1,
      aux_sym__thing_token1,
  [33672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2790), 1,
      sym_word,
  [33679] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2792), 1,
      aux_sym__thing_token1,
  [33686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2794), 1,
      sym_word,
  [33693] = 2,
    ACTIONS(77), 1,
      sym_comment,
    ACTIONS(2796), 1,
      aux_sym__thing_token1,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(8)] = 0,
  [SMALL_STATE(9)] = 119,
  [SMALL_STATE(10)] = 238,
  [SMALL_STATE(11)] = 357,
  [SMALL_STATE(12)] = 475,
  [SMALL_STATE(13)] = 593,
  [SMALL_STATE(14)] = 674,
  [SMALL_STATE(15)] = 755,
  [SMALL_STATE(16)] = 836,
  [SMALL_STATE(17)] = 917,
  [SMALL_STATE(18)] = 998,
  [SMALL_STATE(19)] = 1079,
  [SMALL_STATE(20)] = 1160,
  [SMALL_STATE(21)] = 1241,
  [SMALL_STATE(22)] = 1322,
  [SMALL_STATE(23)] = 1403,
  [SMALL_STATE(24)] = 1484,
  [SMALL_STATE(25)] = 1565,
  [SMALL_STATE(26)] = 1681,
  [SMALL_STATE(27)] = 1797,
  [SMALL_STATE(28)] = 1849,
  [SMALL_STATE(29)] = 1901,
  [SMALL_STATE(30)] = 1953,
  [SMALL_STATE(31)] = 2005,
  [SMALL_STATE(32)] = 2057,
  [SMALL_STATE(33)] = 2109,
  [SMALL_STATE(34)] = 2161,
  [SMALL_STATE(35)] = 2213,
  [SMALL_STATE(36)] = 2265,
  [SMALL_STATE(37)] = 2317,
  [SMALL_STATE(38)] = 2369,
  [SMALL_STATE(39)] = 2421,
  [SMALL_STATE(40)] = 2473,
  [SMALL_STATE(41)] = 2525,
  [SMALL_STATE(42)] = 2577,
  [SMALL_STATE(43)] = 2629,
  [SMALL_STATE(44)] = 2681,
  [SMALL_STATE(45)] = 2733,
  [SMALL_STATE(46)] = 2785,
  [SMALL_STATE(47)] = 2837,
  [SMALL_STATE(48)] = 2889,
  [SMALL_STATE(49)] = 2941,
  [SMALL_STATE(50)] = 2993,
  [SMALL_STATE(51)] = 3045,
  [SMALL_STATE(52)] = 3098,
  [SMALL_STATE(53)] = 3151,
  [SMALL_STATE(54)] = 3204,
  [SMALL_STATE(55)] = 3257,
  [SMALL_STATE(56)] = 3310,
  [SMALL_STATE(57)] = 3363,
  [SMALL_STATE(58)] = 3416,
  [SMALL_STATE(59)] = 3469,
  [SMALL_STATE(60)] = 3522,
  [SMALL_STATE(61)] = 3575,
  [SMALL_STATE(62)] = 3628,
  [SMALL_STATE(63)] = 3681,
  [SMALL_STATE(64)] = 3734,
  [SMALL_STATE(65)] = 3787,
  [SMALL_STATE(66)] = 3840,
  [SMALL_STATE(67)] = 3893,
  [SMALL_STATE(68)] = 3946,
  [SMALL_STATE(69)] = 3999,
  [SMALL_STATE(70)] = 4052,
  [SMALL_STATE(71)] = 4105,
  [SMALL_STATE(72)] = 4158,
  [SMALL_STATE(73)] = 4211,
  [SMALL_STATE(74)] = 4264,
  [SMALL_STATE(75)] = 4317,
  [SMALL_STATE(76)] = 4374,
  [SMALL_STATE(77)] = 4431,
  [SMALL_STATE(78)] = 4488,
  [SMALL_STATE(79)] = 4545,
  [SMALL_STATE(80)] = 4602,
  [SMALL_STATE(81)] = 4659,
  [SMALL_STATE(82)] = 4714,
  [SMALL_STATE(83)] = 4769,
  [SMALL_STATE(84)] = 4821,
  [SMALL_STATE(85)] = 4873,
  [SMALL_STATE(86)] = 4922,
  [SMALL_STATE(87)] = 4971,
  [SMALL_STATE(88)] = 5003,
  [SMALL_STATE(89)] = 5035,
  [SMALL_STATE(90)] = 5067,
  [SMALL_STATE(91)] = 5099,
  [SMALL_STATE(92)] = 5131,
  [SMALL_STATE(93)] = 5163,
  [SMALL_STATE(94)] = 5195,
  [SMALL_STATE(95)] = 5227,
  [SMALL_STATE(96)] = 5259,
  [SMALL_STATE(97)] = 5307,
  [SMALL_STATE(98)] = 5339,
  [SMALL_STATE(99)] = 5371,
  [SMALL_STATE(100)] = 5403,
  [SMALL_STATE(101)] = 5435,
  [SMALL_STATE(102)] = 5479,
  [SMALL_STATE(103)] = 5523,
  [SMALL_STATE(104)] = 5555,
  [SMALL_STATE(105)] = 5587,
  [SMALL_STATE(106)] = 5619,
  [SMALL_STATE(107)] = 5663,
  [SMALL_STATE(108)] = 5695,
  [SMALL_STATE(109)] = 5727,
  [SMALL_STATE(110)] = 5759,
  [SMALL_STATE(111)] = 5791,
  [SMALL_STATE(112)] = 5823,
  [SMALL_STATE(113)] = 5855,
  [SMALL_STATE(114)] = 5887,
  [SMALL_STATE(115)] = 5919,
  [SMALL_STATE(116)] = 5951,
  [SMALL_STATE(117)] = 5983,
  [SMALL_STATE(118)] = 6015,
  [SMALL_STATE(119)] = 6047,
  [SMALL_STATE(120)] = 6079,
  [SMALL_STATE(121)] = 6111,
  [SMALL_STATE(122)] = 6143,
  [SMALL_STATE(123)] = 6175,
  [SMALL_STATE(124)] = 6207,
  [SMALL_STATE(125)] = 6239,
  [SMALL_STATE(126)] = 6271,
  [SMALL_STATE(127)] = 6303,
  [SMALL_STATE(128)] = 6335,
  [SMALL_STATE(129)] = 6367,
  [SMALL_STATE(130)] = 6399,
  [SMALL_STATE(131)] = 6431,
  [SMALL_STATE(132)] = 6463,
  [SMALL_STATE(133)] = 6495,
  [SMALL_STATE(134)] = 6527,
  [SMALL_STATE(135)] = 6571,
  [SMALL_STATE(136)] = 6619,
  [SMALL_STATE(137)] = 6651,
  [SMALL_STATE(138)] = 6683,
  [SMALL_STATE(139)] = 6715,
  [SMALL_STATE(140)] = 6747,
  [SMALL_STATE(141)] = 6779,
  [SMALL_STATE(142)] = 6811,
  [SMALL_STATE(143)] = 6843,
  [SMALL_STATE(144)] = 6875,
  [SMALL_STATE(145)] = 6907,
  [SMALL_STATE(146)] = 6939,
  [SMALL_STATE(147)] = 6971,
  [SMALL_STATE(148)] = 7003,
  [SMALL_STATE(149)] = 7035,
  [SMALL_STATE(150)] = 7067,
  [SMALL_STATE(151)] = 7099,
  [SMALL_STATE(152)] = 7131,
  [SMALL_STATE(153)] = 7163,
  [SMALL_STATE(154)] = 7195,
  [SMALL_STATE(155)] = 7227,
  [SMALL_STATE(156)] = 7259,
  [SMALL_STATE(157)] = 7291,
  [SMALL_STATE(158)] = 7323,
  [SMALL_STATE(159)] = 7355,
  [SMALL_STATE(160)] = 7403,
  [SMALL_STATE(161)] = 7435,
  [SMALL_STATE(162)] = 7467,
  [SMALL_STATE(163)] = 7499,
  [SMALL_STATE(164)] = 7531,
  [SMALL_STATE(165)] = 7563,
  [SMALL_STATE(166)] = 7595,
  [SMALL_STATE(167)] = 7627,
  [SMALL_STATE(168)] = 7659,
  [SMALL_STATE(169)] = 7691,
  [SMALL_STATE(170)] = 7723,
  [SMALL_STATE(171)] = 7755,
  [SMALL_STATE(172)] = 7787,
  [SMALL_STATE(173)] = 7819,
  [SMALL_STATE(174)] = 7851,
  [SMALL_STATE(175)] = 7883,
  [SMALL_STATE(176)] = 7915,
  [SMALL_STATE(177)] = 7963,
  [SMALL_STATE(178)] = 7995,
  [SMALL_STATE(179)] = 8027,
  [SMALL_STATE(180)] = 8059,
  [SMALL_STATE(181)] = 8091,
  [SMALL_STATE(182)] = 8123,
  [SMALL_STATE(183)] = 8155,
  [SMALL_STATE(184)] = 8203,
  [SMALL_STATE(185)] = 8235,
  [SMALL_STATE(186)] = 8267,
  [SMALL_STATE(187)] = 8299,
  [SMALL_STATE(188)] = 8331,
  [SMALL_STATE(189)] = 8366,
  [SMALL_STATE(190)] = 8397,
  [SMALL_STATE(191)] = 8446,
  [SMALL_STATE(192)] = 8487,
  [SMALL_STATE(193)] = 8518,
  [SMALL_STATE(194)] = 8549,
  [SMALL_STATE(195)] = 8590,
  [SMALL_STATE(196)] = 8621,
  [SMALL_STATE(197)] = 8662,
  [SMALL_STATE(198)] = 8697,
  [SMALL_STATE(199)] = 8744,
  [SMALL_STATE(200)] = 8775,
  [SMALL_STATE(201)] = 8816,
  [SMALL_STATE(202)] = 8863,
  [SMALL_STATE(203)] = 8906,
  [SMALL_STATE(204)] = 8947,
  [SMALL_STATE(205)] = 8988,
  [SMALL_STATE(206)] = 9029,
  [SMALL_STATE(207)] = 9060,
  [SMALL_STATE(208)] = 9107,
  [SMALL_STATE(209)] = 9138,
  [SMALL_STATE(210)] = 9179,
  [SMALL_STATE(211)] = 9222,
  [SMALL_STATE(212)] = 9253,
  [SMALL_STATE(213)] = 9294,
  [SMALL_STATE(214)] = 9335,
  [SMALL_STATE(215)] = 9388,
  [SMALL_STATE(216)] = 9429,
  [SMALL_STATE(217)] = 9482,
  [SMALL_STATE(218)] = 9529,
  [SMALL_STATE(219)] = 9582,
  [SMALL_STATE(220)] = 9635,
  [SMALL_STATE(221)] = 9665,
  [SMALL_STATE(222)] = 9705,
  [SMALL_STATE(223)] = 9735,
  [SMALL_STATE(224)] = 9765,
  [SMALL_STATE(225)] = 9795,
  [SMALL_STATE(226)] = 9825,
  [SMALL_STATE(227)] = 9855,
  [SMALL_STATE(228)] = 9885,
  [SMALL_STATE(229)] = 9915,
  [SMALL_STATE(230)] = 9945,
  [SMALL_STATE(231)] = 9975,
  [SMALL_STATE(232)] = 10005,
  [SMALL_STATE(233)] = 10035,
  [SMALL_STATE(234)] = 10065,
  [SMALL_STATE(235)] = 10095,
  [SMALL_STATE(236)] = 10125,
  [SMALL_STATE(237)] = 10155,
  [SMALL_STATE(238)] = 10185,
  [SMALL_STATE(239)] = 10215,
  [SMALL_STATE(240)] = 10245,
  [SMALL_STATE(241)] = 10275,
  [SMALL_STATE(242)] = 10305,
  [SMALL_STATE(243)] = 10335,
  [SMALL_STATE(244)] = 10365,
  [SMALL_STATE(245)] = 10395,
  [SMALL_STATE(246)] = 10425,
  [SMALL_STATE(247)] = 10455,
  [SMALL_STATE(248)] = 10485,
  [SMALL_STATE(249)] = 10515,
  [SMALL_STATE(250)] = 10545,
  [SMALL_STATE(251)] = 10575,
  [SMALL_STATE(252)] = 10605,
  [SMALL_STATE(253)] = 10635,
  [SMALL_STATE(254)] = 10665,
  [SMALL_STATE(255)] = 10695,
  [SMALL_STATE(256)] = 10737,
  [SMALL_STATE(257)] = 10767,
  [SMALL_STATE(258)] = 10797,
  [SMALL_STATE(259)] = 10827,
  [SMALL_STATE(260)] = 10857,
  [SMALL_STATE(261)] = 10897,
  [SMALL_STATE(262)] = 10947,
  [SMALL_STATE(263)] = 10977,
  [SMALL_STATE(264)] = 11007,
  [SMALL_STATE(265)] = 11037,
  [SMALL_STATE(266)] = 11067,
  [SMALL_STATE(267)] = 11097,
  [SMALL_STATE(268)] = 11127,
  [SMALL_STATE(269)] = 11157,
  [SMALL_STATE(270)] = 11187,
  [SMALL_STATE(271)] = 11217,
  [SMALL_STATE(272)] = 11247,
  [SMALL_STATE(273)] = 11277,
  [SMALL_STATE(274)] = 11307,
  [SMALL_STATE(275)] = 11337,
  [SMALL_STATE(276)] = 11367,
  [SMALL_STATE(277)] = 11407,
  [SMALL_STATE(278)] = 11437,
  [SMALL_STATE(279)] = 11467,
  [SMALL_STATE(280)] = 11497,
  [SMALL_STATE(281)] = 11527,
  [SMALL_STATE(282)] = 11557,
  [SMALL_STATE(283)] = 11587,
  [SMALL_STATE(284)] = 11637,
  [SMALL_STATE(285)] = 11667,
  [SMALL_STATE(286)] = 11697,
  [SMALL_STATE(287)] = 11727,
  [SMALL_STATE(288)] = 11757,
  [SMALL_STATE(289)] = 11787,
  [SMALL_STATE(290)] = 11837,
  [SMALL_STATE(291)] = 11867,
  [SMALL_STATE(292)] = 11907,
  [SMALL_STATE(293)] = 11937,
  [SMALL_STATE(294)] = 11967,
  [SMALL_STATE(295)] = 11997,
  [SMALL_STATE(296)] = 12027,
  [SMALL_STATE(297)] = 12057,
  [SMALL_STATE(298)] = 12097,
  [SMALL_STATE(299)] = 12127,
  [SMALL_STATE(300)] = 12157,
  [SMALL_STATE(301)] = 12187,
  [SMALL_STATE(302)] = 12227,
  [SMALL_STATE(303)] = 12257,
  [SMALL_STATE(304)] = 12299,
  [SMALL_STATE(305)] = 12329,
  [SMALL_STATE(306)] = 12359,
  [SMALL_STATE(307)] = 12389,
  [SMALL_STATE(308)] = 12423,
  [SMALL_STATE(309)] = 12453,
  [SMALL_STATE(310)] = 12503,
  [SMALL_STATE(311)] = 12533,
  [SMALL_STATE(312)] = 12563,
  [SMALL_STATE(313)] = 12593,
  [SMALL_STATE(314)] = 12623,
  [SMALL_STATE(315)] = 12653,
  [SMALL_STATE(316)] = 12683,
  [SMALL_STATE(317)] = 12713,
  [SMALL_STATE(318)] = 12743,
  [SMALL_STATE(319)] = 12773,
  [SMALL_STATE(320)] = 12820,
  [SMALL_STATE(321)] = 12861,
  [SMALL_STATE(322)] = 12906,
  [SMALL_STATE(323)] = 12953,
  [SMALL_STATE(324)] = 13000,
  [SMALL_STATE(325)] = 13039,
  [SMALL_STATE(326)] = 13078,
  [SMALL_STATE(327)] = 13119,
  [SMALL_STATE(328)] = 13166,
  [SMALL_STATE(329)] = 13211,
  [SMALL_STATE(330)] = 13254,
  [SMALL_STATE(331)] = 13299,
  [SMALL_STATE(332)] = 13343,
  [SMALL_STATE(333)] = 13387,
  [SMALL_STATE(334)] = 13431,
  [SMALL_STATE(335)] = 13475,
  [SMALL_STATE(336)] = 13513,
  [SMALL_STATE(337)] = 13545,
  [SMALL_STATE(338)] = 13585,
  [SMALL_STATE(339)] = 13626,
  [SMALL_STATE(340)] = 13667,
  [SMALL_STATE(341)] = 13708,
  [SMALL_STATE(342)] = 13749,
  [SMALL_STATE(343)] = 13790,
  [SMALL_STATE(344)] = 13831,
  [SMALL_STATE(345)] = 13872,
  [SMALL_STATE(346)] = 13909,
  [SMALL_STATE(347)] = 13950,
  [SMALL_STATE(348)] = 13991,
  [SMALL_STATE(349)] = 14032,
  [SMALL_STATE(350)] = 14071,
  [SMALL_STATE(351)] = 14108,
  [SMALL_STATE(352)] = 14149,
  [SMALL_STATE(353)] = 14190,
  [SMALL_STATE(354)] = 14231,
  [SMALL_STATE(355)] = 14272,
  [SMALL_STATE(356)] = 14313,
  [SMALL_STATE(357)] = 14352,
  [SMALL_STATE(358)] = 14387,
  [SMALL_STATE(359)] = 14428,
  [SMALL_STATE(360)] = 14463,
  [SMALL_STATE(361)] = 14504,
  [SMALL_STATE(362)] = 14545,
  [SMALL_STATE(363)] = 14586,
  [SMALL_STATE(364)] = 14627,
  [SMALL_STATE(365)] = 14668,
  [SMALL_STATE(366)] = 14703,
  [SMALL_STATE(367)] = 14744,
  [SMALL_STATE(368)] = 14782,
  [SMALL_STATE(369)] = 14820,
  [SMALL_STATE(370)] = 14858,
  [SMALL_STATE(371)] = 14896,
  [SMALL_STATE(372)] = 14934,
  [SMALL_STATE(373)] = 14972,
  [SMALL_STATE(374)] = 15010,
  [SMALL_STATE(375)] = 15048,
  [SMALL_STATE(376)] = 15086,
  [SMALL_STATE(377)] = 15124,
  [SMALL_STATE(378)] = 15166,
  [SMALL_STATE(379)] = 15204,
  [SMALL_STATE(380)] = 15242,
  [SMALL_STATE(381)] = 15280,
  [SMALL_STATE(382)] = 15318,
  [SMALL_STATE(383)] = 15356,
  [SMALL_STATE(384)] = 15394,
  [SMALL_STATE(385)] = 15432,
  [SMALL_STATE(386)] = 15470,
  [SMALL_STATE(387)] = 15508,
  [SMALL_STATE(388)] = 15546,
  [SMALL_STATE(389)] = 15584,
  [SMALL_STATE(390)] = 15622,
  [SMALL_STATE(391)] = 15660,
  [SMALL_STATE(392)] = 15698,
  [SMALL_STATE(393)] = 15736,
  [SMALL_STATE(394)] = 15774,
  [SMALL_STATE(395)] = 15812,
  [SMALL_STATE(396)] = 15850,
  [SMALL_STATE(397)] = 15888,
  [SMALL_STATE(398)] = 15930,
  [SMALL_STATE(399)] = 15968,
  [SMALL_STATE(400)] = 16006,
  [SMALL_STATE(401)] = 16044,
  [SMALL_STATE(402)] = 16082,
  [SMALL_STATE(403)] = 16120,
  [SMALL_STATE(404)] = 16158,
  [SMALL_STATE(405)] = 16196,
  [SMALL_STATE(406)] = 16234,
  [SMALL_STATE(407)] = 16272,
  [SMALL_STATE(408)] = 16310,
  [SMALL_STATE(409)] = 16348,
  [SMALL_STATE(410)] = 16386,
  [SMALL_STATE(411)] = 16424,
  [SMALL_STATE(412)] = 16462,
  [SMALL_STATE(413)] = 16500,
  [SMALL_STATE(414)] = 16538,
  [SMALL_STATE(415)] = 16576,
  [SMALL_STATE(416)] = 16614,
  [SMALL_STATE(417)] = 16652,
  [SMALL_STATE(418)] = 16690,
  [SMALL_STATE(419)] = 16728,
  [SMALL_STATE(420)] = 16766,
  [SMALL_STATE(421)] = 16802,
  [SMALL_STATE(422)] = 16840,
  [SMALL_STATE(423)] = 16878,
  [SMALL_STATE(424)] = 16916,
  [SMALL_STATE(425)] = 16954,
  [SMALL_STATE(426)] = 16992,
  [SMALL_STATE(427)] = 17030,
  [SMALL_STATE(428)] = 17068,
  [SMALL_STATE(429)] = 17104,
  [SMALL_STATE(430)] = 17142,
  [SMALL_STATE(431)] = 17180,
  [SMALL_STATE(432)] = 17218,
  [SMALL_STATE(433)] = 17256,
  [SMALL_STATE(434)] = 17286,
  [SMALL_STATE(435)] = 17324,
  [SMALL_STATE(436)] = 17362,
  [SMALL_STATE(437)] = 17400,
  [SMALL_STATE(438)] = 17442,
  [SMALL_STATE(439)] = 17480,
  [SMALL_STATE(440)] = 17518,
  [SMALL_STATE(441)] = 17556,
  [SMALL_STATE(442)] = 17594,
  [SMALL_STATE(443)] = 17632,
  [SMALL_STATE(444)] = 17670,
  [SMALL_STATE(445)] = 17705,
  [SMALL_STATE(446)] = 17742,
  [SMALL_STATE(447)] = 17777,
  [SMALL_STATE(448)] = 17812,
  [SMALL_STATE(449)] = 17847,
  [SMALL_STATE(450)] = 17882,
  [SMALL_STATE(451)] = 17917,
  [SMALL_STATE(452)] = 17952,
  [SMALL_STATE(453)] = 17987,
  [SMALL_STATE(454)] = 18022,
  [SMALL_STATE(455)] = 18059,
  [SMALL_STATE(456)] = 18094,
  [SMALL_STATE(457)] = 18129,
  [SMALL_STATE(458)] = 18164,
  [SMALL_STATE(459)] = 18199,
  [SMALL_STATE(460)] = 18232,
  [SMALL_STATE(461)] = 18267,
  [SMALL_STATE(462)] = 18294,
  [SMALL_STATE(463)] = 18329,
  [SMALL_STATE(464)] = 18364,
  [SMALL_STATE(465)] = 18399,
  [SMALL_STATE(466)] = 18432,
  [SMALL_STATE(467)] = 18467,
  [SMALL_STATE(468)] = 18502,
  [SMALL_STATE(469)] = 18539,
  [SMALL_STATE(470)] = 18576,
  [SMALL_STATE(471)] = 18611,
  [SMALL_STATE(472)] = 18646,
  [SMALL_STATE(473)] = 18681,
  [SMALL_STATE(474)] = 18716,
  [SMALL_STATE(475)] = 18751,
  [SMALL_STATE(476)] = 18786,
  [SMALL_STATE(477)] = 18821,
  [SMALL_STATE(478)] = 18854,
  [SMALL_STATE(479)] = 18889,
  [SMALL_STATE(480)] = 18924,
  [SMALL_STATE(481)] = 18959,
  [SMALL_STATE(482)] = 18994,
  [SMALL_STATE(483)] = 19029,
  [SMALL_STATE(484)] = 19064,
  [SMALL_STATE(485)] = 19099,
  [SMALL_STATE(486)] = 19134,
  [SMALL_STATE(487)] = 19171,
  [SMALL_STATE(488)] = 19206,
  [SMALL_STATE(489)] = 19241,
  [SMALL_STATE(490)] = 19276,
  [SMALL_STATE(491)] = 19311,
  [SMALL_STATE(492)] = 19344,
  [SMALL_STATE(493)] = 19379,
  [SMALL_STATE(494)] = 19414,
  [SMALL_STATE(495)] = 19445,
  [SMALL_STATE(496)] = 19480,
  [SMALL_STATE(497)] = 19515,
  [SMALL_STATE(498)] = 19550,
  [SMALL_STATE(499)] = 19585,
  [SMALL_STATE(500)] = 19620,
  [SMALL_STATE(501)] = 19655,
  [SMALL_STATE(502)] = 19690,
  [SMALL_STATE(503)] = 19725,
  [SMALL_STATE(504)] = 19756,
  [SMALL_STATE(505)] = 19791,
  [SMALL_STATE(506)] = 19824,
  [SMALL_STATE(507)] = 19859,
  [SMALL_STATE(508)] = 19894,
  [SMALL_STATE(509)] = 19929,
  [SMALL_STATE(510)] = 19963,
  [SMALL_STATE(511)] = 19995,
  [SMALL_STATE(512)] = 20029,
  [SMALL_STATE(513)] = 20061,
  [SMALL_STATE(514)] = 20095,
  [SMALL_STATE(515)] = 20129,
  [SMALL_STATE(516)] = 20159,
  [SMALL_STATE(517)] = 20191,
  [SMALL_STATE(518)] = 20225,
  [SMALL_STATE(519)] = 20257,
  [SMALL_STATE(520)] = 20291,
  [SMALL_STATE(521)] = 20325,
  [SMALL_STATE(522)] = 20355,
  [SMALL_STATE(523)] = 20389,
  [SMALL_STATE(524)] = 20423,
  [SMALL_STATE(525)] = 20457,
  [SMALL_STATE(526)] = 20491,
  [SMALL_STATE(527)] = 20525,
  [SMALL_STATE(528)] = 20557,
  [SMALL_STATE(529)] = 20591,
  [SMALL_STATE(530)] = 20625,
  [SMALL_STATE(531)] = 20659,
  [SMALL_STATE(532)] = 20693,
  [SMALL_STATE(533)] = 20727,
  [SMALL_STATE(534)] = 20761,
  [SMALL_STATE(535)] = 20795,
  [SMALL_STATE(536)] = 20829,
  [SMALL_STATE(537)] = 20863,
  [SMALL_STATE(538)] = 20897,
  [SMALL_STATE(539)] = 20931,
  [SMALL_STATE(540)] = 20965,
  [SMALL_STATE(541)] = 20999,
  [SMALL_STATE(542)] = 21033,
  [SMALL_STATE(543)] = 21067,
  [SMALL_STATE(544)] = 21101,
  [SMALL_STATE(545)] = 21136,
  [SMALL_STATE(546)] = 21167,
  [SMALL_STATE(547)] = 21198,
  [SMALL_STATE(548)] = 21229,
  [SMALL_STATE(549)] = 21264,
  [SMALL_STATE(550)] = 21295,
  [SMALL_STATE(551)] = 21326,
  [SMALL_STATE(552)] = 21357,
  [SMALL_STATE(553)] = 21388,
  [SMALL_STATE(554)] = 21419,
  [SMALL_STATE(555)] = 21454,
  [SMALL_STATE(556)] = 21485,
  [SMALL_STATE(557)] = 21516,
  [SMALL_STATE(558)] = 21547,
  [SMALL_STATE(559)] = 21578,
  [SMALL_STATE(560)] = 21609,
  [SMALL_STATE(561)] = 21640,
  [SMALL_STATE(562)] = 21671,
  [SMALL_STATE(563)] = 21702,
  [SMALL_STATE(564)] = 21733,
  [SMALL_STATE(565)] = 21764,
  [SMALL_STATE(566)] = 21799,
  [SMALL_STATE(567)] = 21830,
  [SMALL_STATE(568)] = 21861,
  [SMALL_STATE(569)] = 21892,
  [SMALL_STATE(570)] = 21923,
  [SMALL_STATE(571)] = 21954,
  [SMALL_STATE(572)] = 21985,
  [SMALL_STATE(573)] = 22016,
  [SMALL_STATE(574)] = 22047,
  [SMALL_STATE(575)] = 22078,
  [SMALL_STATE(576)] = 22109,
  [SMALL_STATE(577)] = 22140,
  [SMALL_STATE(578)] = 22171,
  [SMALL_STATE(579)] = 22202,
  [SMALL_STATE(580)] = 22233,
  [SMALL_STATE(581)] = 22264,
  [SMALL_STATE(582)] = 22295,
  [SMALL_STATE(583)] = 22326,
  [SMALL_STATE(584)] = 22357,
  [SMALL_STATE(585)] = 22388,
  [SMALL_STATE(586)] = 22419,
  [SMALL_STATE(587)] = 22450,
  [SMALL_STATE(588)] = 22481,
  [SMALL_STATE(589)] = 22512,
  [SMALL_STATE(590)] = 22543,
  [SMALL_STATE(591)] = 22574,
  [SMALL_STATE(592)] = 22605,
  [SMALL_STATE(593)] = 22640,
  [SMALL_STATE(594)] = 22671,
  [SMALL_STATE(595)] = 22702,
  [SMALL_STATE(596)] = 22733,
  [SMALL_STATE(597)] = 22764,
  [SMALL_STATE(598)] = 22795,
  [SMALL_STATE(599)] = 22829,
  [SMALL_STATE(600)] = 22859,
  [SMALL_STATE(601)] = 22893,
  [SMALL_STATE(602)] = 22923,
  [SMALL_STATE(603)] = 22957,
  [SMALL_STATE(604)] = 22991,
  [SMALL_STATE(605)] = 23025,
  [SMALL_STATE(606)] = 23059,
  [SMALL_STATE(607)] = 23093,
  [SMALL_STATE(608)] = 23127,
  [SMALL_STATE(609)] = 23161,
  [SMALL_STATE(610)] = 23195,
  [SMALL_STATE(611)] = 23225,
  [SMALL_STATE(612)] = 23259,
  [SMALL_STATE(613)] = 23293,
  [SMALL_STATE(614)] = 23327,
  [SMALL_STATE(615)] = 23361,
  [SMALL_STATE(616)] = 23391,
  [SMALL_STATE(617)] = 23425,
  [SMALL_STATE(618)] = 23455,
  [SMALL_STATE(619)] = 23489,
  [SMALL_STATE(620)] = 23523,
  [SMALL_STATE(621)] = 23557,
  [SMALL_STATE(622)] = 23587,
  [SMALL_STATE(623)] = 23621,
  [SMALL_STATE(624)] = 23655,
  [SMALL_STATE(625)] = 23689,
  [SMALL_STATE(626)] = 23723,
  [SMALL_STATE(627)] = 23757,
  [SMALL_STATE(628)] = 23791,
  [SMALL_STATE(629)] = 23825,
  [SMALL_STATE(630)] = 23859,
  [SMALL_STATE(631)] = 23893,
  [SMALL_STATE(632)] = 23927,
  [SMALL_STATE(633)] = 23961,
  [SMALL_STATE(634)] = 23995,
  [SMALL_STATE(635)] = 24029,
  [SMALL_STATE(636)] = 24063,
  [SMALL_STATE(637)] = 24097,
  [SMALL_STATE(638)] = 24127,
  [SMALL_STATE(639)] = 24161,
  [SMALL_STATE(640)] = 24195,
  [SMALL_STATE(641)] = 24225,
  [SMALL_STATE(642)] = 24255,
  [SMALL_STATE(643)] = 24285,
  [SMALL_STATE(644)] = 24319,
  [SMALL_STATE(645)] = 24353,
  [SMALL_STATE(646)] = 24387,
  [SMALL_STATE(647)] = 24416,
  [SMALL_STATE(648)] = 24447,
  [SMALL_STATE(649)] = 24478,
  [SMALL_STATE(650)] = 24507,
  [SMALL_STATE(651)] = 24538,
  [SMALL_STATE(652)] = 24569,
  [SMALL_STATE(653)] = 24598,
  [SMALL_STATE(654)] = 24627,
  [SMALL_STATE(655)] = 24658,
  [SMALL_STATE(656)] = 24687,
  [SMALL_STATE(657)] = 24718,
  [SMALL_STATE(658)] = 24747,
  [SMALL_STATE(659)] = 24776,
  [SMALL_STATE(660)] = 24805,
  [SMALL_STATE(661)] = 24836,
  [SMALL_STATE(662)] = 24867,
  [SMALL_STATE(663)] = 24898,
  [SMALL_STATE(664)] = 24927,
  [SMALL_STATE(665)] = 24956,
  [SMALL_STATE(666)] = 24987,
  [SMALL_STATE(667)] = 25018,
  [SMALL_STATE(668)] = 25049,
  [SMALL_STATE(669)] = 25078,
  [SMALL_STATE(670)] = 25109,
  [SMALL_STATE(671)] = 25138,
  [SMALL_STATE(672)] = 25167,
  [SMALL_STATE(673)] = 25198,
  [SMALL_STATE(674)] = 25229,
  [SMALL_STATE(675)] = 25260,
  [SMALL_STATE(676)] = 25291,
  [SMALL_STATE(677)] = 25322,
  [SMALL_STATE(678)] = 25353,
  [SMALL_STATE(679)] = 25384,
  [SMALL_STATE(680)] = 25415,
  [SMALL_STATE(681)] = 25444,
  [SMALL_STATE(682)] = 25475,
  [SMALL_STATE(683)] = 25506,
  [SMALL_STATE(684)] = 25527,
  [SMALL_STATE(685)] = 25558,
  [SMALL_STATE(686)] = 25589,
  [SMALL_STATE(687)] = 25618,
  [SMALL_STATE(688)] = 25647,
  [SMALL_STATE(689)] = 25678,
  [SMALL_STATE(690)] = 25699,
  [SMALL_STATE(691)] = 25730,
  [SMALL_STATE(692)] = 25761,
  [SMALL_STATE(693)] = 25792,
  [SMALL_STATE(694)] = 25823,
  [SMALL_STATE(695)] = 25854,
  [SMALL_STATE(696)] = 25885,
  [SMALL_STATE(697)] = 25916,
  [SMALL_STATE(698)] = 25947,
  [SMALL_STATE(699)] = 25976,
  [SMALL_STATE(700)] = 26007,
  [SMALL_STATE(701)] = 26038,
  [SMALL_STATE(702)] = 26067,
  [SMALL_STATE(703)] = 26096,
  [SMALL_STATE(704)] = 26117,
  [SMALL_STATE(705)] = 26148,
  [SMALL_STATE(706)] = 26179,
  [SMALL_STATE(707)] = 26200,
  [SMALL_STATE(708)] = 26231,
  [SMALL_STATE(709)] = 26262,
  [SMALL_STATE(710)] = 26293,
  [SMALL_STATE(711)] = 26324,
  [SMALL_STATE(712)] = 26353,
  [SMALL_STATE(713)] = 26384,
  [SMALL_STATE(714)] = 26415,
  [SMALL_STATE(715)] = 26444,
  [SMALL_STATE(716)] = 26472,
  [SMALL_STATE(717)] = 26496,
  [SMALL_STATE(718)] = 26520,
  [SMALL_STATE(719)] = 26544,
  [SMALL_STATE(720)] = 26570,
  [SMALL_STATE(721)] = 26594,
  [SMALL_STATE(722)] = 26618,
  [SMALL_STATE(723)] = 26646,
  [SMALL_STATE(724)] = 26674,
  [SMALL_STATE(725)] = 26700,
  [SMALL_STATE(726)] = 26726,
  [SMALL_STATE(727)] = 26750,
  [SMALL_STATE(728)] = 26774,
  [SMALL_STATE(729)] = 26802,
  [SMALL_STATE(730)] = 26828,
  [SMALL_STATE(731)] = 26856,
  [SMALL_STATE(732)] = 26880,
  [SMALL_STATE(733)] = 26904,
  [SMALL_STATE(734)] = 26930,
  [SMALL_STATE(735)] = 26954,
  [SMALL_STATE(736)] = 26982,
  [SMALL_STATE(737)] = 27006,
  [SMALL_STATE(738)] = 27030,
  [SMALL_STATE(739)] = 27056,
  [SMALL_STATE(740)] = 27084,
  [SMALL_STATE(741)] = 27112,
  [SMALL_STATE(742)] = 27140,
  [SMALL_STATE(743)] = 27166,
  [SMALL_STATE(744)] = 27190,
  [SMALL_STATE(745)] = 27218,
  [SMALL_STATE(746)] = 27246,
  [SMALL_STATE(747)] = 27270,
  [SMALL_STATE(748)] = 27294,
  [SMALL_STATE(749)] = 27318,
  [SMALL_STATE(750)] = 27346,
  [SMALL_STATE(751)] = 27370,
  [SMALL_STATE(752)] = 27394,
  [SMALL_STATE(753)] = 27422,
  [SMALL_STATE(754)] = 27448,
  [SMALL_STATE(755)] = 27476,
  [SMALL_STATE(756)] = 27499,
  [SMALL_STATE(757)] = 27524,
  [SMALL_STATE(758)] = 27549,
  [SMALL_STATE(759)] = 27572,
  [SMALL_STATE(760)] = 27591,
  [SMALL_STATE(761)] = 27614,
  [SMALL_STATE(762)] = 27637,
  [SMALL_STATE(763)] = 27656,
  [SMALL_STATE(764)] = 27675,
  [SMALL_STATE(765)] = 27694,
  [SMALL_STATE(766)] = 27717,
  [SMALL_STATE(767)] = 27740,
  [SMALL_STATE(768)] = 27765,
  [SMALL_STATE(769)] = 27790,
  [SMALL_STATE(770)] = 27809,
  [SMALL_STATE(771)] = 27834,
  [SMALL_STATE(772)] = 27853,
  [SMALL_STATE(773)] = 27878,
  [SMALL_STATE(774)] = 27901,
  [SMALL_STATE(775)] = 27926,
  [SMALL_STATE(776)] = 27945,
  [SMALL_STATE(777)] = 27964,
  [SMALL_STATE(778)] = 27989,
  [SMALL_STATE(779)] = 28014,
  [SMALL_STATE(780)] = 28033,
  [SMALL_STATE(781)] = 28052,
  [SMALL_STATE(782)] = 28075,
  [SMALL_STATE(783)] = 28094,
  [SMALL_STATE(784)] = 28113,
  [SMALL_STATE(785)] = 28136,
  [SMALL_STATE(786)] = 28155,
  [SMALL_STATE(787)] = 28178,
  [SMALL_STATE(788)] = 28203,
  [SMALL_STATE(789)] = 28222,
  [SMALL_STATE(790)] = 28247,
  [SMALL_STATE(791)] = 28266,
  [SMALL_STATE(792)] = 28285,
  [SMALL_STATE(793)] = 28308,
  [SMALL_STATE(794)] = 28327,
  [SMALL_STATE(795)] = 28346,
  [SMALL_STATE(796)] = 28369,
  [SMALL_STATE(797)] = 28394,
  [SMALL_STATE(798)] = 28413,
  [SMALL_STATE(799)] = 28432,
  [SMALL_STATE(800)] = 28451,
  [SMALL_STATE(801)] = 28470,
  [SMALL_STATE(802)] = 28488,
  [SMALL_STATE(803)] = 28506,
  [SMALL_STATE(804)] = 28528,
  [SMALL_STATE(805)] = 28546,
  [SMALL_STATE(806)] = 28564,
  [SMALL_STATE(807)] = 28582,
  [SMALL_STATE(808)] = 28600,
  [SMALL_STATE(809)] = 28618,
  [SMALL_STATE(810)] = 28640,
  [SMALL_STATE(811)] = 28658,
  [SMALL_STATE(812)] = 28676,
  [SMALL_STATE(813)] = 28702,
  [SMALL_STATE(814)] = 28724,
  [SMALL_STATE(815)] = 28742,
  [SMALL_STATE(816)] = 28760,
  [SMALL_STATE(817)] = 28782,
  [SMALL_STATE(818)] = 28804,
  [SMALL_STATE(819)] = 28822,
  [SMALL_STATE(820)] = 28840,
  [SMALL_STATE(821)] = 28863,
  [SMALL_STATE(822)] = 28879,
  [SMALL_STATE(823)] = 28895,
  [SMALL_STATE(824)] = 28911,
  [SMALL_STATE(825)] = 28927,
  [SMALL_STATE(826)] = 28943,
  [SMALL_STATE(827)] = 28959,
  [SMALL_STATE(828)] = 28975,
  [SMALL_STATE(829)] = 28991,
  [SMALL_STATE(830)] = 29007,
  [SMALL_STATE(831)] = 29023,
  [SMALL_STATE(832)] = 29039,
  [SMALL_STATE(833)] = 29055,
  [SMALL_STATE(834)] = 29071,
  [SMALL_STATE(835)] = 29090,
  [SMALL_STATE(836)] = 29107,
  [SMALL_STATE(837)] = 29124,
  [SMALL_STATE(838)] = 29145,
  [SMALL_STATE(839)] = 29166,
  [SMALL_STATE(840)] = 29183,
  [SMALL_STATE(841)] = 29202,
  [SMALL_STATE(842)] = 29219,
  [SMALL_STATE(843)] = 29233,
  [SMALL_STATE(844)] = 29247,
  [SMALL_STATE(845)] = 29261,
  [SMALL_STATE(846)] = 29275,
  [SMALL_STATE(847)] = 29289,
  [SMALL_STATE(848)] = 29301,
  [SMALL_STATE(849)] = 29313,
  [SMALL_STATE(850)] = 29325,
  [SMALL_STATE(851)] = 29337,
  [SMALL_STATE(852)] = 29349,
  [SMALL_STATE(853)] = 29363,
  [SMALL_STATE(854)] = 29379,
  [SMALL_STATE(855)] = 29393,
  [SMALL_STATE(856)] = 29409,
  [SMALL_STATE(857)] = 29423,
  [SMALL_STATE(858)] = 29435,
  [SMALL_STATE(859)] = 29449,
  [SMALL_STATE(860)] = 29461,
  [SMALL_STATE(861)] = 29475,
  [SMALL_STATE(862)] = 29489,
  [SMALL_STATE(863)] = 29501,
  [SMALL_STATE(864)] = 29515,
  [SMALL_STATE(865)] = 29527,
  [SMALL_STATE(866)] = 29541,
  [SMALL_STATE(867)] = 29555,
  [SMALL_STATE(868)] = 29569,
  [SMALL_STATE(869)] = 29583,
  [SMALL_STATE(870)] = 29595,
  [SMALL_STATE(871)] = 29609,
  [SMALL_STATE(872)] = 29623,
  [SMALL_STATE(873)] = 29637,
  [SMALL_STATE(874)] = 29649,
  [SMALL_STATE(875)] = 29663,
  [SMALL_STATE(876)] = 29677,
  [SMALL_STATE(877)] = 29691,
  [SMALL_STATE(878)] = 29703,
  [SMALL_STATE(879)] = 29717,
  [SMALL_STATE(880)] = 29729,
  [SMALL_STATE(881)] = 29740,
  [SMALL_STATE(882)] = 29753,
  [SMALL_STATE(883)] = 29764,
  [SMALL_STATE(884)] = 29775,
  [SMALL_STATE(885)] = 29786,
  [SMALL_STATE(886)] = 29797,
  [SMALL_STATE(887)] = 29808,
  [SMALL_STATE(888)] = 29825,
  [SMALL_STATE(889)] = 29836,
  [SMALL_STATE(890)] = 29853,
  [SMALL_STATE(891)] = 29864,
  [SMALL_STATE(892)] = 29877,
  [SMALL_STATE(893)] = 29896,
  [SMALL_STATE(894)] = 29909,
  [SMALL_STATE(895)] = 29920,
  [SMALL_STATE(896)] = 29939,
  [SMALL_STATE(897)] = 29950,
  [SMALL_STATE(898)] = 29963,
  [SMALL_STATE(899)] = 29976,
  [SMALL_STATE(900)] = 29993,
  [SMALL_STATE(901)] = 30006,
  [SMALL_STATE(902)] = 30019,
  [SMALL_STATE(903)] = 30032,
  [SMALL_STATE(904)] = 30043,
  [SMALL_STATE(905)] = 30054,
  [SMALL_STATE(906)] = 30067,
  [SMALL_STATE(907)] = 30078,
  [SMALL_STATE(908)] = 30093,
  [SMALL_STATE(909)] = 30104,
  [SMALL_STATE(910)] = 30115,
  [SMALL_STATE(911)] = 30126,
  [SMALL_STATE(912)] = 30143,
  [SMALL_STATE(913)] = 30158,
  [SMALL_STATE(914)] = 30171,
  [SMALL_STATE(915)] = 30184,
  [SMALL_STATE(916)] = 30197,
  [SMALL_STATE(917)] = 30210,
  [SMALL_STATE(918)] = 30229,
  [SMALL_STATE(919)] = 30242,
  [SMALL_STATE(920)] = 30255,
  [SMALL_STATE(921)] = 30266,
  [SMALL_STATE(922)] = 30279,
  [SMALL_STATE(923)] = 30298,
  [SMALL_STATE(924)] = 30311,
  [SMALL_STATE(925)] = 30324,
  [SMALL_STATE(926)] = 30337,
  [SMALL_STATE(927)] = 30350,
  [SMALL_STATE(928)] = 30367,
  [SMALL_STATE(929)] = 30380,
  [SMALL_STATE(930)] = 30399,
  [SMALL_STATE(931)] = 30412,
  [SMALL_STATE(932)] = 30431,
  [SMALL_STATE(933)] = 30448,
  [SMALL_STATE(934)] = 30467,
  [SMALL_STATE(935)] = 30480,
  [SMALL_STATE(936)] = 30499,
  [SMALL_STATE(937)] = 30512,
  [SMALL_STATE(938)] = 30523,
  [SMALL_STATE(939)] = 30536,
  [SMALL_STATE(940)] = 30549,
  [SMALL_STATE(941)] = 30564,
  [SMALL_STATE(942)] = 30579,
  [SMALL_STATE(943)] = 30590,
  [SMALL_STATE(944)] = 30603,
  [SMALL_STATE(945)] = 30614,
  [SMALL_STATE(946)] = 30627,
  [SMALL_STATE(947)] = 30640,
  [SMALL_STATE(948)] = 30653,
  [SMALL_STATE(949)] = 30666,
  [SMALL_STATE(950)] = 30677,
  [SMALL_STATE(951)] = 30690,
  [SMALL_STATE(952)] = 30701,
  [SMALL_STATE(953)] = 30712,
  [SMALL_STATE(954)] = 30722,
  [SMALL_STATE(955)] = 30738,
  [SMALL_STATE(956)] = 30748,
  [SMALL_STATE(957)] = 30762,
  [SMALL_STATE(958)] = 30778,
  [SMALL_STATE(959)] = 30794,
  [SMALL_STATE(960)] = 30810,
  [SMALL_STATE(961)] = 30826,
  [SMALL_STATE(962)] = 30836,
  [SMALL_STATE(963)] = 30852,
  [SMALL_STATE(964)] = 30868,
  [SMALL_STATE(965)] = 30884,
  [SMALL_STATE(966)] = 30894,
  [SMALL_STATE(967)] = 30904,
  [SMALL_STATE(968)] = 30914,
  [SMALL_STATE(969)] = 30928,
  [SMALL_STATE(970)] = 30944,
  [SMALL_STATE(971)] = 30960,
  [SMALL_STATE(972)] = 30974,
  [SMALL_STATE(973)] = 30988,
  [SMALL_STATE(974)] = 31004,
  [SMALL_STATE(975)] = 31014,
  [SMALL_STATE(976)] = 31030,
  [SMALL_STATE(977)] = 31046,
  [SMALL_STATE(978)] = 31056,
  [SMALL_STATE(979)] = 31072,
  [SMALL_STATE(980)] = 31088,
  [SMALL_STATE(981)] = 31098,
  [SMALL_STATE(982)] = 31108,
  [SMALL_STATE(983)] = 31118,
  [SMALL_STATE(984)] = 31128,
  [SMALL_STATE(985)] = 31138,
  [SMALL_STATE(986)] = 31148,
  [SMALL_STATE(987)] = 31162,
  [SMALL_STATE(988)] = 31172,
  [SMALL_STATE(989)] = 31186,
  [SMALL_STATE(990)] = 31202,
  [SMALL_STATE(991)] = 31216,
  [SMALL_STATE(992)] = 31226,
  [SMALL_STATE(993)] = 31236,
  [SMALL_STATE(994)] = 31248,
  [SMALL_STATE(995)] = 31260,
  [SMALL_STATE(996)] = 31276,
  [SMALL_STATE(997)] = 31286,
  [SMALL_STATE(998)] = 31302,
  [SMALL_STATE(999)] = 31312,
  [SMALL_STATE(1000)] = 31328,
  [SMALL_STATE(1001)] = 31338,
  [SMALL_STATE(1002)] = 31354,
  [SMALL_STATE(1003)] = 31366,
  [SMALL_STATE(1004)] = 31378,
  [SMALL_STATE(1005)] = 31391,
  [SMALL_STATE(1006)] = 31404,
  [SMALL_STATE(1007)] = 31417,
  [SMALL_STATE(1008)] = 31430,
  [SMALL_STATE(1009)] = 31443,
  [SMALL_STATE(1010)] = 31456,
  [SMALL_STATE(1011)] = 31467,
  [SMALL_STATE(1012)] = 31478,
  [SMALL_STATE(1013)] = 31491,
  [SMALL_STATE(1014)] = 31502,
  [SMALL_STATE(1015)] = 31513,
  [SMALL_STATE(1016)] = 31524,
  [SMALL_STATE(1017)] = 31535,
  [SMALL_STATE(1018)] = 31548,
  [SMALL_STATE(1019)] = 31559,
  [SMALL_STATE(1020)] = 31572,
  [SMALL_STATE(1021)] = 31583,
  [SMALL_STATE(1022)] = 31596,
  [SMALL_STATE(1023)] = 31607,
  [SMALL_STATE(1024)] = 31618,
  [SMALL_STATE(1025)] = 31629,
  [SMALL_STATE(1026)] = 31640,
  [SMALL_STATE(1027)] = 31651,
  [SMALL_STATE(1028)] = 31662,
  [SMALL_STATE(1029)] = 31673,
  [SMALL_STATE(1030)] = 31686,
  [SMALL_STATE(1031)] = 31697,
  [SMALL_STATE(1032)] = 31708,
  [SMALL_STATE(1033)] = 31719,
  [SMALL_STATE(1034)] = 31730,
  [SMALL_STATE(1035)] = 31743,
  [SMALL_STATE(1036)] = 31754,
  [SMALL_STATE(1037)] = 31765,
  [SMALL_STATE(1038)] = 31776,
  [SMALL_STATE(1039)] = 31789,
  [SMALL_STATE(1040)] = 31802,
  [SMALL_STATE(1041)] = 31813,
  [SMALL_STATE(1042)] = 31826,
  [SMALL_STATE(1043)] = 31839,
  [SMALL_STATE(1044)] = 31852,
  [SMALL_STATE(1045)] = 31865,
  [SMALL_STATE(1046)] = 31878,
  [SMALL_STATE(1047)] = 31891,
  [SMALL_STATE(1048)] = 31904,
  [SMALL_STATE(1049)] = 31917,
  [SMALL_STATE(1050)] = 31930,
  [SMALL_STATE(1051)] = 31943,
  [SMALL_STATE(1052)] = 31956,
  [SMALL_STATE(1053)] = 31967,
  [SMALL_STATE(1054)] = 31980,
  [SMALL_STATE(1055)] = 31993,
  [SMALL_STATE(1056)] = 32006,
  [SMALL_STATE(1057)] = 32019,
  [SMALL_STATE(1058)] = 32032,
  [SMALL_STATE(1059)] = 32043,
  [SMALL_STATE(1060)] = 32056,
  [SMALL_STATE(1061)] = 32069,
  [SMALL_STATE(1062)] = 32077,
  [SMALL_STATE(1063)] = 32087,
  [SMALL_STATE(1064)] = 32095,
  [SMALL_STATE(1065)] = 32105,
  [SMALL_STATE(1066)] = 32115,
  [SMALL_STATE(1067)] = 32125,
  [SMALL_STATE(1068)] = 32135,
  [SMALL_STATE(1069)] = 32145,
  [SMALL_STATE(1070)] = 32155,
  [SMALL_STATE(1071)] = 32165,
  [SMALL_STATE(1072)] = 32175,
  [SMALL_STATE(1073)] = 32185,
  [SMALL_STATE(1074)] = 32195,
  [SMALL_STATE(1075)] = 32205,
  [SMALL_STATE(1076)] = 32215,
  [SMALL_STATE(1077)] = 32225,
  [SMALL_STATE(1078)] = 32235,
  [SMALL_STATE(1079)] = 32245,
  [SMALL_STATE(1080)] = 32255,
  [SMALL_STATE(1081)] = 32265,
  [SMALL_STATE(1082)] = 32272,
  [SMALL_STATE(1083)] = 32279,
  [SMALL_STATE(1084)] = 32286,
  [SMALL_STATE(1085)] = 32293,
  [SMALL_STATE(1086)] = 32300,
  [SMALL_STATE(1087)] = 32307,
  [SMALL_STATE(1088)] = 32314,
  [SMALL_STATE(1089)] = 32321,
  [SMALL_STATE(1090)] = 32328,
  [SMALL_STATE(1091)] = 32335,
  [SMALL_STATE(1092)] = 32342,
  [SMALL_STATE(1093)] = 32349,
  [SMALL_STATE(1094)] = 32356,
  [SMALL_STATE(1095)] = 32363,
  [SMALL_STATE(1096)] = 32370,
  [SMALL_STATE(1097)] = 32377,
  [SMALL_STATE(1098)] = 32384,
  [SMALL_STATE(1099)] = 32391,
  [SMALL_STATE(1100)] = 32398,
  [SMALL_STATE(1101)] = 32405,
  [SMALL_STATE(1102)] = 32412,
  [SMALL_STATE(1103)] = 32419,
  [SMALL_STATE(1104)] = 32426,
  [SMALL_STATE(1105)] = 32433,
  [SMALL_STATE(1106)] = 32440,
  [SMALL_STATE(1107)] = 32447,
  [SMALL_STATE(1108)] = 32454,
  [SMALL_STATE(1109)] = 32461,
  [SMALL_STATE(1110)] = 32468,
  [SMALL_STATE(1111)] = 32475,
  [SMALL_STATE(1112)] = 32482,
  [SMALL_STATE(1113)] = 32489,
  [SMALL_STATE(1114)] = 32496,
  [SMALL_STATE(1115)] = 32503,
  [SMALL_STATE(1116)] = 32510,
  [SMALL_STATE(1117)] = 32517,
  [SMALL_STATE(1118)] = 32524,
  [SMALL_STATE(1119)] = 32531,
  [SMALL_STATE(1120)] = 32538,
  [SMALL_STATE(1121)] = 32545,
  [SMALL_STATE(1122)] = 32552,
  [SMALL_STATE(1123)] = 32559,
  [SMALL_STATE(1124)] = 32566,
  [SMALL_STATE(1125)] = 32573,
  [SMALL_STATE(1126)] = 32580,
  [SMALL_STATE(1127)] = 32587,
  [SMALL_STATE(1128)] = 32594,
  [SMALL_STATE(1129)] = 32601,
  [SMALL_STATE(1130)] = 32608,
  [SMALL_STATE(1131)] = 32615,
  [SMALL_STATE(1132)] = 32622,
  [SMALL_STATE(1133)] = 32629,
  [SMALL_STATE(1134)] = 32636,
  [SMALL_STATE(1135)] = 32643,
  [SMALL_STATE(1136)] = 32650,
  [SMALL_STATE(1137)] = 32657,
  [SMALL_STATE(1138)] = 32664,
  [SMALL_STATE(1139)] = 32671,
  [SMALL_STATE(1140)] = 32678,
  [SMALL_STATE(1141)] = 32685,
  [SMALL_STATE(1142)] = 32692,
  [SMALL_STATE(1143)] = 32699,
  [SMALL_STATE(1144)] = 32706,
  [SMALL_STATE(1145)] = 32713,
  [SMALL_STATE(1146)] = 32720,
  [SMALL_STATE(1147)] = 32727,
  [SMALL_STATE(1148)] = 32734,
  [SMALL_STATE(1149)] = 32741,
  [SMALL_STATE(1150)] = 32748,
  [SMALL_STATE(1151)] = 32755,
  [SMALL_STATE(1152)] = 32762,
  [SMALL_STATE(1153)] = 32769,
  [SMALL_STATE(1154)] = 32776,
  [SMALL_STATE(1155)] = 32783,
  [SMALL_STATE(1156)] = 32790,
  [SMALL_STATE(1157)] = 32797,
  [SMALL_STATE(1158)] = 32804,
  [SMALL_STATE(1159)] = 32811,
  [SMALL_STATE(1160)] = 32818,
  [SMALL_STATE(1161)] = 32825,
  [SMALL_STATE(1162)] = 32832,
  [SMALL_STATE(1163)] = 32839,
  [SMALL_STATE(1164)] = 32846,
  [SMALL_STATE(1165)] = 32853,
  [SMALL_STATE(1166)] = 32860,
  [SMALL_STATE(1167)] = 32867,
  [SMALL_STATE(1168)] = 32874,
  [SMALL_STATE(1169)] = 32881,
  [SMALL_STATE(1170)] = 32888,
  [SMALL_STATE(1171)] = 32895,
  [SMALL_STATE(1172)] = 32902,
  [SMALL_STATE(1173)] = 32909,
  [SMALL_STATE(1174)] = 32916,
  [SMALL_STATE(1175)] = 32923,
  [SMALL_STATE(1176)] = 32930,
  [SMALL_STATE(1177)] = 32937,
  [SMALL_STATE(1178)] = 32944,
  [SMALL_STATE(1179)] = 32951,
  [SMALL_STATE(1180)] = 32958,
  [SMALL_STATE(1181)] = 32965,
  [SMALL_STATE(1182)] = 32972,
  [SMALL_STATE(1183)] = 32979,
  [SMALL_STATE(1184)] = 32986,
  [SMALL_STATE(1185)] = 32993,
  [SMALL_STATE(1186)] = 33000,
  [SMALL_STATE(1187)] = 33007,
  [SMALL_STATE(1188)] = 33014,
  [SMALL_STATE(1189)] = 33021,
  [SMALL_STATE(1190)] = 33028,
  [SMALL_STATE(1191)] = 33035,
  [SMALL_STATE(1192)] = 33042,
  [SMALL_STATE(1193)] = 33049,
  [SMALL_STATE(1194)] = 33056,
  [SMALL_STATE(1195)] = 33063,
  [SMALL_STATE(1196)] = 33070,
  [SMALL_STATE(1197)] = 33077,
  [SMALL_STATE(1198)] = 33084,
  [SMALL_STATE(1199)] = 33091,
  [SMALL_STATE(1200)] = 33098,
  [SMALL_STATE(1201)] = 33105,
  [SMALL_STATE(1202)] = 33112,
  [SMALL_STATE(1203)] = 33119,
  [SMALL_STATE(1204)] = 33126,
  [SMALL_STATE(1205)] = 33133,
  [SMALL_STATE(1206)] = 33140,
  [SMALL_STATE(1207)] = 33147,
  [SMALL_STATE(1208)] = 33154,
  [SMALL_STATE(1209)] = 33161,
  [SMALL_STATE(1210)] = 33168,
  [SMALL_STATE(1211)] = 33175,
  [SMALL_STATE(1212)] = 33182,
  [SMALL_STATE(1213)] = 33189,
  [SMALL_STATE(1214)] = 33196,
  [SMALL_STATE(1215)] = 33203,
  [SMALL_STATE(1216)] = 33210,
  [SMALL_STATE(1217)] = 33217,
  [SMALL_STATE(1218)] = 33224,
  [SMALL_STATE(1219)] = 33231,
  [SMALL_STATE(1220)] = 33238,
  [SMALL_STATE(1221)] = 33245,
  [SMALL_STATE(1222)] = 33252,
  [SMALL_STATE(1223)] = 33259,
  [SMALL_STATE(1224)] = 33266,
  [SMALL_STATE(1225)] = 33273,
  [SMALL_STATE(1226)] = 33280,
  [SMALL_STATE(1227)] = 33287,
  [SMALL_STATE(1228)] = 33294,
  [SMALL_STATE(1229)] = 33301,
  [SMALL_STATE(1230)] = 33308,
  [SMALL_STATE(1231)] = 33315,
  [SMALL_STATE(1232)] = 33322,
  [SMALL_STATE(1233)] = 33329,
  [SMALL_STATE(1234)] = 33336,
  [SMALL_STATE(1235)] = 33343,
  [SMALL_STATE(1236)] = 33350,
  [SMALL_STATE(1237)] = 33357,
  [SMALL_STATE(1238)] = 33364,
  [SMALL_STATE(1239)] = 33371,
  [SMALL_STATE(1240)] = 33378,
  [SMALL_STATE(1241)] = 33385,
  [SMALL_STATE(1242)] = 33392,
  [SMALL_STATE(1243)] = 33399,
  [SMALL_STATE(1244)] = 33406,
  [SMALL_STATE(1245)] = 33413,
  [SMALL_STATE(1246)] = 33420,
  [SMALL_STATE(1247)] = 33427,
  [SMALL_STATE(1248)] = 33434,
  [SMALL_STATE(1249)] = 33441,
  [SMALL_STATE(1250)] = 33448,
  [SMALL_STATE(1251)] = 33455,
  [SMALL_STATE(1252)] = 33462,
  [SMALL_STATE(1253)] = 33469,
  [SMALL_STATE(1254)] = 33476,
  [SMALL_STATE(1255)] = 33483,
  [SMALL_STATE(1256)] = 33490,
  [SMALL_STATE(1257)] = 33497,
  [SMALL_STATE(1258)] = 33504,
  [SMALL_STATE(1259)] = 33511,
  [SMALL_STATE(1260)] = 33518,
  [SMALL_STATE(1261)] = 33525,
  [SMALL_STATE(1262)] = 33532,
  [SMALL_STATE(1263)] = 33539,
  [SMALL_STATE(1264)] = 33546,
  [SMALL_STATE(1265)] = 33553,
  [SMALL_STATE(1266)] = 33560,
  [SMALL_STATE(1267)] = 33567,
  [SMALL_STATE(1268)] = 33574,
  [SMALL_STATE(1269)] = 33581,
  [SMALL_STATE(1270)] = 33588,
  [SMALL_STATE(1271)] = 33595,
  [SMALL_STATE(1272)] = 33602,
  [SMALL_STATE(1273)] = 33609,
  [SMALL_STATE(1274)] = 33616,
  [SMALL_STATE(1275)] = 33623,
  [SMALL_STATE(1276)] = 33630,
  [SMALL_STATE(1277)] = 33637,
  [SMALL_STATE(1278)] = 33644,
  [SMALL_STATE(1279)] = 33651,
  [SMALL_STATE(1280)] = 33658,
  [SMALL_STATE(1281)] = 33665,
  [SMALL_STATE(1282)] = 33672,
  [SMALL_STATE(1283)] = 33679,
  [SMALL_STATE(1284)] = 33686,
  [SMALL_STATE(1285)] = 33693,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_makefile, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(878),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1069),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(417),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(492),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(468),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(760),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(845),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(533),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(812),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [89] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elsif_directive, 2, 0, 15),
  [91] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elsif_directive, 3, 0, 25),
  [93] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(76),
  [96] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(845),
  [99] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(846),
  [102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(1263),
  [105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(533),
  [108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(1067),
  [111] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(408),
  [114] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(446),
  [117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(330),
  [120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(1111),
  [123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(454),
  [126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0),
  [128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(468),
  [131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(445),
  [134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(557),
  [137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(558),
  [140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(760),
  [143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(734),
  [146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(737),
  [149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__conditional_consequence, 2, 0, 0), SHIFT_REPEAT(437),
  [152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_directive, 3, 0, 24),
  [154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_directive, 2, 0, 0),
  [156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(354),
  [174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(360),
  [182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(629),
  [188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(635),
  [198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(338),
  [202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(622),
  [206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(598),
  [214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(341),
  [218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(339),
  [226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(607),
  [230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(634),
  [238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(346),
  [242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(343),
  [246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0),
  [254] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(75),
  [257] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(854),
  [260] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(878),
  [263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(1284),
  [266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(514),
  [269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(1069),
  [272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(417),
  [275] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(492),
  [278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(321),
  [281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(1282),
  [284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(469),
  [287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(445),
  [293] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(558),
  [299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(760),
  [302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(760),
  [305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(734),
  [308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_makefile_repeat1, 2, 0, 0), SHIFT_REPEAT(737),
  [311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_makefile, 1, 0, 0),
  [313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 6, 0, 58),
  [315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 6, 0, 57),
  [317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 7, 0, 65),
  [319] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 5, 0, 43),
  [321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0),
  [323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0), SHIFT_REPEAT(445),
  [329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0), SHIFT_REPEAT(558),
  [335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0), SHIFT_REPEAT(437),
  [338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 5, 0, 40),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 4, 0, 29),
  [342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recipe, 2, 0, 0),
  [344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 7, 0, 54),
  [346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 7, 0, 66),
  [348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 4, 0, 17),
  [350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 3, 0, 17),
  [352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 7, 0, 69),
  [354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 5, 0, 41),
  [356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 8, 0, 76),
  [358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 6, 0, 54),
  [360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__static_pattern_rule, 6, 0, 43),
  [362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ordinary_rule, 6, 0, 52),
  [364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recipe, 3, 0, 0),
  [366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 6, 0, 43),
  [368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe, 2, 0, 0),
  [372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 5, 0, 40),
  [374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 7, 0, 65),
  [376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 8, 0, 76),
  [378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0),
  [380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_recipe_repeat1, 2, 0, 0), SHIFT_REPEAT(397),
  [383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 7, 0, 66),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 4, 0, 17),
  [387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 5, 0, 43),
  [389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe, 3, 0, 0),
  [391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 5, 0, 41),
  [393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 7, 0, 54),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 3, 0, 17),
  [397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 4, 0, 29),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 7, 0, 69),
  [401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 6, 0, 52),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 6, 0, 54),
  [405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordinary_rule, 6, 0, 57),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__static_pattern_rule, 6, 0, 58),
  [409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 1, 0, 0),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(633),
  [431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 1, 0, 0),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(638),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(784),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(613),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shell_text_without_split, 1, 0, 4),
  [471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(870),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_text, 1, 0, 4),
  [489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(786),
  [491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(503),
  [493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 4, 0, 12),
  [507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 4, 0, 12),
  [509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__prefixed_recipe_line, 3, 0, 0),
  [511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__prefixed_recipe_line, 3, 0, 0),
  [513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 8, 0, 63),
  [515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 8, 0, 63),
  [517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 7, 0, 60),
  [519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 7, 0, 60),
  [521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 8, 0, 72),
  [523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 8, 0, 72),
  [525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 8, 0, 60),
  [527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 8, 0, 60),
  [529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 7, 0, 32),
  [531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 7, 0, 32),
  [533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 7, 0, 59),
  [535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 7, 0, 59),
  [537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 1, 0, 4),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(512),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(946),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 2, 0, 0),
  [559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 2, 0, 0),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(612),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 8, 0, 75),
  [567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 8, 0, 75),
  [569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 6, 0, 56),
  [571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 6, 0, 56),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(614),
  [575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 8, 0, 77),
  [577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 8, 0, 77),
  [579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 6, 0, 42),
  [581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 6, 0, 42),
  [583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 6, 0, 55),
  [585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 6, 0, 55),
  [587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 6, 0, 53),
  [589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 6, 0, 53),
  [591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifeq_directive, 3, 0, 10),
  [593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifeq_directive, 3, 0, 10),
  [595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifneq_directive, 3, 0, 10),
  [597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifneq_directive, 3, 0, 10),
  [599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifdef_directive, 3, 0, 8),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifdef_directive, 3, 0, 8),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ifndef_directive, 3, 0, 8),
  [605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ifndef_directive, 3, 0, 8),
  [607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional, 6, 0, 28),
  [609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional, 6, 0, 28),
  [611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shell_assignment, 6, 0, 49),
  [613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shell_assignment, 6, 0, 49),
  [615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 6, 0, 49),
  [617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 6, 0, 49),
  [619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 6, 0, 45),
  [621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 6, 0, 45),
  [623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 6, 0, 32),
  [625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 6, 0, 32),
  [627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 6, 0, 44),
  [629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 6, 0, 44),
  [631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rule, 1, 0, 1),
  [633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule, 1, 0, 1),
  [635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rule, 1, 0, 2),
  [637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule, 1, 0, 2),
  [639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 9, 0, 78),
  [641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 9, 0, 78),
  [643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 5, 0, 42),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 5, 0, 42),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 8, 0, 71),
  [649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 8, 0, 71),
  [651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 7, 0, 61),
  [653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 7, 0, 61),
  [655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional, 5, 0, 14),
  [657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional, 5, 0, 14),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 7, 0, 45),
  [671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 7, 0, 45),
  [673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 7, 0, 63),
  [675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 7, 0, 63),
  [677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__prefixed_recipe_line, 2, 0, 0),
  [679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__prefixed_recipe_line, 2, 0, 0),
  [681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional, 5, 0, 28),
  [683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional, 5, 0, 28),
  [685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 7, 0, 53),
  [687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 7, 0, 53),
  [689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shell_assignment, 5, 0, 37),
  [691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shell_assignment, 5, 0, 37),
  [693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 5, 0, 37),
  [695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 5, 0, 37),
  [697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shell_assignment, 5, 0, 30),
  [699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shell_assignment, 5, 0, 30),
  [701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 5, 0, 30),
  [703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 5, 0, 30),
  [705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 5, 0, 22),
  [707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 5, 0, 22),
  [709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 5, 0, 32),
  [711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 5, 0, 32),
  [713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_RECIPEPREFIX_assignment, 5, 0, 30),
  [715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_RECIPEPREFIX_assignment, 5, 0, 30),
  [717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_VPATH_assignment, 5, 0, 30),
  [719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_VPATH_assignment, 5, 0, 30),
  [721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 7, 0, 64),
  [723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 7, 0, 64),
  [725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_vpath_directive, 2, 0, 0),
  [727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_vpath_directive, 2, 0, 0),
  [729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_directive, 2, 0, 0),
  [731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_directive, 2, 0, 0),
  [733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_define_directive, 8, 0, 70),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_directive, 8, 0, 70),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unexport_directive, 2, 0, 0),
  [743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unexport_directive, 2, 0, 0),
  [745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 7, 0, 55),
  [747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 7, 0, 55),
  [749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional, 4, 0, 28),
  [751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional, 4, 0, 28),
  [753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional, 4, 0, 14),
  [755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional, 4, 0, 14),
  [757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_override_directive, 2, 0, 0),
  [759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_override_directive, 2, 0, 0),
  [761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shell_assignment, 4, 0, 19),
  [763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shell_assignment, 4, 0, 19),
  [765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 4, 0, 19),
  [767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 4, 0, 19),
  [769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_private_directive, 2, 0, 0),
  [771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_private_directive, 2, 0, 0),
  [773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 9, 0, 79),
  [775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 9, 0, 79),
  [777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 4, 0, 22),
  [779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 4, 0, 22),
  [781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_vpath_directive, 4, 0, 20),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_vpath_directive, 4, 0, 20),
  [785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_RECIPEPREFIX_assignment, 4, 0, 19),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_RECIPEPREFIX_assignment, 4, 0, 19),
  [789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_VPATH_assignment, 4, 0, 19),
  [791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_VPATH_assignment, 4, 0, 19),
  [793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 7, 0, 67),
  [795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 7, 0, 67),
  [797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(905),
  [813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 7, 0, 68),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 7, 0, 68),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__thing, 2, 0, 0),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__thing, 2, 0, 0),
  [821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional, 3, 0, 14),
  [823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional, 3, 0, 14),
  [825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include_directive, 3, 0, 5),
  [827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include_directive, 3, 0, 5),
  [829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_vpath_directive, 3, 0, 6),
  [831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_vpath_directive, 3, 0, 6),
  [833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 3, 0, 12),
  [835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 3, 0, 12),
  [837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(521),
  [841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(920),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_directive, 3, 0, 7),
  [855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_directive, 3, 0, 7),
  [857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_undefine_directive, 3, 0, 8),
  [859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_undefine_directive, 3, 0, 8),
  [861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unexport_directive, 3, 0, 7),
  [863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unexport_directive, 3, 0, 7),
  [865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_assignment, 8, 0, 74),
  [867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_assignment, 8, 0, 74),
  [869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 1, 0, 0),
  [871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 1, 0, 0),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(347),
  [877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(344),
  [893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0),
  [897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0),
  [899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(348),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(363),
  [913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(528),
  [931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(342),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [953] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(197),
  [956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0),
  [958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0),
  [960] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(784),
  [963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(751),
  [966] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(750),
  [969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenation, 2, 0, 0),
  [973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenation, 2, 0, 0),
  [975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(529),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(188),
  [990] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(765),
  [993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(734),
  [996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(737),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(307),
  [1020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(758),
  [1023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(758),
  [1026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(717),
  [1029] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(718),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(336),
  [1040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paths, 1, 0, 0),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [1052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [1062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_paths_repeat1, 2, 0, 0),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 3, 0, 0),
  [1088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 3, 0, 0),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [1118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [1122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(336),
  [1137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(761),
  [1140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(726),
  [1143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenation_repeat1, 2, 0, 0), SHIFT_REPEAT(727),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [1162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__attached_recipe_line, 1, 0, 0),
  [1164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [1166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(85),
  [1168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [1170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [1192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [1200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [1202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(81),
  [1204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [1208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [1210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [1212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(82),
  [1214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [1222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [1226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [1228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [1234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__conditional_args_cmp, 2, 0, 9),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [1246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 1, 0, 4),
  [1256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 1, 0, 4),
  [1258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 1, 0, 4),
  [1264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 1, 0, 4),
  [1266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [1274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [1276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 31),
  [1284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 31),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 31),
  [1290] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 1, 0, 4),
  [1292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 1, 0, 4),
  [1294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [1298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat2, 1, 0, 4),
  [1302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 1, 0, 4),
  [1304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [1310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [1312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [1314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [1316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [1324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat2, 2, 0, 31),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [1330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [1338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [1344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_line_repeat1, 2, 0, 0), SHIFT_REPEAT(795),
  [1353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_line_repeat1, 2, 0, 0), SHIFT_REPEAT(176),
  [1356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_line_repeat1, 2, 0, 0), SHIFT_REPEAT(692),
  [1359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_line_repeat1, 2, 0, 0), SHIFT_REPEAT(728),
  [1362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_recipe_line_repeat1, 2, 0, 0), SHIFT_REPEAT(686),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [1437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [1451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(86),
  [1453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(637),
  [1455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [1457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_text, 2, 0, 0),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [1465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [1467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [1471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0),
  [1473] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(781),
  [1476] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(459),
  [1479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(816),
  [1482] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(852),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(681),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [1489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [1493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(684),
  [1495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [1497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [1499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(662),
  [1501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [1511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shell_text_without_split, 2, 0, 4),
  [1513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [1517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [1519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [1521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [1531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shell_text_without_split, 2, 0, 0),
  [1533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [1539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0),
  [1541] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(786),
  [1544] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(503),
  [1547] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(859),
  [1550] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(809),
  [1553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [1555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [1557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(695),
  [1559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_text, 2, 0, 4),
  [1561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(647),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [1567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [1569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [1571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [1573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [1579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(676),
  [1581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(673),
  [1583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [1585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(682),
  [1587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [1591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [1593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [1595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(688),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [1601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [1603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [1605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shell_text_without_split, 1, 0, 0),
  [1607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [1609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_text, 1, 0, 0),
  [1611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [1613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(667),
  [1615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [1617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [1619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 1, 0, 0),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 2, 0, 0),
  [1631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(453),
  [1633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [1635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0),
  [1637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(773),
  [1640] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(512),
  [1643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(938),
  [1646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(813),
  [1649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(796),
  [1651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [1653] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(795),
  [1656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(516),
  [1659] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(803),
  [1662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0), SHIFT_REPEAT(905),
  [1665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [1667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [1669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 2, 0, 4),
  [1671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [1673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(792),
  [1682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(521),
  [1685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(951),
  [1688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat2, 2, 0, 0), SHIFT_REPEAT(817),
  [1691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 5, 0, 35),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 5, 0, 35),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0),
  [1699] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0), SHIFT_REPEAT(781),
  [1702] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0), SHIFT_REPEAT(453),
  [1705] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0), SHIFT_REPEAT(853),
  [1708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shell_function, 5, 0, 35),
  [1710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shell_function, 5, 0, 35),
  [1712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [1716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [1718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [1728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0),
  [1730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(786),
  [1733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(505),
  [1736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(856),
  [1739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shell_function, 6, 0, 35),
  [1741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shell_function, 6, 0, 35),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [1745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 6, 0, 35),
  [1747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 6, 0, 35),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [1755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [1759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [1761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [1765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [1769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [1771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 3, 0, 4),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [1777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [1779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(513),
  [1783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [1785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 3, 0, 0),
  [1787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(491),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [1791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(825),
  [1793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [1795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(732),
  [1797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(519),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [1801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shell_text_without_split, 3, 0, 0),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(826),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [1807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [1809] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(792),
  [1812] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(518),
  [1815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(950),
  [1818] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string, 2, 0, 0), SHIFT_REPEAT(766),
  [1821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string, 2, 0, 0),
  [1823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string, 2, 0, 0), SHIFT_REPEAT(736),
  [1826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shell_text_without_split, 3, 0, 4),
  [1834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [1836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string, 2, 0, 0), SHIFT_REPEAT(755),
  [1839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string, 2, 0, 0), SHIFT_REPEAT(748),
  [1842] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(773),
  [1845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(513),
  [1848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(940),
  [1851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [1853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [1855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [1857] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0), SHIFT_REPEAT(795),
  [1860] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0), SHIFT_REPEAT(519),
  [1863] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0), SHIFT_REPEAT(907),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [1872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [1874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [1876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(928),
  [1878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [1888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_substitution_reference, 8, 0, 73),
  [1892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_substitution_reference, 8, 0, 73),
  [1894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [1896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [1898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [1900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [1902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [1904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [1908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [1910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_reference, 2, 0, 0),
  [1912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_reference, 2, 0, 0),
  [1914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_automatic_variable, 2, 0, 0),
  [1916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_automatic_variable, 2, 0, 0),
  [1918] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 3),
  [1920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 3),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [1924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [1932] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 11),
  [1934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 11),
  [1936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_automatic_variable, 4, 0, 0),
  [1938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_automatic_variable, 4, 0, 0),
  [1940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(510),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(923),
  [1946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_reference, 4, 0, 0),
  [1948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_reference, 4, 0, 0),
  [1950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [1956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(800),
  [1960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_automatic_variable, 5, 0, 0),
  [1964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_automatic_variable, 5, 0, 0),
  [1966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_archive, 4, 0, 23),
  [1970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_archive, 4, 0, 23),
  [1972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [1984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [1988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [1996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [1998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [2000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(551),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [2007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [2013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [2023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [2025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(586),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [2032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1080),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [2036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(536),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(754),
  [2042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [2046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 1, 0, 0),
  [2048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 1, 0, 0),
  [2050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [2052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 1, 0, 0),
  [2054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(916),
  [2056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [2062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat2, 2, 0, 0),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [2068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [2070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_recipe_line_repeat1, 2, 0, 0),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [2076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [2080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [2082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(532),
  [2092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [2096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [2098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 0),
  [2100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [2102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 4),
  [2104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__shell_text_without_split_repeat1, 2, 0, 4),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [2108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(993),
  [2110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 4),
  [2112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 2, 0, 4),
  [2114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0),
  [2116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [2118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [2120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [2122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(537),
  [2124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [2128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(542),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(539),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [2136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [2142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(520),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [2146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 1, 0, 0),
  [2148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [2152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shell_text_with_split, 2, 0, 0),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_paths, 2, 0, 0),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [2172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__normal_prerequisites, 1, 0, 18),
  [2174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [2176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__normal_prerequisites, 1, 0, 18),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [2184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [2194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_conditional_repeat1, 2, 0, 0),
  [2198] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_conditional_repeat1, 2, 0, 0), SHIFT_REPEAT(820),
  [2201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_paths_repeat1, 2, 0, 0), SHIFT_REPEAT(563),
  [2208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [2212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [2218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1061),
  [2220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1121),
  [2222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_define_directive_repeat1, 2, 0, 0),
  [2224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_define_directive_repeat1, 2, 0, 0), SHIFT_REPEAT(1061),
  [2227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [2229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1116),
  [2231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1103),
  [2233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [2235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [2237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [2241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [2243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [2255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1281),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [2259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [2263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 36),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [2267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [2273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [2281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [2287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [2301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [2305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [2309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [2311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [2313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [2315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [2317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [2319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1105),
  [2321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [2323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 21),
  [2325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [2327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [2329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [2331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [2333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [2335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [2337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [2339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 48), SHIFT_REPEAT(739),
  [2342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 48),
  [2344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [2350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [2352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [2354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [2356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [2360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1113),
  [2362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1120),
  [2364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_define_directive_repeat1, 1, 0, 0),
  [2366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 1, 0, 16),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [2370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 47),
  [2372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 4, 0, 50),
  [2374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 4, 0, 51),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [2380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [2386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [2388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(488),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [2392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 5, 0, 62),
  [2394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 2, 0, 26),
  [2396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 2, 0, 27),
  [2398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 3, 0, 39),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [2402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [2404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recipe_line, 3, 0, 38),
  [2406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [2410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [2414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [2430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [2434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__conditional_args_cmp, 5, 0, 46),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [2464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [2474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [2488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [2490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [2496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [2500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [2510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [2512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shell_command, 1, 0, 13),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [2536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [2538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [2546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__conditional_args_cmp, 4, 0, 34),
  [2548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__conditional_args_cmp, 4, 0, 33),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [2556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [2558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [2560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [2570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [2586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__attached_recipe_line, 2, 0, 0),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [2590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [2600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [2602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [2604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [2608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [2610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [2612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [2614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [2616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [2618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [2620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [2622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [2624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [2628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [2630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [2632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [2634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__conditional_args_cmp, 3, 0, 0),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [2638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [2642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [2644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [2646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [2648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [2650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [2652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [2654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [2656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [2658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [2660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [2666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [2670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [2672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [2674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [2676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [2678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [2682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [2684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [2688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [2690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [2692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [2694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [2696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [2698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [2702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [2704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [2706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [2716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [2718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [2720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [2726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [2728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [2730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [2734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [2738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [2740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [2742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [2744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [2746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [2748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [2750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [2754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [2758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [2760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [2764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [2766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [2768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [2772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [2774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [2776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [2778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [2780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2786] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [2790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [2792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [2794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [2796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_make(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_word,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
